html_content = '''<!doctype html>
<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <link rel="icon" type="image/svg+xml" href="/vanna.svg" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <link href="https://fonts.googleapis.com/css2?family=Roboto+Slab:wght@350&display=swap" rel="stylesheet">
    <script src="https://cdn.plot.ly/plotly-latest.min.js" type="text/javascript"></script>
    <title>Vanna.AI</title>
    <script type="module" crossorigin src="/assets/index-4b99beea.js"></script>
    <link rel="stylesheet" href="/assets/index-76ef0799.css">
  </head>
  <body class="bg-white dark:bg-slate-900">
    <div id="app"></div>
    
  </body>
</html>
'''

css_content = '''.nav-title{font-family:Roboto Slab,serif}*,:before,:after{box-sizing:border-box;border-width:0;border-style:solid;border-color:#e5e7eb}:before,:after{--tw-content: ""}html{line-height:1.5;-webkit-text-size-adjust:100%;-moz-tab-size:4;-o-tab-size:4;tab-size:4;font-family:ui-sans-serif,system-ui,-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica Neue,Arial,Noto Sans,sans-serif,"Apple Color Emoji","Segoe UI Emoji",Segoe UI Symbol,"Noto Color Emoji";font-feature-settings:normal;font-variation-settings:normal}body{margin:0;line-height:inherit}hr{height:0;color:inherit;border-top-width:1px}abbr:where([title]){-webkit-text-decoration:underline dotted;text-decoration:underline dotted}h1,h2,h3,h4,h5,h6{font-size:inherit;font-weight:inherit}a{color:inherit;text-decoration:inherit}b,strong{font-weight:bolder}code,kbd,samp,pre{font-family:ui-monospace,SFMono-Regular,Menlo,Monaco,Consolas,Liberation Mono,Courier New,monospace;font-size:1em}small{font-size:80%}sub,sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline}sub{bottom:-.25em}sup{top:-.5em}table{text-indent:0;border-color:inherit;border-collapse:collapse}button,input,optgroup,select,textarea{font-family:inherit;font-feature-settings:inherit;font-variation-settings:inherit;font-size:100%;font-weight:inherit;line-height:inherit;color:inherit;margin:0;padding:0}button,select{text-transform:none}button,[type=button],[type=reset],[type=submit]{-webkit-appearance:button;background-color:transparent;background-image:none}:-moz-focusring{outline:auto}:-moz-ui-invalid{box-shadow:none}progress{vertical-align:baseline}::-webkit-inner-spin-button,::-webkit-outer-spin-button{height:auto}[type=search]{-webkit-appearance:textfield;outline-offset:-2px}::-webkit-search-decoration{-webkit-appearance:none}::-webkit-file-upload-button{-webkit-appearance:button;font:inherit}summary{display:list-item}blockquote,dl,dd,h1,h2,h3,h4,h5,h6,hr,figure,p,pre{margin:0}fieldset{margin:0;padding:0}legend{padding:0}ol,ul,menu{list-style:none;margin:0;padding:0}dialog{padding:0}textarea{resize:vertical}input::-moz-placeholder,textarea::-moz-placeholder{opacity:1;color:#9ca3af}input::placeholder,textarea::placeholder{opacity:1;color:#9ca3af}button,[role=button]{cursor:pointer}:disabled{cursor:default}img,svg,video,canvas,audio,iframe,embed,object{display:block;vertical-align:middle}img,video{max-width:100%;height:auto}[hidden]{display:none}*,:before,:after{--tw-border-spacing-x: 0;--tw-border-spacing-y: 0;--tw-translate-x: 0;--tw-translate-y: 0;--tw-rotate: 0;--tw-skew-x: 0;--tw-skew-y: 0;--tw-scale-x: 1;--tw-scale-y: 1;--tw-pan-x: ;--tw-pan-y: ;--tw-pinch-zoom: ;--tw-scroll-snap-strictness: proximity;--tw-gradient-from-position: ;--tw-gradient-via-position: ;--tw-gradient-to-position: ;--tw-ordinal: ;--tw-slashed-zero: ;--tw-numeric-figure: ;--tw-numeric-spacing: ;--tw-numeric-fraction: ;--tw-ring-inset: ;--tw-ring-offset-width: 0px;--tw-ring-offset-color: #fff;--tw-ring-color: rgb(59 130 246 / .5);--tw-ring-offset-shadow: 0 0 #0000;--tw-ring-shadow: 0 0 #0000;--tw-shadow: 0 0 #0000;--tw-shadow-colored: 0 0 #0000;--tw-blur: ;--tw-brightness: ;--tw-contrast: ;--tw-grayscale: ;--tw-hue-rotate: ;--tw-invert: ;--tw-saturate: ;--tw-sepia: ;--tw-drop-shadow: ;--tw-backdrop-blur: ;--tw-backdrop-brightness: ;--tw-backdrop-contrast: ;--tw-backdrop-grayscale: ;--tw-backdrop-hue-rotate: ;--tw-backdrop-invert: ;--tw-backdrop-opacity: ;--tw-backdrop-saturate: ;--tw-backdrop-sepia: }::backdrop{--tw-border-spacing-x: 0;--tw-border-spacing-y: 0;--tw-translate-x: 0;--tw-translate-y: 0;--tw-rotate: 0;--tw-skew-x: 0;--tw-skew-y: 0;--tw-scale-x: 1;--tw-scale-y: 1;--tw-pan-x: ;--tw-pan-y: ;--tw-pinch-zoom: ;--tw-scroll-snap-strictness: proximity;--tw-gradient-from-position: ;--tw-gradient-via-position: ;--tw-gradient-to-position: ;--tw-ordinal: ;--tw-slashed-zero: ;--tw-numeric-figure: ;--tw-numeric-spacing: ;--tw-numeric-fraction: ;--tw-ring-inset: ;--tw-ring-offset-width: 0px;--tw-ring-offset-color: #fff;--tw-ring-color: rgb(59 130 246 / .5);--tw-ring-offset-shadow: 0 0 #0000;--tw-ring-shadow: 0 0 #0000;--tw-shadow: 0 0 #0000;--tw-shadow-colored: 0 0 #0000;--tw-blur: ;--tw-brightness: ;--tw-contrast: ;--tw-grayscale: ;--tw-hue-rotate: ;--tw-invert: ;--tw-saturate: ;--tw-sepia: ;--tw-drop-shadow: ;--tw-backdrop-blur: ;--tw-backdrop-brightness: ;--tw-backdrop-contrast: ;--tw-backdrop-grayscale: ;--tw-backdrop-hue-rotate: ;--tw-backdrop-invert: ;--tw-backdrop-opacity: ;--tw-backdrop-saturate: ;--tw-backdrop-sepia: }.sr-only{position:absolute;width:1px;height:1px;padding:0;margin:-1px;overflow:hidden;clip:rect(0,0,0,0);white-space:nowrap;border-width:0}.pointer-events-none{pointer-events:none}.collapse{visibility:collapse}.static{position:static}.fixed{position:fixed}.absolute{position:absolute}.relative{position:relative}.sticky{position:sticky}.inset-0{top:0;right:0;bottom:0;left:0}.inset-x-px{left:1px;right:1px}.inset-y-0{top:0;bottom:0}.bottom-0{bottom:0}.bottom-px{bottom:1px}.end-0{inset-inline-end:0px}.left-0{left:0}.right-0{right:0}.top-0{top:0}.z-10{z-index:10}.z-50{z-index:50}.z-\[60\]{z-index:60}.z-\[80\]{z-index:80}.-m-1{margin:-.25rem}.-m-1\.5{margin:-.375rem}.m-1{margin:.25rem}.m-3{margin:.75rem}.mx-auto{margin-left:auto;margin-right:auto}.mb-1{margin-bottom:.25rem}.mb-2{margin-bottom:.5rem}.mb-2\.5{margin-bottom:.625rem}.mb-3{margin-bottom:.75rem}.mb-auto{margin-bottom:auto}.ml-3{margin-left:.75rem}.ml-4{margin-left:1rem}.mr-1{margin-right:.25rem}.mr-1\.5{margin-right:.375rem}.mr-3{margin-right:.75rem}.ms-0{margin-inline-start:0px}.ms-3{margin-inline-start:.75rem}.mt-0{margin-top:0}.mt-0\.5{margin-top:.125rem}.mt-1{margin-top:.25rem}.mt-16{margin-top:4rem}.mt-2{margin-top:.5rem}.mt-3{margin-top:.75rem}.mt-5{margin-top:1.25rem}.mt-6{margin-top:1.5rem}.mt-7{margin-top:1.75rem}.mt-auto{margin-top:auto}.block{display:block}.inline-block{display:inline-block}.inline{display:inline}.flex{display:flex}.inline-flex{display:inline-flex}.table{display:table}.grid{display:grid}.hidden{display:none}.h-1{height:.25rem}.h-1\.5{height:.375rem}.h-3{height:.75rem}.h-3\.5{height:.875rem}.h-4{height:1rem}.h-5{height:1.25rem}.h-6{height:1.5rem}.h-7{height:1.75rem}.h-8{height:2rem}.h-\[2\.375rem\]{height:2.375rem}.h-auto{height:auto}.h-full{height:100%}.h-px{height:1px}.h-screen{height:100vh}.min-h-\[15rem\]{min-height:15rem}.min-h-\[calc\(100\%-3\.5rem\)\]{min-height:calc(100% - 3.5rem)}.w-0{width:0px}.w-1{width:.25rem}.w-1\.5{width:.375rem}.w-28{width:7rem}.w-3{width:.75rem}.w-3\.5{width:.875rem}.w-4{width:1rem}.w-6{width:1.5rem}.w-64{width:16rem}.w-8{width:2rem}.w-\[2\.375rem\]{width:2.375rem}.w-\[3\.25rem\]{width:3.25rem}.w-full{width:100%}.w-px{width:1px}.min-w-full{min-width:100%}.max-w-2xl{max-width:42rem}.max-w-4xl{max-width:56rem}.max-w-7xl{max-width:80rem}.max-w-\[50rem\]{max-width:50rem}.max-w-\[85rem\]{max-width:85rem}.max-w-md{max-width:28rem}.max-w-sm{max-width:24rem}.max-w-xs{max-width:20rem}.flex-1{flex:1 1 0%}.flex-auto{flex:1 1 auto}.flex-none{flex:none}.flex-shrink-0,.shrink-0{flex-shrink:0}.grow{flex-grow:1}.-translate-x-full{--tw-translate-x: -100%;transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skew(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.translate-x-0{--tw-translate-x: 0px;transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skew(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.translate-x-full{--tw-translate-x: 100%;transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skew(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.transform{transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skew(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}@keyframes bounce{0%,to{transform:translateY(-25%);animation-timing-function:cubic-bezier(.8,0,1,1)}50%{transform:none;animation-timing-function:cubic-bezier(0,0,.2,1)}}.animate-bounce{animation:bounce 1s infinite}@keyframes ping{75%,to{transform:scale(2);opacity:0}}.animate-ping{animation:ping 1s cubic-bezier(0,0,.2,1) infinite}@keyframes pulse{50%{opacity:.5}}.animate-pulse{animation:pulse 2s cubic-bezier(.4,0,.6,1) infinite}@keyframes spin{to{transform:rotate(360deg)}}.animate-spin{animation:spin 1s linear infinite}.cursor-pointer{cursor:pointer}.resize{resize:both}.appearance-none{-webkit-appearance:none;-moz-appearance:none;appearance:none}.flex-col{flex-direction:column}.items-start{align-items:flex-start}.items-center{align-items:center}.justify-end{justify-content:flex-end}.justify-center{justify-content:center}.justify-between{justify-content:space-between}.gap-1{gap:.25rem}.gap-1\.5{gap:.375rem}.gap-2{gap:.5rem}.gap-3{gap:.75rem}.gap-x-1{-moz-column-gap:.25rem;column-gap:.25rem}.gap-x-2{-moz-column-gap:.5rem;column-gap:.5rem}.gap-x-3{-moz-column-gap:.75rem;column-gap:.75rem}.gap-y-4{row-gap:1rem}.-space-y-px>:not([hidden])~:not([hidden]){--tw-space-y-reverse: 0;margin-top:calc(-1px * calc(1 - var(--tw-space-y-reverse)));margin-bottom:calc(-1px * var(--tw-space-y-reverse))}.space-y-1>:not([hidden])~:not([hidden]){--tw-space-y-reverse: 0;margin-top:calc(.25rem * calc(1 - var(--tw-space-y-reverse)));margin-bottom:calc(.25rem * var(--tw-space-y-reverse))}.space-y-1\.5>:not([hidden])~:not([hidden]){--tw-space-y-reverse: 0;margin-top:calc(.375rem * calc(1 - var(--tw-space-y-reverse)));margin-bottom:calc(.375rem * var(--tw-space-y-reverse))}.space-y-3>:not([hidden])~:not([hidden]){--tw-space-y-reverse: 0;margin-top:calc(.75rem * calc(1 - var(--tw-space-y-reverse)));margin-bottom:calc(.75rem * var(--tw-space-y-reverse))}.space-y-5>:not([hidden])~:not([hidden]){--tw-space-y-reverse: 0;margin-top:calc(1.25rem * calc(1 - var(--tw-space-y-reverse)));margin-bottom:calc(1.25rem * var(--tw-space-y-reverse))}.divide-y>:not([hidden])~:not([hidden]){--tw-divide-y-reverse: 0;border-top-width:calc(1px * calc(1 - var(--tw-divide-y-reverse)));border-bottom-width:calc(1px * var(--tw-divide-y-reverse))}.divide-gray-200>:not([hidden])~:not([hidden]){--tw-divide-opacity: 1;border-color:rgb(229 231 235 / var(--tw-divide-opacity))}.overflow-hidden{overflow:hidden}.overflow-x-auto{overflow-x:auto}.overflow-y-auto{overflow-y:auto}.overflow-x-hidden{overflow-x:hidden}.overflow-y-hidden{overflow-y:hidden}.truncate{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.whitespace-nowrap{white-space:nowrap}.whitespace-pre-wrap{white-space:pre-wrap}.whitespace-break-spaces{white-space:break-spaces}.rounded{border-radius:.25rem}.rounded-full{border-radius:9999px}.rounded-lg{border-radius:.5rem}.rounded-md{border-radius:.375rem}.rounded-xl{border-radius:.75rem}.rounded-b-md{border-bottom-right-radius:.375rem;border-bottom-left-radius:.375rem}.border{border-width:1px}.border-2{border-width:2px}.border-\[3px\]{border-width:3px}.border-b{border-bottom-width:1px}.border-r{border-right-width:1px}.border-s{border-inline-start-width:1px}.border-t{border-top-width:1px}.border-blue-500{--tw-border-opacity: 1;border-color:rgb(59 130 246 / var(--tw-border-opacity))}.border-blue-600{--tw-border-opacity: 1;border-color:rgb(37 99 235 / var(--tw-border-opacity))}.border-current{border-color:currentColor}.border-gray-200{--tw-border-opacity: 1;border-color:rgb(229 231 235 / var(--tw-border-opacity))}.border-gray-300{--tw-border-opacity: 1;border-color:rgb(209 213 219 / var(--tw-border-opacity))}.border-gray-600{--tw-border-opacity: 1;border-color:rgb(75 85 99 / var(--tw-border-opacity))}.border-gray-700{--tw-border-opacity: 1;border-color:rgb(55 65 81 / var(--tw-border-opacity))}.border-green-200{--tw-border-opacity: 1;border-color:rgb(187 247 208 / var(--tw-border-opacity))}.border-neutral-700{--tw-border-opacity: 1;border-color:rgb(64 64 64 / var(--tw-border-opacity))}.border-red-200{--tw-border-opacity: 1;border-color:rgb(254 202 202 / var(--tw-border-opacity))}.border-transparent{border-color:transparent}.border-yellow-200{--tw-border-opacity: 1;border-color:rgb(254 240 138 / var(--tw-border-opacity))}.border-t-transparent{border-top-color:transparent}.bg-blue-500{--tw-bg-opacity: 1;background-color:rgb(59 130 246 / var(--tw-bg-opacity))}.bg-blue-600{--tw-bg-opacity: 1;background-color:rgb(37 99 235 / var(--tw-bg-opacity))}.bg-gray-100{--tw-bg-opacity: 1;background-color:rgb(243 244 246 / var(--tw-bg-opacity))}.bg-gray-50{--tw-bg-opacity: 1;background-color:rgb(249 250 251 / var(--tw-bg-opacity))}.bg-gray-600{--tw-bg-opacity: 1;background-color:rgb(75 85 99 / var(--tw-bg-opacity))}.bg-gray-700{--tw-bg-opacity: 1;background-color:rgb(55 65 81 / var(--tw-bg-opacity))}.bg-gray-800{--tw-bg-opacity: 1;background-color:rgb(31 41 55 / var(--tw-bg-opacity))}.bg-gray-900{--tw-bg-opacity: 1;background-color:rgb(17 24 39 / var(--tw-bg-opacity))}.bg-green-600{--tw-bg-opacity: 1;background-color:rgb(22 163 74 / var(--tw-bg-opacity))}.bg-neutral-800{--tw-bg-opacity: 1;background-color:rgb(38 38 38 / var(--tw-bg-opacity))}.bg-slate-800{--tw-bg-opacity: 1;background-color:rgb(30 41 59 / var(--tw-bg-opacity))}.bg-slate-900{--tw-bg-opacity: 1;background-color:rgb(15 23 42 / var(--tw-bg-opacity))}.bg-white{--tw-bg-opacity: 1;background-color:rgb(255 255 255 / var(--tw-bg-opacity))}.bg-yellow-50{--tw-bg-opacity: 1;background-color:rgb(254 252 232 / var(--tw-bg-opacity))}.bg-opacity-50{--tw-bg-opacity: .5}.bg-opacity-80{--tw-bg-opacity: .8}.p-1{padding:.25rem}.p-1\.5{padding:.375rem}.p-2{padding:.5rem}.p-2\.5{padding:.625rem}.p-3{padding:.75rem}.p-4{padding:1rem}.p-6{padding:1.5rem}.px-3{padding-left:.75rem;padding-right:.75rem}.px-4{padding-left:1rem;padding-right:1rem}.px-6{padding-left:1.5rem;padding-right:1.5rem}.px-7{padding-left:1.75rem;padding-right:1.75rem}.py-10{padding-top:2.5rem;padding-bottom:2.5rem}.py-16{padding-top:4rem;padding-bottom:4rem}.py-2{padding-top:.5rem;padding-bottom:.5rem}.py-2\.5{padding-top:.625rem;padding-bottom:.625rem}.py-3{padding-top:.75rem;padding-bottom:.75rem}.py-4{padding-top:1rem;padding-bottom:1rem}.py-5{padding-top:1.25rem;padding-bottom:1.25rem}.pb-12{padding-bottom:3rem}.pe-3{padding-inline-end:.75rem}.pl-7{padding-left:1.75rem}.pr-4{padding-right:1rem}.pr-9{padding-right:2.25rem}.text-left{text-align:left}.text-center{text-align:center}.text-start{text-align:start}.align-middle{vertical-align:middle}.font-mono{font-family:ui-monospace,SFMono-Regular,Menlo,Monaco,Consolas,Liberation Mono,Courier New,monospace}.text-2xl{font-size:1.5rem;line-height:2rem}.text-3xl{font-size:1.875rem;line-height:2.25rem}.text-7xl{font-size:4.5rem;line-height:1}.text-sm{font-size:.875rem;line-height:1.25rem}.text-xl{font-size:1.25rem;line-height:1.75rem}.text-xs{font-size:.75rem;line-height:1rem}.font-bold{font-weight:700}.font-medium{font-weight:500}.font-semibold{font-weight:600}.uppercase{text-transform:uppercase}.leading-none{line-height:1}.tracking-wide{letter-spacing:.025em}.text-blue-500{--tw-text-opacity: 1;color:rgb(59 130 246 / var(--tw-text-opacity))}.text-blue-600{--tw-text-opacity: 1;color:rgb(37 99 235 / var(--tw-text-opacity))}.text-gray-200{--tw-text-opacity: 1;color:rgb(229 231 235 / var(--tw-text-opacity))}.text-gray-300{--tw-text-opacity: 1;color:rgb(209 213 219 / var(--tw-text-opacity))}.text-gray-400{--tw-text-opacity: 1;color:rgb(156 163 175 / var(--tw-text-opacity))}.text-gray-500{--tw-text-opacity: 1;color:rgb(107 114 128 / var(--tw-text-opacity))}.text-gray-600{--tw-text-opacity: 1;color:rgb(75 85 99 / var(--tw-text-opacity))}.text-gray-700{--tw-text-opacity: 1;color:rgb(55 65 81 / var(--tw-text-opacity))}.text-gray-800{--tw-text-opacity: 1;color:rgb(31 41 55 / var(--tw-text-opacity))}.text-green-500{--tw-text-opacity: 1;color:rgb(34 197 94 / var(--tw-text-opacity))}.text-green-600{--tw-text-opacity: 1;color:rgb(22 163 74 / var(--tw-text-opacity))}.text-neutral-400{--tw-text-opacity: 1;color:rgb(163 163 163 / var(--tw-text-opacity))}.text-red-500{--tw-text-opacity: 1;color:rgb(239 68 68 / var(--tw-text-opacity))}.text-red-600{--tw-text-opacity: 1;color:rgb(220 38 38 / var(--tw-text-opacity))}.text-slate-400{--tw-text-opacity: 1;color:rgb(148 163 184 / var(--tw-text-opacity))}.text-slate-700{--tw-text-opacity: 1;color:rgb(51 65 85 / var(--tw-text-opacity))}.text-white{--tw-text-opacity: 1;color:rgb(255 255 255 / var(--tw-text-opacity))}.text-yellow-400{--tw-text-opacity: 1;color:rgb(250 204 21 / var(--tw-text-opacity))}.text-yellow-700{--tw-text-opacity: 1;color:rgb(161 98 7 / var(--tw-text-opacity))}.text-yellow-800{--tw-text-opacity: 1;color:rgb(133 77 14 / var(--tw-text-opacity))}.decoration-2{text-decoration-thickness:2px}.opacity-0{opacity:0}.shadow{--tw-shadow: 0 1px 3px 0 rgb(0 0 0 / .1), 0 1px 2px -1px rgb(0 0 0 / .1);--tw-shadow-colored: 0 1px 3px 0 var(--tw-shadow-color), 0 1px 2px -1px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000),var(--tw-ring-shadow, 0 0 #0000),var(--tw-shadow)}.shadow-sm{--tw-shadow: 0 1px 2px 0 rgb(0 0 0 / .05);--tw-shadow-colored: 0 1px 2px 0 var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000),var(--tw-ring-shadow, 0 0 #0000),var(--tw-shadow)}.shadow-slate-700{--tw-shadow-color: #334155;--tw-shadow: var(--tw-shadow-colored)}.ring-1{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}.ring-transparent{--tw-ring-color: transparent}.ring-offset-white{--tw-ring-offset-color: #fff}.blur{--tw-blur: blur(8px);filter:var(--tw-blur) var(--tw-brightness) var(--tw-contrast) var(--tw-grayscale) var(--tw-hue-rotate) var(--tw-invert) var(--tw-saturate) var(--tw-sepia) var(--tw-drop-shadow)}.filter{filter:var(--tw-blur) var(--tw-brightness) var(--tw-contrast) var(--tw-grayscale) var(--tw-hue-rotate) var(--tw-invert) var(--tw-saturate) var(--tw-sepia) var(--tw-drop-shadow)}.transition{transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,-webkit-backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter,-webkit-backdrop-filter;transition-timing-function:cubic-bezier(.4,0,.2,1);transition-duration:.15s}.transition-all{transition-property:all;transition-timing-function:cubic-bezier(.4,0,.2,1);transition-duration:.15s}.transition-colors{transition-property:color,background-color,border-color,text-decoration-color,fill,stroke;transition-timing-function:cubic-bezier(.4,0,.2,1);transition-duration:.15s}.duration-200{transition-duration:.2s}.duration-300{transition-duration:.3s}.duration-500{transition-duration:.5s}.ease-in-out{transition-timing-function:cubic-bezier(.4,0,.2,1)}.ease-out{transition-timing-function:cubic-bezier(0,0,.2,1)}.\[--body-scroll\:true\]{--body-scroll: true}.before\:inline-block:before{content:var(--tw-content);display:inline-block}.before\:h-6:before{content:var(--tw-content);height:1.5rem}.before\:w-6:before{content:var(--tw-content);width:1.5rem}.before\:translate-x-0:before{content:var(--tw-content);--tw-translate-x: 0px;transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skew(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.before\:transform:before{content:var(--tw-content);transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skew(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.before\:rounded-full:before{content:var(--tw-content);border-radius:9999px}.before\:bg-white:before{content:var(--tw-content);--tw-bg-opacity: 1;background-color:rgb(255 255 255 / var(--tw-bg-opacity))}.before\:shadow:before{content:var(--tw-content);--tw-shadow: 0 1px 3px 0 rgb(0 0 0 / .1), 0 1px 2px -1px rgb(0 0 0 / .1);--tw-shadow-colored: 0 1px 3px 0 var(--tw-shadow-color), 0 1px 2px -1px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000),var(--tw-ring-shadow, 0 0 #0000),var(--tw-shadow)}.before\:ring-0:before{content:var(--tw-content);--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(0px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}.before\:transition:before{content:var(--tw-content);transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,-webkit-backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter,-webkit-backdrop-filter;transition-timing-function:cubic-bezier(.4,0,.2,1);transition-duration:.15s}.before\:duration-200:before{content:var(--tw-content);transition-duration:.2s}.before\:ease-in-out:before{content:var(--tw-content);transition-timing-function:cubic-bezier(.4,0,.2,1)}.first\:mt-0:first-child{margin-top:0}.first\:rounded-t-lg:first-child{border-top-left-radius:.5rem;border-top-right-radius:.5rem}.last\:rounded-b-lg:last-child{border-bottom-right-radius:.5rem;border-bottom-left-radius:.5rem}.checked\:bg-blue-600:checked{--tw-bg-opacity: 1;background-color:rgb(37 99 235 / var(--tw-bg-opacity))}.checked\:bg-none:checked{background-image:none}.checked\:before\:translate-x-full:checked:before{content:var(--tw-content);--tw-translate-x: 100%;transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skew(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.checked\:before\:bg-blue-200:checked:before{content:var(--tw-content);--tw-bg-opacity: 1;background-color:rgb(191 219 254 / var(--tw-bg-opacity))}.hover\:border-green-500:hover{--tw-border-opacity: 1;border-color:rgb(34 197 94 / var(--tw-border-opacity))}.hover\:border-red-500:hover{--tw-border-opacity: 1;border-color:rgb(239 68 68 / var(--tw-border-opacity))}.hover\:bg-blue-50:hover{--tw-bg-opacity: 1;background-color:rgb(239 246 255 / var(--tw-bg-opacity))}.hover\:bg-blue-500:hover{--tw-bg-opacity: 1;background-color:rgb(59 130 246 / var(--tw-bg-opacity))}.hover\:bg-blue-600:hover{--tw-bg-opacity: 1;background-color:rgb(37 99 235 / var(--tw-bg-opacity))}.hover\:bg-blue-700:hover{--tw-bg-opacity: 1;background-color:rgb(29 78 216 / var(--tw-bg-opacity))}.hover\:bg-gray-100:hover{--tw-bg-opacity: 1;background-color:rgb(243 244 246 / var(--tw-bg-opacity))}.hover\:bg-gray-50:hover{--tw-bg-opacity: 1;background-color:rgb(249 250 251 / var(--tw-bg-opacity))}.hover\:bg-green-500:hover{--tw-bg-opacity: 1;background-color:rgb(34 197 94 / var(--tw-bg-opacity))}.hover\:bg-red-500:hover{--tw-bg-opacity: 1;background-color:rgb(239 68 68 / var(--tw-bg-opacity))}.hover\:text-blue-500:hover{--tw-text-opacity: 1;color:rgb(59 130 246 / var(--tw-text-opacity))}.hover\:text-blue-600:hover{--tw-text-opacity: 1;color:rgb(37 99 235 / var(--tw-text-opacity))}.hover\:text-blue-800:hover{--tw-text-opacity: 1;color:rgb(30 64 175 / var(--tw-text-opacity))}.hover\:text-gray-400:hover{--tw-text-opacity: 1;color:rgb(156 163 175 / var(--tw-text-opacity))}.hover\:text-red-600:hover{--tw-text-opacity: 1;color:rgb(220 38 38 / var(--tw-text-opacity))}.hover\:text-white:hover{--tw-text-opacity: 1;color:rgb(255 255 255 / var(--tw-text-opacity))}.focus\:z-10:focus{z-index:10}.focus\:border-blue-500:focus{--tw-border-opacity: 1;border-color:rgb(59 130 246 / var(--tw-border-opacity))}.focus\:border-blue-600:focus{--tw-border-opacity: 1;border-color:rgb(37 99 235 / var(--tw-border-opacity))}.focus\:outline-none:focus{outline:2px solid transparent;outline-offset:2px}.focus\:ring-2:focus{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}.focus\:ring-blue-500:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(59 130 246 / var(--tw-ring-opacity))}.focus\:ring-blue-600:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(37 99 235 / var(--tw-ring-opacity))}.focus\:ring-gray-400:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(156 163 175 / var(--tw-ring-opacity))}.focus\:ring-green-200:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(187 247 208 / var(--tw-ring-opacity))}.focus\:ring-red-200:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(254 202 202 / var(--tw-ring-opacity))}.focus\:ring-red-500:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(239 68 68 / var(--tw-ring-opacity))}.focus\:ring-offset-2:focus{--tw-ring-offset-width: 2px}.focus\:ring-offset-white:focus{--tw-ring-offset-color: #fff}.disabled\:pointer-events-none:disabled{pointer-events:none}.disabled\:opacity-50:disabled{opacity:.5}.open.hs-overlay-open\:mt-7{margin-top:1.75rem}.open.hs-overlay-open\:translate-x-0{--tw-translate-x: 0px;transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skew(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.open.hs-overlay-open\:opacity-100{opacity:1}.open.hs-overlay-open\:duration-500{transition-duration:.5s}.open .hs-overlay-open\:mt-7{margin-top:1.75rem}.open .hs-overlay-open\:translate-x-0{--tw-translate-x: 0px;transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skew(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.open .hs-overlay-open\:opacity-100{opacity:1}.open .hs-overlay-open\:duration-500{transition-duration:.5s}@media (prefers-color-scheme: dark){.dark\:divide-gray-700>:not([hidden])~:not([hidden]){--tw-divide-opacity: 1;border-color:rgb(55 65 81 / var(--tw-divide-opacity))}.dark\:border-blue-500{--tw-border-opacity: 1;border-color:rgb(59 130 246 / var(--tw-border-opacity))}.dark\:border-gray-600{--tw-border-opacity: 1;border-color:rgb(75 85 99 / var(--tw-border-opacity))}.dark\:border-gray-700{--tw-border-opacity: 1;border-color:rgb(55 65 81 / var(--tw-border-opacity))}.dark\:border-neutral-700{--tw-border-opacity: 1;border-color:rgb(64 64 64 / var(--tw-border-opacity))}.dark\:bg-gray-700{--tw-bg-opacity: 1;background-color:rgb(55 65 81 / var(--tw-bg-opacity))}.dark\:bg-gray-800{--tw-bg-opacity: 1;background-color:rgb(31 41 55 / var(--tw-bg-opacity))}.dark\:bg-neutral-800{--tw-bg-opacity: 1;background-color:rgb(38 38 38 / var(--tw-bg-opacity))}.dark\:bg-slate-800{--tw-bg-opacity: 1;background-color:rgb(30 41 59 / var(--tw-bg-opacity))}.dark\:bg-slate-900{--tw-bg-opacity: 1;background-color:rgb(15 23 42 / var(--tw-bg-opacity))}.dark\:bg-opacity-80{--tw-bg-opacity: .8}.dark\:text-blue-500{--tw-text-opacity: 1;color:rgb(59 130 246 / var(--tw-text-opacity))}.dark\:text-gray-200{--tw-text-opacity: 1;color:rgb(229 231 235 / var(--tw-text-opacity))}.dark\:text-gray-300{--tw-text-opacity: 1;color:rgb(209 213 219 / var(--tw-text-opacity))}.dark\:text-gray-400{--tw-text-opacity: 1;color:rgb(156 163 175 / var(--tw-text-opacity))}.dark\:text-gray-500{--tw-text-opacity: 1;color:rgb(107 114 128 / var(--tw-text-opacity))}.dark\:text-neutral-400{--tw-text-opacity: 1;color:rgb(163 163 163 / var(--tw-text-opacity))}.dark\:text-slate-400{--tw-text-opacity: 1;color:rgb(148 163 184 / var(--tw-text-opacity))}.dark\:text-white{--tw-text-opacity: 1;color:rgb(255 255 255 / var(--tw-text-opacity))}.dark\:placeholder-gray-400::-moz-placeholder{--tw-placeholder-opacity: 1;color:rgb(156 163 175 / var(--tw-placeholder-opacity))}.dark\:placeholder-gray-400::placeholder{--tw-placeholder-opacity: 1;color:rgb(156 163 175 / var(--tw-placeholder-opacity))}.dark\:shadow-slate-700\/\[\.7\]{--tw-shadow-color: rgb(51 65 85 / .7);--tw-shadow: var(--tw-shadow-colored)}.dark\:before\:bg-gray-400:before{content:var(--tw-content);--tw-bg-opacity: 1;background-color:rgb(156 163 175 / var(--tw-bg-opacity))}.dark\:checked\:border-blue-500:checked{--tw-border-opacity: 1;border-color:rgb(59 130 246 / var(--tw-border-opacity))}.dark\:checked\:bg-blue-500:checked{--tw-bg-opacity: 1;background-color:rgb(59 130 246 / var(--tw-bg-opacity))}.dark\:checked\:bg-blue-600:checked{--tw-bg-opacity: 1;background-color:rgb(37 99 235 / var(--tw-bg-opacity))}.dark\:checked\:before\:bg-blue-200:checked:before{content:var(--tw-content);--tw-bg-opacity: 1;background-color:rgb(191 219 254 / var(--tw-bg-opacity))}.dark\:hover\:border-blue-400:hover{--tw-border-opacity: 1;border-color:rgb(96 165 250 / var(--tw-border-opacity))}.dark\:hover\:bg-gray-900:hover{--tw-bg-opacity: 1;background-color:rgb(17 24 39 / var(--tw-bg-opacity))}.dark\:hover\:bg-neutral-700:hover{--tw-bg-opacity: 1;background-color:rgb(64 64 64 / var(--tw-bg-opacity))}.dark\:hover\:bg-slate-800:hover{--tw-bg-opacity: 1;background-color:rgb(30 41 59 / var(--tw-bg-opacity))}.dark\:hover\:text-blue-400:hover{--tw-text-opacity: 1;color:rgb(96 165 250 / var(--tw-text-opacity))}.dark\:hover\:text-blue-500:hover{--tw-text-opacity: 1;color:rgb(59 130 246 / var(--tw-text-opacity))}.dark\:hover\:text-red-500:hover{--tw-text-opacity: 1;color:rgb(239 68 68 / var(--tw-text-opacity))}.dark\:hover\:text-slate-300:hover{--tw-text-opacity: 1;color:rgb(203 213 225 / var(--tw-text-opacity))}.dark\:hover\:text-white:hover{--tw-text-opacity: 1;color:rgb(255 255 255 / var(--tw-text-opacity))}.dark\:focus\:border-blue-500:focus{--tw-border-opacity: 1;border-color:rgb(59 130 246 / var(--tw-border-opacity))}.dark\:focus\:outline-none:focus{outline:2px solid transparent;outline-offset:2px}.dark\:focus\:ring-1:focus{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}.dark\:focus\:ring-blue-500:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(59 130 246 / var(--tw-ring-opacity))}.dark\:focus\:ring-gray-600:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(75 85 99 / var(--tw-ring-opacity))}.dark\:focus\:ring-gray-700:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(55 65 81 / var(--tw-ring-opacity))}.dark\:focus\:ring-red-600:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(220 38 38 / var(--tw-ring-opacity))}.dark\:focus\:ring-offset-gray-800:focus{--tw-ring-offset-color: #1f2937}}@media (min-width: 640px){.sm\:mx-auto{margin-left:auto;margin-right:auto}.sm\:mb-3{margin-bottom:.75rem}.sm\:mt-10{margin-top:2.5rem}.sm\:w-auto{width:auto}.sm\:w-full{width:100%}.sm\:max-w-lg{max-width:32rem}.sm\:flex-row{flex-direction:row}.sm\:gap-3{gap:.75rem}.sm\:gap-x-4{-moz-column-gap:1rem;column-gap:1rem}.sm\:p-4{padding:1rem}.sm\:px-6{padding-left:1.5rem;padding-right:1.5rem}.sm\:py-4{padding-top:1rem;padding-bottom:1rem}.sm\:py-6{padding-top:1.5rem;padding-bottom:1.5rem}.sm\:text-3xl{font-size:1.875rem;line-height:2.25rem}.sm\:text-4xl{font-size:2.25rem;line-height:2.5rem}.sm\:text-9xl{font-size:8rem;line-height:1}}@media (min-width: 768px){.md\:flex{display:flex}.md\:items-center{align-items:center}.md\:justify-between{justify-content:space-between}.md\:p-10{padding:2.5rem}.md\:p-5{padding:1.25rem}}@media (min-width: 1024px){.lg\:bottom-0{bottom:0}.lg\:right-auto{right:auto}.lg\:block{display:block}.lg\:hidden{display:none}.lg\:translate-x-0{--tw-translate-x: 0px;transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skew(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.lg\:px-8{padding-left:2rem;padding-right:2rem}.lg\:py-14{padding-top:3.5rem;padding-bottom:3.5rem}.lg\:pl-64{padding-left:16rem}}
'''

js_content = '''var Kr=Object.defineProperty;var Xr=(o,e,n)=>e in o?Kr(o,e,{enumerable:!0,configurable:!0,writable:!0,value:n}):o[e]=n;var _n=(o,e,n)=>(Xr(o,typeof e!="symbol"?e+"":e,n),n);(function(){const e=document.createElement("link").relList;if(e&&e.supports&&e.supports("modulepreload"))return;for(const r of document.querySelectorAll('link[rel="modulepreload"]'))t(r);new MutationObserver(r=>{for(const i of r)if(i.type==="childList")for(const s of i.addedNodes)s.tagName==="LINK"&&s.rel==="modulepreload"&&t(s)}).observe(document,{childList:!0,subtree:!0});function n(r){const i={};return r.integrity&&(i.integrity=r.integrity),r.referrerPolicy&&(i.referrerPolicy=r.referrerPolicy),r.crossOrigin==="use-credentials"?i.credentials="include":r.crossOrigin==="anonymous"?i.credentials="omit":i.credentials="same-origin",i}function t(r){if(r.ep)return;r.ep=!0;const i=n(r);fetch(r.href,i)}})();function Y(){}function eo(o,e){for(const n in e)o[n]=e[n];return o}function Mr(o){return o()}function Gn(){return Object.create(null)}function mt(o){o.forEach(Mr)}function Dt(o){return typeof o=="function"}function he(o,e){return o!=o?e==e:o!==e||o&&typeof o=="object"||typeof o=="function"}let en;function Zn(o,e){return o===e?!0:(en||(en=document.createElement("a")),en.href=e,o===en.href)}function to(o){return Object.keys(o).length===0}function Dr(o,...e){if(o==null){for(const t of e)t(void 0);return Y}const n=o.subscribe(...e);return n.unsubscribe?()=>n.unsubscribe():n}function pt(o){let e;return Dr(o,n=>e=n)(),e}function et(o,e,n){o.$$.on_destroy.push(Dr(e,n))}function on(o,e,n,t){if(o){const r=Rr(o,e,n,t);return o[0](r)}}function Rr(o,e,n,t){return o[1]&&t?eo(n.ctx.slice(),o[1](t(e))):n.ctx}function sn(o,e,n,t){if(o[2]&&t){const r=o[2](t(n));if(e.dirty===void 0)return r;if(typeof r=="object"){const i=[],s=Math.max(e.dirty.length,r.length);for(let l=0;l<s;l+=1)i[l]=e.dirty[l]|r[l];return i}return e.dirty|r}return e.dirty}function ln(o,e,n,t,r,i){if(r){const s=Rr(e,n,t,i);o.p(s,r)}}function an(o){if(o.ctx.length>32){const e=[],n=o.ctx.length/32;for(let t=0;t<n;t++)e[t]=-1;return e}return-1}function v(o,e){o.appendChild(e)}function N(o,e,n){o.insertBefore(e,n||null)}function B(o){o.parentNode&&o.parentNode.removeChild(o)}function nt(o,e){for(let n=0;n<o.length;n+=1)o[n]&&o[n].d(e)}function E(o){return document.createElement(o)}function Xe(o){return document.createElementNS("http://www.w3.org/2000/svg",o)}function pe(o){return document.createTextNode(o)}function Q(){return pe(" ")}function Ve(){return pe("")}function Te(o,e,n,t){return o.addEventListener(e,n,t),()=>o.removeEventListener(e,n,t)}function d(o,e,n){n==null?o.removeAttribute(e):o.getAttribute(e)!==n&&o.setAttribute(e,n)}function no(o){let e;return{p(...n){e=n,e.forEach(t=>o.push(t))},r(){e.forEach(n=>o.splice(o.indexOf(n),1))}}}function ro(o){return Array.from(o.childNodes)}function De(o,e){e=""+e,o.data!==e&&(o.data=e)}function gt(o,e){o.value=e??""}function tn(o,e,n,t){n==null?o.style.removeProperty(e):o.style.setProperty(e,n,t?"important":"")}let Wt;function Zt(o){Wt=o}function oo(){if(!Wt)throw new Error("Function called outside component initialization");return Wt}function Hr(o){oo().$$.on_mount.push(o)}const Mt=[],$n=[];let Rt=[];const kn=[],io=Promise.resolve();let xn=!1;function so(){xn||(xn=!0,io.then(Br))}function Sn(o){Rt.push(o)}function lo(o){kn.push(o)}const wn=new Set;let qt=0;function Br(){if(qt!==0)return;const o=Wt;do{try{for(;qt<Mt.length;){const e=Mt[qt];qt++,Zt(e),ao(e.$$)}}catch(e){throw Mt.length=0,qt=0,e}for(Zt(null),Mt.length=0,qt=0;$n.length;)$n.pop()();for(let e=0;e<Rt.length;e+=1){const n=Rt[e];wn.has(n)||(wn.add(n),n())}Rt.length=0}while(Mt.length);for(;kn.length;)kn.pop()();xn=!1,wn.clear(),Zt(o)}function ao(o){if(o.fragment!==null){o.update(),mt(o.before_update);const e=o.dirty;o.dirty=[-1],o.fragment&&o.fragment.p(o.ctx,e),o.after_update.forEach(Sn)}}function co(o){const e=[],n=[];Rt.forEach(t=>o.indexOf(t)===-1?e.push(t):n.push(t)),n.forEach(t=>t()),Rt=e}const nn=new Set;let St;function Se(){St={r:0,c:[],p:St}}function Oe(){St.r||mt(St.c),St=St.p}function L(o,e){o&&o.i&&(nn.delete(o),o.i(e))}function A(o,e,n,t){if(o&&o.o){if(nn.has(o))return;nn.add(o),St.c.push(()=>{nn.delete(o),t&&(n&&o.d(1),t())}),o.o(e)}else t&&t()}function Le(o){return(o==null?void 0:o.length)!==void 0?o:Array.from(o)}function uo(o,e,n){const t=o.$$.props[e];t!==void 0&&(o.$$.bound[t]=n,n(o.$$.ctx[t]))}function U(o){o&&o.c()}function G(o,e,n){const{fragment:t,after_update:r}=o.$$;t&&t.m(e,n),Sn(()=>{const i=o.$$.on_mount.map(Mr).filter(Dt);o.$$.on_destroy?o.$$.on_destroy.push(...i):mt(i),o.$$.on_mount=[]}),r.forEach(Sn)}function Z(o,e){const n=o.$$;n.fragment!==null&&(co(n.after_update),mt(n.on_destroy),n.fragment&&n.fragment.d(e),n.on_destroy=n.fragment=null,n.ctx=[])}function fo(o,e){o.$$.dirty[0]===-1&&(Mt.push(o),so(),o.$$.dirty.fill(0)),o.$$.dirty[e/31|0]|=1<<e%31}function be(o,e,n,t,r,i,s,l=[-1]){const c=Wt;Zt(o);const a=o.$$={fragment:null,ctx:[],props:i,update:Y,not_equal:r,bound:Gn(),on_mount:[],on_destroy:[],on_disconnect:[],before_update:[],after_update:[],context:new Map(e.context||(c?c.$$.context:[])),callbacks:Gn(),dirty:l,skip_bound:!1,root:e.target||c.$$.root};s&&s(a.root);let g=!1;if(a.ctx=n?n(o,e.props||{},(h,x,...k)=>{const q=k.length?k[0]:x;return a.ctx&&r(a.ctx[h],a.ctx[h]=q)&&(!a.skip_bound&&a.bound[h]&&a.bound[h](q),g&&fo(o,h)),x}):[],a.update(),g=!0,mt(a.before_update),a.fragment=t?t(a.ctx):!1,e.target){if(e.hydrate){const h=ro(e.target);a.fragment&&a.fragment.l(h),h.forEach(B)}else a.fragment&&a.fragment.c();e.intro&&L(o.$$.fragment),G(o,e.target,e.anchor),Br()}Zt(c)}class ve{constructor(){_n(this,"$$");_n(this,"$$set")}$destroy(){Z(this,1),this.$destroy=Y}$on(e,n){if(!Dt(n))return Y;const t=this.$$.callbacks[e]||(this.$$.callbacks[e]=[]);return t.push(n),()=>{const r=t.indexOf(n);r!==-1&&t.splice(r,1)}}$set(e){this.$$set&&!to(e)&&(this.$$.skip_bound=!0,this.$$set(e),this.$$.skip_bound=!1)}}const po="4";typeof window<"u"&&(window.__svelte||(window.__svelte={v:new Set})).v.add(po);const At=[];function rt(o,e=Y){let n;const t=new Set;function r(l){if(he(o,l)&&(o=l,n)){const c=!At.length;for(const a of t)a[1](),At.push(a,o);if(c){for(let a=0;a<At.length;a+=2)At[a][0](At[a+1]);At.length=0}}}function i(l){r(l(o))}function s(l,c=Y){const a=[l,c];return t.add(a),t.size===1&&(n=e(r,i)||Y),l(o),()=>{t.delete(a),t.size===0&&n&&(n(),n=null)}}return{set:r,update:i,subscribe:s}}let Ht=rt(""),Bt=rt([]),On=rt(null),cn=rt(null),un=rt(!1),Ut=rt(!1),wt=rt("chat"),Cn=rt([]),Qt=rt(""),Nr=rt(!1),Ot=rt({debug:!0,logo:"",title:"Welcome to Vanna.AI",subtitle:"Loading...",show_training_data:!0,suggested_questions:!0,sql:!0,table:!0,csv_download:!0,chart:!0,redraw_chart:!0,auto_fix_sql:!0,ask_results_correct:!0,followup_questions:!0,summarization:!0}),fn=rt(null);function dn(){Bt.set([]),un.set(!1),Ut.set(!1)}async function Ln(o){dn();let e=pt(Ot);ue({type:"user_question",question:o}),un.set(!0);const n=await xe("generate_sql","GET",{question:o});if(ue(n),n.type!=="sql")return;window.location.hash=n.id,Ht.set(n.id),Qt.set(n.text);const t=await xe("run_sql","GET",{id:n.id});if(ue(t),t.type==="df"){if(t.should_generate_chart){const r=await xe("generate_plotly_figure","GET",{id:t.id});if(ue(r),r.type!=="plotly_figure")return;Cn.update(i=>[...i,{question:o,id:r.id}])}if(e.summarization){const r=await xe("generate_summary","GET",{id:n.id});ue(r)}ue({type:"feedback_question"}),ue({type:"feedback_buttons"})}}async function go(o){let e=pt(Ot);if(ue(o),o.type!=="sql")return;window.location.hash=o.id,Ht.set(o.id),Qt.set(o.text);const n=await xe("run_sql","GET",{id:o.id});if(ue(n),n.type!=="df")return;const t=await xe("generate_plotly_figure","GET",{id:n.id});if(ue(t),t.type==="plotly_figure"){if(e.summarization){const r=await xe("generate_summary","GET",{id:t.id});ue(r)}ue({type:"feedback_question"}),ue({type:"feedback_buttons"})}}function mo(o){ue({type:"user_question",question:"Re-run the SQL"}),xe("run_sql","GET",{id:o}).then(ue).then(e=>{e.type==="df"&&xe("generate_plotly_figure","GET",{id:e.id}).then(ue).then(n=>{n.type==="plotly_figure"&&xe("generate_followup_questions","GET",{id:n.id}).then(ue)})})}function ho(){xe("get_question_history","GET",[]).then($o)}function yo(){xe("get_config","GET",[]).then(wo)}function Ir(){window.location.hash="training-data",wt.set("training-data"),xe("get_training_data","GET",[]).then(rn)}function zr(){window.location.hash="",wt.set("chat"),dn(),pt(On)===null&&xe("generate_questions","GET",[]).then(_o)}function bo(o){window.location.hash=o,wt.set("chat"),dn(),un.set(!0),xe("load_question","GET",{id:o}).then(ue)}function vo(o){cn.set(null),xe("remove_training_data","POST",{id:o}).then(e=>{xe("get_training_data","GET",[]).then(rn)})}function ue(o){return o.type==="not_logged_in"?(fn.set(o.html),wt.set("login"),o):(Bt.update(e=>[...e,o]),xo(),o)}function rn(o){return cn.set(o),o.type==="df"?JSON.parse(o.df).length===0&&wt.set("no-training-data"):o.type==="not_logged_in"&&(fn.set(o.html),wt.set("login")),o}function _o(o){return On.set(o),o}function wo(o){return o.type==="config"?(Ot.set(o.config),o.config.debug&&jo()):o.type==="not_logged_in"&&(fn.set(o.html),wt.set("login")),o}function $o(o){return o.type==="question_history"&&Cn.set(o.questions),o}function ko(o,e){cn.set(null);let n={};n[e]=o,xe("train","POST",n).then(rn).then(t=>{t.type!=="error"&&xe("get_training_data","GET",[]).then(rn)})}async function xe(o,e,n){try{Ut.set(!0);let t="",r;if(e==="GET")t=Object.entries(n).filter(([s,l])=>s!=="endpoint"&&s!=="addMessage").map(([s,l])=>`${encodeURIComponent(s)}=${encodeURIComponent(l)}`).join("&"),r=await fetch(`/api/v0/${o}?${t}`);else{let s=JSON.stringify(n);r=await fetch(`/api/v0/${o}`,{method:"POST",headers:{"Content-Type":"application/json"},body:s})}if(!r.ok)throw new Error("The server returned an error. See the server logs for more details.");const i=await r.json();return Ut.set(!1),i}catch(t){return Ut.set(!1),{type:"error",error:String(t)}}}function xo(){setTimeout(()=>{window.scrollTo({top:document.body.scrollHeight,behavior:"smooth"})},100)}function So(){let o=pt(Bt),e=o.find(n=>n.type==="user_question");if(e&&e.type==="user_question"){let n=o.findLast(t=>t.type==="sql");if(n&&n.type==="sql")return{question:e.question,sql:n.text}}return null}function pn(o){Bt.update(e=>e.filter(n=>n.type!==o))}function Oo(o){xe("fix_sql","POST",{id:pt(Ht),error:o}).then(go)}function Co(o){let n=pt(Bt).find(t=>t.type==="user_question");n&&n.type==="user_question"&&(xe("update_sql","POST",{id:pt(Ht),sql:o}).then(ue).then(t=>{t.type==="sql"&&(Qt.set(t.text),xe("run_sql","GET",{id:t.id}).then(ue).then(r=>{r.type==="df"?JSON.parse(r.df).length>1?xe("generate_plotly_figure","GET",{id:r.id}).then(ue).then(s=>{ue({type:"feedback_question"}),ue({type:"feedback_buttons"})}):(ue({type:"feedback_question"}),ue({type:"feedback_buttons"})):(ue({type:"feedback_question"}),ue({type:"feedback_buttons"}))}))}),pn("user_sql"))}function Lo(){ue({type:"chart_modification"})}function Eo(){pn("feedback_buttons"),ue({type:"feedback_correct"});let o=So();o&&(xe("train","POST",o),xe("generate_followup_questions","GET",{id:pt(Ht)}).then(ue))}function Un(){pn("feedback_buttons"),ue({type:"feedback_incorrect"}),ue({type:"user_sql"})}function To(o){pn("chart_modification"),ue({type:"user_question",question:"Update the chart with these instructions: "+o}),xe("generate_plotly_figure","GET",{id:pt(Ht),chart_instructions:o}).then(ue)}function jo(){var o=new WebSocket("ws://"+window.location.host+"/api/v0/log");o.onopen=function(){console.log("Connected to WebSocket server at /log.")},o.onmessage=function(e){console.log("Received message:",e.data);try{var n=JSON.parse(e.data)}catch(r){console.error("Error parsing JSON:",r);return}var t=document.getElementById("log-contents");t&&(t.innerHTML+="<details> <summary>"+n.title+"</summary> "+JSON.stringify(n.message)+"</details> <br>")},o.onclose=function(e){console.log("WebSocket connection closed:",e)},o.onerror=function(e){console.error("WebSocket error:",e)}}function Wn(o,e,n){const t=o.slice();return t[3]=e[n],t}function Qn(o){let e,n,t,r;return{c(){e=E("li"),n=E("button"),n.innerHTML=`<svg class="w-3.5 h-3.5" fill="none" stroke="currentColor" stroke-width="1.5" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg" aria-hidden="true"><path stroke-linecap="round" stroke-linejoin="round" d="M4.26 10.147a60.436 60.436 0 00-.491 6.347A48.627 48.627 0 0112 20.904a48.627 48.627 0 018.232-4.41 60.46 60.46 0 00-.491-6.347m-15.482 0a50.57 50.57 0 00-2.658-.813A59.905 59.905 0 0112 3.493a59.902 59.902 0 0110.399 5.84c-.896.248-1.783.52-2.658.814m-15.482 0A50.697 50.697 0 0112 13.489a50.702 50.702 0 017.74-3.342M6.75 15a.75.75 0 100-1.5.75.75 0 000 1.5zm0 0v-3.675A55.378 55.378 0 0112 8.443m-7.007 11.55A5.981 5.981 0 006.75 15.75v-1.5"></path></svg>
              Training Data`,d(n,"class","flex items-center gap-x-3 py-2 px-3 text-sm text-slate-700 rounded-md hover:bg-gray-100 dark:hover:bg-gray-900 dark:text-slate-400 dark:hover:text-slate-300 border-t border-b border-gray-200 dark:border-gray-700 w-full")},m(i,s){N(i,e,s),v(e,n),t||(r=Te(n,"click",Ir),t=!0)},d(i){i&&B(e),t=!1,r()}}}function Fn(o){let e,n,t,r,i,s=o[3].question+"",l,c,a,g;function h(){return o[2](o[3])}return{c(){e=E("li"),n=E("button"),t=Xe("svg"),r=Xe("path"),i=Q(),l=pe(s),c=Q(),d(r,"stroke-linecap","round"),d(r,"stroke-linejoin","round"),d(r,"d","M7.5 8.25h9m-9 3H12m-9.75 1.51c0 1.6 1.123 2.994 2.707 3.227 1.129.166 2.27.293 3.423.379.35.026.67.21.865.501L12 21l2.755-4.133a1.14 1.14 0 01.865-.501 48.172 48.172 0 003.423-.379c1.584-.233 2.707-1.626 2.707-3.228V6.741c0-1.602-1.123-2.995-2.707-3.228A48.394 48.394 0 0012 3c-2.392 0-4.744.175-7.043.513C3.373 3.746 2.25 5.14 2.25 6.741v6.018z"),d(t,"class","w-3.5 h-3.5"),d(t,"fill","none"),d(t,"stroke","currentColor"),d(t,"stroke-width","1.5"),d(t,"viewBox","0 0 24 24"),d(t,"xmlns","http://www.w3.org/2000/svg"),d(t,"aria-hidden","true"),d(n,"class","flex items-center text-left gap-x-3 py-2 px-3 text-sm text-slate-700 rounded-md hover:bg-gray-100 dark:hover:bg-gray-900 dark:text-slate-400 dark:hover:text-slate-300")},m(x,k){N(x,e,k),v(e,n),v(n,t),v(t,r),v(n,i),v(n,l),v(e,c),a||(g=Te(n,"click",h),a=!0)},p(x,k){o=x,k&2&&s!==(s=o[3].question+"")&&De(l,s)},d(x){x&&B(e),a=!1,g()}}}function Po(o){let e,n,t,r,i,s,l,c,a,g,h,x,k,q,M,y,p,m,w=o[0].show_training_data&&Qn(),D=Le(o[1]),P=[];for(let C=0;C<D.length;C+=1)P[C]=Fn(Wn(o,D,C));return{c(){e=E("div"),n=E("nav"),t=E("div"),r=E("img"),s=Q(),l=E("div"),l.innerHTML='<button type="button" class="w-8 h-8 inline-flex justify-center items-center gap-2 rounded-md text-gray-700 align-middle focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-offset-white focus:ring-blue-600 transition-all dark:text-gray-400 dark:focus:ring-offset-gray-800" data-hs-overlay="#application-sidebar" aria-controls="application-sidebar" aria-label="Toggle navigation"><svg class="w-4 h-4" width="16" height="16" fill="currentColor" viewBox="0 0 16 16"><path d="M2.146 2.854a.5.5 0 1 1 .708-.708L8 7.293l5.146-5.147a.5.5 0 0 1 .708.708L8.707 8l5.147 5.146a.5.5 0 0 1-.708.708L8 8.707l-5.146 5.147a.5.5 0 0 1-.708-.708L7.293 8 2.146 2.854Z"></path></svg> <span class="sr-only">Sidebar</span></button>',c=Q(),a=E("div"),g=E("ul"),w&&w.c(),h=Q(),x=E("li"),k=E("button"),k.innerHTML=`<svg class="w-3.5 h-3.5" xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" viewBox="0 0 16 16"><path fill-rule="evenodd" clip-rule="evenodd" d="M8 2C8.47339 2 8.85714 2.38376 8.85714 2.85714V7.14286L13.1429 7.14286C13.6162 7.14286 14 7.52661 14 8C14 8.47339 13.6162 8.85714 13.1429 8.85714L8.85714 8.85715V13.1429C8.85714 13.6162 8.47339 14 8 14C7.52661 14 7.14286 13.6162 7.14286 13.1429V8.85715L2.85714 8.85715C2.38376 8.85715 2 8.4734 2 8.00001C2 7.52662 2.38376 7.14287 2.85714 7.14287L7.14286 7.14286V2.85714C7.14286 2.38376 7.52661 2 8 2Z" fill="currentColor"></path></svg>
              New question`,q=Q();for(let C=0;C<P.length;C+=1)P[C].c();M=Q(),y=E("div"),y.innerHTML=`<div class="py-2.5 px-7"><p class="inline-flex items-center gap-x-2 text-xs text-green-600"><span class="block w-1.5 h-1.5 rounded-full bg-green-600"></span>
            Connected</p></div> <div class="p-4 border-t border-gray-200 dark:border-gray-700"><a class="flex justify-between items-center gap-x-3 py-2 px-3 text-sm text-slate-700 rounded-md hover:bg-gray-100 dark:hover:bg-gray-900 dark:text-slate-400 dark:hover:text-slate-300" href="/auth/logout">Sign out
            <svg class="w-3.5 h-3.5" xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" viewBox="0 0 16 16"><path fill-rule="evenodd" d="M10 3.5a.5.5 0 0 0-.5-.5h-8a.5.5 0 0 0-.5.5v9a.5.5 0 0 0 .5.5h8a.5.5 0 0 0 .5-.5v-2a.5.5 0 0 1 1 0v2A1.5 1.5 0 0 1 9.5 14h-8A1.5 1.5 0 0 1 0 12.5v-9A1.5 1.5 0 0 1 1.5 2h8A1.5 1.5 0 0 1 11 3.5v2a.5.5 0 0 1-1 0v-2z"></path><path fill-rule="evenodd" d="M4.146 8.354a.5.5 0 0 1 0-.708l3-3a.5.5 0 1 1 .708.708L5.707 7.5H14.5a.5.5 0 0 1 0 1H5.707l2.147 2.146a.5.5 0 0 1-.708.708l-3-3z"></path></svg></a></div>`,d(r,"class","w-28 h-auto"),Zn(r.src,i=o[0].logo)||d(r,"src",i),d(r,"alt","Vanna Logo"),d(l,"class","lg:hidden"),d(t,"class","flex items-center justify-between py-4 pr-4 pl-7"),d(k,"class","flex items-center gap-x-3 py-2 px-3 text-sm text-slate-700 rounded-md hover:bg-gray-100 dark:hover:bg-gray-900 dark:text-slate-400 dark:hover:text-slate-300"),d(g,"class","space-y-1.5 p-4"),d(a,"class","h-full"),d(y,"class","mt-auto"),d(n,"class","hs-accordion-group w-full h-full flex flex-col"),d(n,"data-hs-accordion-always-open",""),d(e,"id","application-sidebar"),d(e,"class","hs-overlay hs-overlay-open:translate-x-0 -translate-x-full transition-all duration-300 transform hidden fixed top-0 left-0 bottom-0 z-[60] w-64 bg-white border-r border-gray-200 overflow-y-auto scrollbar-y lg:block lg:translate-x-0 lg:right-auto lg:bottom-0 dark:scrollbar-y dark:bg-slate-900 dark:border-gray-700")},m(C,f){N(C,e,f),v(e,n),v(n,t),v(t,r),v(t,s),v(t,l),v(n,c),v(n,a),v(a,g),w&&w.m(g,null),v(g,h),v(g,x),v(x,k),v(g,q);for(let u=0;u<P.length;u+=1)P[u]&&P[u].m(g,null);v(n,M),v(n,y),p||(m=Te(k,"click",zr),p=!0)},p(C,[f]){if(f&1&&!Zn(r.src,i=C[0].logo)&&d(r,"src",i),C[0].show_training_data?w||(w=Qn(),w.c(),w.m(g,h)):w&&(w.d(1),w=null),f&2){D=Le(C[1]);let u;for(u=0;u<D.length;u+=1){const _=Wn(C,D,u);P[u]?P[u].p(_,f):(P[u]=Fn(_),P[u].c(),P[u].m(g,null))}for(;u<P.length;u+=1)P[u].d(1);P.length=D.length}},i:Y,o:Y,d(C){C&&B(e),w&&w.d(),nt(P,C),p=!1,m()}}}function qo(o,e,n){let t,r;return et(o,Ot,s=>n(0,t=s)),et(o,Cn,s=>n(1,r=s)),[t,r,s=>{bo(s.id)}]}class Ao extends ve{constructor(e){super(),be(this,e,qo,Po,he,{})}}var Mo={exports:{}};/*! For license information please see preline.js.LICENSE.txt */(function(o,e){(function(n,t){o.exports=t()})(self,function(){return(()=>{var n={661:(s,l,c)=>{function a(M){return a=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(y){return typeof y}:function(y){return y&&typeof Symbol=="function"&&y.constructor===Symbol&&y!==Symbol.prototype?"symbol":typeof y},a(M)}function g(M,y){for(var p=0;p<y.length;p++){var m=y[p];m.enumerable=m.enumerable||!1,m.configurable=!0,"value"in m&&(m.writable=!0),Object.defineProperty(M,m.key,m)}}function h(M,y){return h=Object.setPrototypeOf||function(p,m){return p.__proto__=m,p},h(M,y)}function x(M,y){if(y&&(a(y)==="object"||typeof y=="function"))return y;if(y!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return function(p){if(p===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return p}(M)}function k(M){return k=Object.setPrototypeOf?Object.getPrototypeOf:function(y){return y.__proto__||Object.getPrototypeOf(y)},k(M)}var q=function(M){(function(C,f){if(typeof f!="function"&&f!==null)throw new TypeError("Super expression must either be null or a function");C.prototype=Object.create(f&&f.prototype,{constructor:{value:C,writable:!0,configurable:!0}}),Object.defineProperty(C,"prototype",{writable:!1}),f&&h(C,f)})(P,M);var y,p,m,w,D=(m=P,w=function(){if(typeof Reflect>"u"||!Reflect.construct||Reflect.construct.sham)return!1;if(typeof Proxy=="function")return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){})),!0}catch{return!1}}(),function(){var C,f=k(m);if(w){var u=k(this).constructor;C=Reflect.construct(f,arguments,u)}else C=f.apply(this,arguments);return x(this,C)});function P(){return function(C,f){if(!(C instanceof f))throw new TypeError("Cannot call a class as a function")}(this,P),D.call(this,".hs-accordion")}return y=P,(p=[{key:"init",value:function(){var C=this;document.addEventListener("click",function(f){var u=f.target,_=u.closest(C.selector),j=u.closest(".hs-accordion-toggle"),O=u.closest(".hs-accordion-group");_&&O&&j&&(C._hideAll(_),C.show(_))})}},{key:"show",value:function(C){var f=this;if(C.classList.contains("active"))return this.hide(C);C.classList.add("active");var u=C.querySelector(".hs-accordion-content");u.style.display="block",u.style.height=0,setTimeout(function(){u.style.height="".concat(u.scrollHeight,"px")}),this.afterTransition(u,function(){C.classList.contains("active")&&(u.style.height="",f._fireEvent("open",C),f._dispatch("open.hs.accordion",C,C))})}},{key:"hide",value:function(C){var f=this,u=C.querySelector(".hs-accordion-content");u.style.height="".concat(u.scrollHeight,"px"),setTimeout(function(){u.style.height=0}),this.afterTransition(u,function(){C.classList.contains("active")||(u.style.display="",f._fireEvent("hide",C),f._dispatch("hide.hs.accordion",C,C))}),C.classList.remove("active")}},{key:"_hideAll",value:function(C){var f=this,u=C.closest(".hs-accordion-group");u.hasAttribute("data-hs-accordion-always-open")||u.querySelectorAll(this.selector).forEach(function(_){C!==_&&f.hide(_)})}}])&&g(y.prototype,p),Object.defineProperty(y,"prototype",{writable:!1}),P}(c(765).Z);window.HSAccordion=new q,document.addEventListener("load",window.HSAccordion.init())},795:(s,l,c)=>{function a(y){return a=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(p){return typeof p}:function(p){return p&&typeof Symbol=="function"&&p.constructor===Symbol&&p!==Symbol.prototype?"symbol":typeof p},a(y)}function g(y,p){(p==null||p>y.length)&&(p=y.length);for(var m=0,w=new Array(p);m<p;m++)w[m]=y[m];return w}function h(y,p){for(var m=0;m<p.length;m++){var w=p[m];w.enumerable=w.enumerable||!1,w.configurable=!0,"value"in w&&(w.writable=!0),Object.defineProperty(y,w.key,w)}}function x(y,p){return x=Object.setPrototypeOf||function(m,w){return m.__proto__=w,m},x(y,p)}function k(y,p){if(p&&(a(p)==="object"||typeof p=="function"))return p;if(p!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return function(m){if(m===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return m}(y)}function q(y){return q=Object.setPrototypeOf?Object.getPrototypeOf:function(p){return p.__proto__||Object.getPrototypeOf(p)},q(y)}var M=function(y){(function(f,u){if(typeof u!="function"&&u!==null)throw new TypeError("Super expression must either be null or a function");f.prototype=Object.create(u&&u.prototype,{constructor:{value:f,writable:!0,configurable:!0}}),Object.defineProperty(f,"prototype",{writable:!1}),u&&x(f,u)})(C,y);var p,m,w,D,P=(w=C,D=function(){if(typeof Reflect>"u"||!Reflect.construct||Reflect.construct.sham)return!1;if(typeof Proxy=="function")return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){})),!0}catch{return!1}}(),function(){var f,u=q(w);if(D){var _=q(this).constructor;f=Reflect.construct(u,arguments,_)}else f=u.apply(this,arguments);return k(this,f)});function C(){return function(f,u){if(!(f instanceof u))throw new TypeError("Cannot call a class as a function")}(this,C),P.call(this,"[data-hs-collapse]")}return p=C,(m=[{key:"init",value:function(){var f=this;document.addEventListener("click",function(u){var _=u.target.closest(f.selector);if(_){var j=document.querySelectorAll(_.getAttribute("data-hs-collapse"));f.toggle(j)}})}},{key:"toggle",value:function(f){var u,_=this;f.length&&(u=f,function(j){if(Array.isArray(j))return g(j)}(u)||function(j){if(typeof Symbol<"u"&&j[Symbol.iterator]!=null||j["@@iterator"]!=null)return Array.from(j)}(u)||function(j,O){if(j){if(typeof j=="string")return g(j,O);var T=Object.prototype.toString.call(j).slice(8,-1);return T==="Object"&&j.constructor&&(T=j.constructor.name),T==="Map"||T==="Set"?Array.from(j):T==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(T)?g(j,O):void 0}}(u)||function(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}()).forEach(function(j){j.classList.contains("hidden")?_.show(j):_.hide(j)})}},{key:"show",value:function(f){var u=this;f.classList.add("open"),f.classList.remove("hidden"),f.style.height=0,document.querySelectorAll(this.selector).forEach(function(_){f.closest(_.getAttribute("data-hs-collapse"))&&_.classList.add("open")}),f.style.height="".concat(f.scrollHeight,"px"),this.afterTransition(f,function(){f.classList.contains("open")&&(f.style.height="",u._fireEvent("open",f),u._dispatch("open.hs.collapse",f,f))})}},{key:"hide",value:function(f){var u=this;f.style.height="".concat(f.scrollHeight,"px"),setTimeout(function(){f.style.height=0}),f.classList.remove("open"),this.afterTransition(f,function(){f.classList.contains("open")||(f.classList.add("hidden"),f.style.height=null,u._fireEvent("hide",f),u._dispatch("hide.hs.collapse",f,f),f.querySelectorAll(".hs-mega-menu-content.block").forEach(function(_){_.classList.remove("block"),_.classList.add("hidden")}))}),document.querySelectorAll(this.selector).forEach(function(_){f.closest(_.getAttribute("data-hs-collapse"))&&_.classList.remove("open")})}}])&&h(p.prototype,m),Object.defineProperty(p,"prototype",{writable:!1}),C}(c(765).Z);window.HSCollapse=new M,document.addEventListener("load",window.HSCollapse.init())},682:(s,l,c)=>{var a=c(714),g=c(765);const h={historyIndex:-1,addHistory:function(D){this.historyIndex=D},existsInHistory:function(D){return D>this.historyIndex},clearHistory:function(){this.historyIndex=-1}};function x(D){return x=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(P){return typeof P}:function(P){return P&&typeof Symbol=="function"&&P.constructor===Symbol&&P!==Symbol.prototype?"symbol":typeof P},x(D)}function k(D){return function(P){if(Array.isArray(P))return q(P)}(D)||function(P){if(typeof Symbol<"u"&&P[Symbol.iterator]!=null||P["@@iterator"]!=null)return Array.from(P)}(D)||function(P,C){if(P){if(typeof P=="string")return q(P,C);var f=Object.prototype.toString.call(P).slice(8,-1);return f==="Object"&&P.constructor&&(f=P.constructor.name),f==="Map"||f==="Set"?Array.from(P):f==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(f)?q(P,C):void 0}}(D)||function(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}()}function q(D,P){(P==null||P>D.length)&&(P=D.length);for(var C=0,f=new Array(P);C<P;C++)f[C]=D[C];return f}function M(D,P){for(var C=0;C<P.length;C++){var f=P[C];f.enumerable=f.enumerable||!1,f.configurable=!0,"value"in f&&(f.writable=!0),Object.defineProperty(D,f.key,f)}}function y(D,P){return y=Object.setPrototypeOf||function(C,f){return C.__proto__=f,C},y(D,P)}function p(D,P){if(P&&(x(P)==="object"||typeof P=="function"))return P;if(P!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return function(C){if(C===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return C}(D)}function m(D){return m=Object.setPrototypeOf?Object.getPrototypeOf:function(P){return P.__proto__||Object.getPrototypeOf(P)},m(D)}var w=function(D){(function(O,T){if(typeof T!="function"&&T!==null)throw new TypeError("Super expression must either be null or a function");O.prototype=Object.create(T&&T.prototype,{constructor:{value:O,writable:!0,configurable:!0}}),Object.defineProperty(O,"prototype",{writable:!1}),T&&y(O,T)})(j,D);var P,C,f,u,_=(f=j,u=function(){if(typeof Reflect>"u"||!Reflect.construct||Reflect.construct.sham)return!1;if(typeof Proxy=="function")return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){})),!0}catch{return!1}}(),function(){var O,T=m(f);if(u){var H=m(this).constructor;O=Reflect.construct(T,arguments,H)}else O=T.apply(this,arguments);return p(this,O)});function j(){var O;return function(T,H){if(!(T instanceof H))throw new TypeError("Cannot call a class as a function")}(this,j),(O=_.call(this,".hs-dropdown")).positions={top:"top","top-left":"top-start","top-right":"top-end",bottom:"bottom","bottom-left":"bottom-start","bottom-right":"bottom-end",right:"right","right-top":"right-start","right-bottom":"right-end",left:"left","left-top":"left-start","left-bottom":"left-end"},O.absoluteStrategyModifiers=function(T){return[{name:"applyStyles",fn:function(H){var I=(window.getComputedStyle(T).getPropertyValue("--strategy")||"absolute").replace(" ",""),F=(window.getComputedStyle(T).getPropertyValue("--adaptive")||"adaptive").replace(" ","");H.state.elements.popper.style.position=I,H.state.elements.popper.style.transform=F==="adaptive"?H.state.styles.popper.transform:null,H.state.elements.popper.style.top=null,H.state.elements.popper.style.bottom=null,H.state.elements.popper.style.left=null,H.state.elements.popper.style.right=null,H.state.elements.popper.style.margin=0}},{name:"computeStyles",options:{adaptive:!1}}]},O._history=h,O}return P=j,C=[{key:"init",value:function(){var O=this;document.addEventListener("click",function(T){var H=T.target,I=H.closest(O.selector),F=H.closest(".hs-dropdown-menu");if(I&&I.classList.contains("open")||O._closeOthers(I),F){var J=(window.getComputedStyle(I).getPropertyValue("--auto-close")||"").replace(" ","");if((J=="false"||J=="inside")&&!I.parentElement.closest(O.selector))return}I&&(I.classList.contains("open")?O.close(I):O.open(I))}),document.addEventListener("mousemove",function(T){var H=T.target,I=H.closest(O.selector);if(H.closest(".hs-dropdown-menu"),I){var F=(window.getComputedStyle(I).getPropertyValue("--trigger")||"click").replace(" ","");if(F!=="hover")return;I&&I.classList.contains("open")||O._closeOthers(I),F!=="hover"||I.classList.contains("open")||/iPad|iPhone|iPod/.test(navigator.platform)||navigator.maxTouchPoints&&navigator.maxTouchPoints>2&&/MacIntel/.test(navigator.platform)||navigator.maxTouchPoints&&navigator.maxTouchPoints>2&&/MacIntel/.test(navigator.platform)||O._hover(H)}}),document.addEventListener("keydown",this._keyboardSupport.bind(this)),window.addEventListener("resize",function(){document.querySelectorAll(".hs-dropdown.open").forEach(function(T){O.close(T,!0)})})}},{key:"_closeOthers",value:function(){var O=this,T=arguments.length>0&&arguments[0]!==void 0?arguments[0]:null,H=document.querySelectorAll("".concat(this.selector,".open"));H.forEach(function(I){if(!T||T.closest(".hs-dropdown.open")!==I){var F=(window.getComputedStyle(I).getPropertyValue("--auto-close")||"").replace(" ","");F!="false"&&F!="outside"&&O.close(I)}})}},{key:"_hover",value:function(O){var T=this,H=O.closest(this.selector);this.open(H),document.addEventListener("mousemove",function I(F){F.target.closest(T.selector)&&F.target.closest(T.selector)!==H.parentElement.closest(T.selector)||(T.close(H),document.removeEventListener("mousemove",I,!0))},!0)}},{key:"close",value:function(O){var T=this,H=arguments.length>1&&arguments[1]!==void 0&&arguments[1],I=O.querySelector(".hs-dropdown-menu"),F=function(){O.classList.contains("open")||(I.classList.remove("block"),I.classList.add("hidden"),I.style.inset=null,I.style.position=null,O._popper&&O._popper.destroy())};H||this.afterTransition(O.querySelector("[data-hs-dropdown-transition]")||I,function(){F()}),I.style.margin=null,O.classList.remove("open"),H&&F(),this._fireEvent("close",O),this._dispatch("close.hs.dropdown",O,O);var J=I.querySelectorAll(".hs-dropdown.open");J.forEach(function(Ce){T.close(Ce,!0)})}},{key:"open",value:function(O){var T=O.querySelector(".hs-dropdown-menu"),H=(window.getComputedStyle(O).getPropertyValue("--placement")||"").replace(" ",""),I=(window.getComputedStyle(O).getPropertyValue("--strategy")||"fixed").replace(" ",""),F=((window.getComputedStyle(O).getPropertyValue("--adaptive")||"adaptive").replace(" ",""),parseInt((window.getComputedStyle(O).getPropertyValue("--offset")||"10").replace(" ","")));if(I!=="static"){O._popper&&O._popper.destroy();var J=(0,a.fi)(O,T,{placement:this.positions[H]||"bottom-start",strategy:I,modifiers:[].concat(k(I!=="fixed"?this.absoluteStrategyModifiers(O):[]),[{name:"offset",options:{offset:[0,F]}}])});O._popper=J}T.style.margin=null,T.classList.add("block"),T.classList.remove("hidden"),setTimeout(function(){O.classList.add("open")}),this._fireEvent("open",O),this._dispatch("open.hs.dropdown",O,O)}},{key:"_keyboardSupport",value:function(O){var T=document.querySelector(".hs-dropdown.open");if(T)return O.keyCode===27?(O.preventDefault(),this._esc(T)):O.keyCode===40?(O.preventDefault(),this._down(T)):O.keyCode===38?(O.preventDefault(),this._up(T)):O.keyCode===36?(O.preventDefault(),this._start(T)):O.keyCode===35?(O.preventDefault(),this._end(T)):void this._byChar(T,O.key)}},{key:"_esc",value:function(O){this.close(O)}},{key:"_up",value:function(O){var T=O.querySelector(".hs-dropdown-menu"),H=k(T.querySelectorAll("a")).reverse().filter(function(J){return!J.disabled}),I=T.querySelector("a:focus"),F=H.findIndex(function(J){return J===I});F+1<H.length&&F++,H[F].focus()}},{key:"_down",value:function(O){var T=O.querySelector(".hs-dropdown-menu"),H=k(T.querySelectorAll("a")).filter(function(J){return!J.disabled}),I=T.querySelector("a:focus"),F=H.findIndex(function(J){return J===I});F+1<H.length&&F++,H[F].focus()}},{key:"_start",value:function(O){var T=k(O.querySelector(".hs-dropdown-menu").querySelectorAll("a")).filter(function(H){return!H.disabled});T.length&&T[0].focus()}},{key:"_end",value:function(O){var T=k(O.querySelector(".hs-dropdown-menu").querySelectorAll("a")).reverse().filter(function(H){return!H.disabled});T.length&&T[0].focus()}},{key:"_byChar",value:function(O,T){var H=this,I=k(O.querySelector(".hs-dropdown-menu").querySelectorAll("a")),F=function(){return I.findIndex(function(Ce,ae){return Ce.innerText.toLowerCase().charAt(0)===T.toLowerCase()&&H._history.existsInHistory(ae)})},J=F();J===-1&&(this._history.clearHistory(),J=F()),J!==-1&&(I[J].focus(),this._history.addHistory(J))}},{key:"toggle",value:function(O){O.classList.contains("open")?this.close(O):this.open(O)}}],C&&M(P.prototype,C),Object.defineProperty(P,"prototype",{writable:!1}),j}(g.Z);window.HSDropdown=new w,document.addEventListener("load",window.HSDropdown.init())},284:(s,l,c)=>{function a(y){return a=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(p){return typeof p}:function(p){return p&&typeof Symbol=="function"&&p.constructor===Symbol&&p!==Symbol.prototype?"symbol":typeof p},a(y)}function g(y,p){(p==null||p>y.length)&&(p=y.length);for(var m=0,w=new Array(p);m<p;m++)w[m]=y[m];return w}function h(y,p){for(var m=0;m<p.length;m++){var w=p[m];w.enumerable=w.enumerable||!1,w.configurable=!0,"value"in w&&(w.writable=!0),Object.defineProperty(y,w.key,w)}}function x(y,p){return x=Object.setPrototypeOf||function(m,w){return m.__proto__=w,m},x(y,p)}function k(y,p){if(p&&(a(p)==="object"||typeof p=="function"))return p;if(p!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return function(m){if(m===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return m}(y)}function q(y){return q=Object.setPrototypeOf?Object.getPrototypeOf:function(p){return p.__proto__||Object.getPrototypeOf(p)},q(y)}var M=function(y){(function(f,u){if(typeof u!="function"&&u!==null)throw new TypeError("Super expression must either be null or a function");f.prototype=Object.create(u&&u.prototype,{constructor:{value:f,writable:!0,configurable:!0}}),Object.defineProperty(f,"prototype",{writable:!1}),u&&x(f,u)})(C,y);var p,m,w,D,P=(w=C,D=function(){if(typeof Reflect>"u"||!Reflect.construct||Reflect.construct.sham)return!1;if(typeof Proxy=="function")return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){})),!0}catch{return!1}}(),function(){var f,u=q(w);if(D){var _=q(this).constructor;f=Reflect.construct(u,arguments,_)}else f=u.apply(this,arguments);return k(this,f)});function C(){var f;return function(u,_){if(!(u instanceof _))throw new TypeError("Cannot call a class as a function")}(this,C),(f=P.call(this,"[data-hs-overlay]")).openNextOverlay=!1,f}return p=C,(m=[{key:"init",value:function(){var f=this;document.addEventListener("click",function(u){var _=u.target.closest(f.selector),j=u.target.closest("[data-hs-overlay-close]"),O=u.target.getAttribute("aria-overlay")==="true";return j?f.close(j.closest(".hs-overlay.open")):_?f.toggle(document.querySelector(_.getAttribute("data-hs-overlay"))):void(O&&f._onBackdropClick(u.target))}),document.addEventListener("keydown",function(u){if(u.keyCode===27){var _=document.querySelector(".hs-overlay.open");if(!_)return;setTimeout(function(){_.getAttribute("data-hs-overlay-keyboard")!=="false"&&f.close(_)})}})}},{key:"toggle",value:function(f){f&&(f.classList.contains("hidden")?this.open(f):this.close(f))}},{key:"open",value:function(f){var u=this;if(f){var _=document.querySelector(".hs-overlay.open"),j=this.getClassProperty(f,"--body-scroll","false")!=="true";if(_)return this.openNextOverlay=!0,this.close(_).then(function(){u.open(f),u.openNextOverlay=!1});j&&(document.body.style.overflow="hidden"),this._buildBackdrop(f),this._checkTimer(f),this._autoHide(f),f.classList.remove("hidden"),f.setAttribute("aria-overlay","true"),f.setAttribute("tabindex","-1"),setTimeout(function(){f.classList.contains("hidden")||(f.classList.add("open"),u._fireEvent("open",f),u._dispatch("open.hs.overlay",f,f),u._focusInput(f))},50)}}},{key:"close",value:function(f){var u=this;return new Promise(function(_){f&&(f.classList.remove("open"),f.removeAttribute("aria-overlay"),f.removeAttribute("tabindex","-1"),u.afterTransition(f,function(){f.classList.contains("open")||(f.classList.add("hidden"),u._destroyBackdrop(),u._fireEvent("close",f),u._dispatch("close.hs.overlay",f,f),document.body.style.overflow="",_(f))}))})}},{key:"_autoHide",value:function(f){var u=this,_=parseInt(this.getClassProperty(f,"--auto-hide","0"));_&&(f.autoHide=setTimeout(function(){u.close(f)},_))}},{key:"_checkTimer",value:function(f){f.autoHide&&(clearTimeout(f.autoHide),delete f.autoHide)}},{key:"_onBackdropClick",value:function(f){this.getClassProperty(f,"--overlay-backdrop","true")!=="static"&&this.close(f)}},{key:"_buildBackdrop",value:function(f){var u,_=this,j=f.getAttribute("data-hs-overlay-backdrop-container")||!1,O=document.createElement("div"),T="transition duration fixed inset-0 z-50 bg-gray-900 bg-opacity-50 dark:bg-opacity-80 hs-overlay-backdrop",H=function(J,Ce){var ae=typeof Symbol<"u"&&J[Symbol.iterator]||J["@@iterator"];if(!ae){if(Array.isArray(J)||(ae=function(_e,ft){if(_e){if(typeof _e=="string")return g(_e,ft);var We=Object.prototype.toString.call(_e).slice(8,-1);return We==="Object"&&_e.constructor&&(We=_e.constructor.name),We==="Map"||We==="Set"?Array.from(_e):We==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(We)?g(_e,ft):void 0}}(J))||Ce&&J&&typeof J.length=="number"){ae&&(J=ae);var ot=0,tt=function(){};return{s:tt,n:function(){return ot>=J.length?{done:!0}:{done:!1,value:J[ot++]}},e:function(_e){throw _e},f:tt}}throw new TypeError(`Invalid attempt to iterate non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}var Ge,Ue=!0,ht=!1;return{s:function(){ae=ae.call(J)},n:function(){var _e=ae.next();return Ue=_e.done,_e},e:function(_e){ht=!0,Ge=_e},f:function(){try{Ue||ae.return==null||ae.return()}finally{if(ht)throw Ge}}}}(f.classList.values());try{for(H.s();!(u=H.n()).done;){var I=u.value;I.startsWith("hs-overlay-backdrop-open:")&&(T+=" ".concat(I))}}catch(J){H.e(J)}finally{H.f()}var F=this.getClassProperty(f,"--overlay-backdrop","true")!=="static";this.getClassProperty(f,"--overlay-backdrop","true")==="false"||(j&&((O=document.querySelector(j).cloneNode(!0)).classList.remove("hidden"),T=O.classList,O.classList=""),F&&O.addEventListener("click",function(){return _.close(f)},!0),O.setAttribute("data-hs-overlay-backdrop-template",""),document.body.appendChild(O),setTimeout(function(){O.classList=T}))}},{key:"_destroyBackdrop",value:function(){var f=document.querySelector("[data-hs-overlay-backdrop-template]");f&&(this.openNextOverlay&&(f.style.transitionDuration="".concat(1.8*parseFloat(window.getComputedStyle(f).transitionDuration.replace(/[^\d.-]/g,"")),"s")),f.classList.add("opacity-0"),this.afterTransition(f,function(){f.remove()}))}},{key:"_focusInput",value:function(f){var u=f.querySelector("[autofocus]");u&&u.focus()}}])&&h(p.prototype,m),Object.defineProperty(p,"prototype",{writable:!1}),C}(c(765).Z);window.HSOverlay=new M,document.addEventListener("load",window.HSOverlay.init())},181:(s,l,c)=>{function a(M){return a=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(y){return typeof y}:function(y){return y&&typeof Symbol=="function"&&y.constructor===Symbol&&y!==Symbol.prototype?"symbol":typeof y},a(M)}function g(M,y){for(var p=0;p<y.length;p++){var m=y[p];m.enumerable=m.enumerable||!1,m.configurable=!0,"value"in m&&(m.writable=!0),Object.defineProperty(M,m.key,m)}}function h(M,y){return h=Object.setPrototypeOf||function(p,m){return p.__proto__=m,p},h(M,y)}function x(M,y){if(y&&(a(y)==="object"||typeof y=="function"))return y;if(y!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return function(p){if(p===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return p}(M)}function k(M){return k=Object.setPrototypeOf?Object.getPrototypeOf:function(y){return y.__proto__||Object.getPrototypeOf(y)},k(M)}var q=function(M){(function(C,f){if(typeof f!="function"&&f!==null)throw new TypeError("Super expression must either be null or a function");C.prototype=Object.create(f&&f.prototype,{constructor:{value:C,writable:!0,configurable:!0}}),Object.defineProperty(C,"prototype",{writable:!1}),f&&h(C,f)})(P,M);var y,p,m,w,D=(m=P,w=function(){if(typeof Reflect>"u"||!Reflect.construct||Reflect.construct.sham)return!1;if(typeof Proxy=="function")return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){})),!0}catch{return!1}}(),function(){var C,f=k(m);if(w){var u=k(this).constructor;C=Reflect.construct(f,arguments,u)}else C=f.apply(this,arguments);return x(this,C)});function P(){return function(C,f){if(!(C instanceof f))throw new TypeError("Cannot call a class as a function")}(this,P),D.call(this,"[data-hs-remove-element]")}return y=P,(p=[{key:"init",value:function(){var C=this;document.addEventListener("click",function(f){var u=f.target.closest(C.selector);if(u){var _=document.querySelector(u.getAttribute("data-hs-remove-element"));_&&(_.classList.add("hs-removing"),C.afterTransition(_,function(){_.remove()}))}})}}])&&g(y.prototype,p),Object.defineProperty(y,"prototype",{writable:!1}),P}(c(765).Z);window.HSRemoveElement=new q,document.addEventListener("load",window.HSRemoveElement.init())},778:(s,l,c)=>{function a(M){return a=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(y){return typeof y}:function(y){return y&&typeof Symbol=="function"&&y.constructor===Symbol&&y!==Symbol.prototype?"symbol":typeof y},a(M)}function g(M,y){for(var p=0;p<y.length;p++){var m=y[p];m.enumerable=m.enumerable||!1,m.configurable=!0,"value"in m&&(m.writable=!0),Object.defineProperty(M,m.key,m)}}function h(M,y){return h=Object.setPrototypeOf||function(p,m){return p.__proto__=m,p},h(M,y)}function x(M,y){if(y&&(a(y)==="object"||typeof y=="function"))return y;if(y!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return function(p){if(p===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return p}(M)}function k(M){return k=Object.setPrototypeOf?Object.getPrototypeOf:function(y){return y.__proto__||Object.getPrototypeOf(y)},k(M)}var q=function(M){(function(C,f){if(typeof f!="function"&&f!==null)throw new TypeError("Super expression must either be null or a function");C.prototype=Object.create(f&&f.prototype,{constructor:{value:C,writable:!0,configurable:!0}}),Object.defineProperty(C,"prototype",{writable:!1}),f&&h(C,f)})(P,M);var y,p,m,w,D=(m=P,w=function(){if(typeof Reflect>"u"||!Reflect.construct||Reflect.construct.sham)return!1;if(typeof Proxy=="function")return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){})),!0}catch{return!1}}(),function(){var C,f=k(m);if(w){var u=k(this).constructor;C=Reflect.construct(f,arguments,u)}else C=f.apply(this,arguments);return x(this,C)});function P(){var C;return function(f,u){if(!(f instanceof u))throw new TypeError("Cannot call a class as a function")}(this,P),(C=D.call(this,"[data-hs-scrollspy] ")).activeSection=null,C}return y=P,(p=[{key:"init",value:function(){var C=this;document.querySelectorAll(this.selector).forEach(function(f){var u=document.querySelector(f.getAttribute("data-hs-scrollspy")),_=f.querySelectorAll("[href]"),j=u.children,O=f.getAttribute("data-hs-scrollspy-scrollable-parent")?document.querySelector(f.getAttribute("data-hs-scrollspy-scrollable-parent")):document;Array.from(j).forEach(function(T){T.getAttribute("id")&&O.addEventListener("scroll",function(H){return C._update({$scrollspyEl:f,$scrollspyContentEl:u,links:_,$sectionEl:T,sections:j,ev:H})})}),_.forEach(function(T){T.addEventListener("click",function(H){H.preventDefault(),T.getAttribute("href")!=="javascript:;"&&C._scrollTo({$scrollspyEl:f,$scrollableEl:O,$link:T})})})})}},{key:"_update",value:function(C){var f=C.ev,u=C.$scrollspyEl,_=(C.sections,C.links),j=C.$sectionEl,O=parseInt(this.getClassProperty(u,"--scrollspy-offset","0")),T=this.getClassProperty(j,"--scrollspy-offset")||O,H=f.target===document?0:parseInt(f.target.getBoundingClientRect().top),I=parseInt(j.getBoundingClientRect().top)-T-H,F=j.offsetHeight;if(I<=0&&I+F>0){if(this.activeSection===j)return;_.forEach(function(ot){ot.classList.remove("active")});var J=u.querySelector('[href="#'.concat(j.getAttribute("id"),'"]'));if(J){J.classList.add("active");var Ce=J.closest("[data-hs-scrollspy-group]");if(Ce){var ae=Ce.querySelector("[href]");ae&&ae.classList.add("active")}}this.activeSection=j}}},{key:"_scrollTo",value:function(C){var f=C.$scrollspyEl,u=C.$scrollableEl,_=C.$link,j=document.querySelector(_.getAttribute("href")),O=parseInt(this.getClassProperty(f,"--scrollspy-offset","0")),T=this.getClassProperty(j,"--scrollspy-offset")||O,H=u===document?0:u.offsetTop,I=j.offsetTop-T-H,F=u===document?window:u;this._fireEvent("scroll",f),this._dispatch("scroll.hs.scrollspy",f,f),window.history.replaceState(null,null,_.getAttribute("href")),F.scrollTo({top:I,left:0,behavior:"smooth"})}}])&&g(y.prototype,p),Object.defineProperty(y,"prototype",{writable:!1}),P}(c(765).Z);window.HSScrollspy=new q,document.addEventListener("load",window.HSScrollspy.init())},51:(s,l,c)=>{function a(p){return a=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(m){return typeof m}:function(m){return m&&typeof Symbol=="function"&&m.constructor===Symbol&&m!==Symbol.prototype?"symbol":typeof m},a(p)}function g(p){return function(m){if(Array.isArray(m))return h(m)}(p)||function(m){if(typeof Symbol<"u"&&m[Symbol.iterator]!=null||m["@@iterator"]!=null)return Array.from(m)}(p)||function(m,w){if(m){if(typeof m=="string")return h(m,w);var D=Object.prototype.toString.call(m).slice(8,-1);return D==="Object"&&m.constructor&&(D=m.constructor.name),D==="Map"||D==="Set"?Array.from(m):D==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(D)?h(m,w):void 0}}(p)||function(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}()}function h(p,m){(m==null||m>p.length)&&(m=p.length);for(var w=0,D=new Array(m);w<m;w++)D[w]=p[w];return D}function x(p,m){for(var w=0;w<m.length;w++){var D=m[w];D.enumerable=D.enumerable||!1,D.configurable=!0,"value"in D&&(D.writable=!0),Object.defineProperty(p,D.key,D)}}function k(p,m){return k=Object.setPrototypeOf||function(w,D){return w.__proto__=D,w},k(p,m)}function q(p,m){if(m&&(a(m)==="object"||typeof m=="function"))return m;if(m!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return function(w){if(w===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return w}(p)}function M(p){return M=Object.setPrototypeOf?Object.getPrototypeOf:function(m){return m.__proto__||Object.getPrototypeOf(m)},M(p)}var y=function(p){(function(u,_){if(typeof _!="function"&&_!==null)throw new TypeError("Super expression must either be null or a function");u.prototype=Object.create(_&&_.prototype,{constructor:{value:u,writable:!0,configurable:!0}}),Object.defineProperty(u,"prototype",{writable:!1}),_&&k(u,_)})(f,p);var m,w,D,P,C=(D=f,P=function(){if(typeof Reflect>"u"||!Reflect.construct||Reflect.construct.sham)return!1;if(typeof Proxy=="function")return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){})),!0}catch{return!1}}(),function(){var u,_=M(D);if(P){var j=M(this).constructor;u=Reflect.construct(_,arguments,j)}else u=_.apply(this,arguments);return q(this,u)});function f(){return function(u,_){if(!(u instanceof _))throw new TypeError("Cannot call a class as a function")}(this,f),C.call(this,"[data-hs-tab]")}return m=f,(w=[{key:"init",value:function(){var u=this;document.addEventListener("keydown",this._keyboardSupport.bind(this)),document.addEventListener("click",function(_){var j=_.target.closest(u.selector);j&&u.open(j)}),document.querySelectorAll("[hs-data-tab-select]").forEach(function(_){var j=document.querySelector(_.getAttribute("hs-data-tab-select"));j&&j.addEventListener("change",function(O){var T=document.querySelector('[data-hs-tab="'.concat(O.target.value,'"]'));T&&u.open(T)})})}},{key:"open",value:function(u){var _=document.querySelector(u.getAttribute("data-hs-tab")),j=g(u.parentElement.children),O=g(_.parentElement.children),T=u.closest("[hs-data-tab-select]"),H=T?document.querySelector(T.getAttribute("data-hs-tab")):null;j.forEach(function(I){return I.classList.remove("active")}),O.forEach(function(I){return I.classList.add("hidden")}),u.classList.add("active"),_.classList.remove("hidden"),this._fireEvent("change",u),this._dispatch("change.hs.tab",u,u),H&&(H.value=u.getAttribute("data-hs-tab"))}},{key:"_keyboardSupport",value:function(u){var _=u.target.closest(this.selector);if(_){var j=_.closest('[role="tablist"]').getAttribute("data-hs-tabs-vertical")==="true";return(j?u.keyCode===38:u.keyCode===37)?(u.preventDefault(),this._left(_)):(j?u.keyCode===40:u.keyCode===39)?(u.preventDefault(),this._right(_)):u.keyCode===36?(u.preventDefault(),this._start(_)):u.keyCode===35?(u.preventDefault(),this._end(_)):void 0}}},{key:"_right",value:function(u){var _=u.closest('[role="tablist"]');if(_){var j=g(_.querySelectorAll(this.selector)).filter(function(H){return!H.disabled}),O=_.querySelector("button:focus"),T=j.findIndex(function(H){return H===O});T+1<j.length?T++:T=0,j[T].focus(),this.open(j[T])}}},{key:"_left",value:function(u){var _=u.closest('[role="tablist"]');if(_){var j=g(_.querySelectorAll(this.selector)).filter(function(H){return!H.disabled}).reverse(),O=_.querySelector("button:focus"),T=j.findIndex(function(H){return H===O});T+1<j.length?T++:T=0,j[T].focus(),this.open(j[T])}}},{key:"_start",value:function(u){var _=u.closest('[role="tablist"]');if(_){var j=g(_.querySelectorAll(this.selector)).filter(function(O){return!O.disabled});j.length&&(j[0].focus(),this.open(j[0]))}}},{key:"_end",value:function(u){var _=u.closest('[role="tablist"]');if(_){var j=g(_.querySelectorAll(this.selector)).reverse().filter(function(O){return!O.disabled});j.length&&(j[0].focus(),this.open(j[0]))}}}])&&x(m.prototype,w),Object.defineProperty(m,"prototype",{writable:!1}),f}(c(765).Z);window.HSTabs=new y,document.addEventListener("load",window.HSTabs.init())},185:(s,l,c)=>{var a=c(765),g=c(714);function h(p){return h=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(m){return typeof m}:function(m){return m&&typeof Symbol=="function"&&m.constructor===Symbol&&m!==Symbol.prototype?"symbol":typeof m},h(p)}function x(p,m){for(var w=0;w<m.length;w++){var D=m[w];D.enumerable=D.enumerable||!1,D.configurable=!0,"value"in D&&(D.writable=!0),Object.defineProperty(p,D.key,D)}}function k(p,m){return k=Object.setPrototypeOf||function(w,D){return w.__proto__=D,w},k(p,m)}function q(p,m){if(m&&(h(m)==="object"||typeof m=="function"))return m;if(m!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return function(w){if(w===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return w}(p)}function M(p){return M=Object.setPrototypeOf?Object.getPrototypeOf:function(m){return m.__proto__||Object.getPrototypeOf(m)},M(p)}var y=function(p){(function(u,_){if(typeof _!="function"&&_!==null)throw new TypeError("Super expression must either be null or a function");u.prototype=Object.create(_&&_.prototype,{constructor:{value:u,writable:!0,configurable:!0}}),Object.defineProperty(u,"prototype",{writable:!1}),_&&k(u,_)})(f,p);var m,w,D,P,C=(D=f,P=function(){if(typeof Reflect>"u"||!Reflect.construct||Reflect.construct.sham)return!1;if(typeof Proxy=="function")return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){})),!0}catch{return!1}}(),function(){var u,_=M(D);if(P){var j=M(this).constructor;u=Reflect.construct(_,arguments,j)}else u=_.apply(this,arguments);return q(this,u)});function f(){return function(u,_){if(!(u instanceof _))throw new TypeError("Cannot call a class as a function")}(this,f),C.call(this,".hs-tooltip")}return m=f,(w=[{key:"init",value:function(){var u=this;document.addEventListener("click",function(_){var j=_.target.closest(u.selector);j&&u.getClassProperty(j,"--trigger")==="focus"&&u._focus(j),j&&u.getClassProperty(j,"--trigger")==="click"&&u._click(j)}),document.addEventListener("mousemove",function(_){var j=_.target.closest(u.selector);j&&u.getClassProperty(j,"--trigger")!=="focus"&&u.getClassProperty(j,"--trigger")!=="click"&&u._hover(j)})}},{key:"_hover",value:function(u){var _=this;if(!u.classList.contains("show")){var j=u.querySelector(".hs-tooltip-toggle"),O=u.querySelector(".hs-tooltip-content"),T=this.getClassProperty(u,"--placement");(0,g.fi)(j,O,{placement:T||"top",strategy:"fixed",modifiers:[{name:"offset",options:{offset:[0,5]}}]}),this.show(u),u.addEventListener("mouseleave",function H(I){I.relatedTarget.closest(_.selector)&&I.relatedTarget.closest(_.selector)==u||(_.hide(u),u.removeEventListener("mouseleave",H,!0))},!0)}}},{key:"_focus",value:function(u){var _=this,j=u.querySelector(".hs-tooltip-toggle"),O=u.querySelector(".hs-tooltip-content"),T=this.getClassProperty(u,"--placement"),H=this.getClassProperty(u,"--strategy");(0,g.fi)(j,O,{placement:T||"top",strategy:H||"fixed",modifiers:[{name:"offset",options:{offset:[0,5]}}]}),this.show(u),u.addEventListener("blur",function I(){_.hide(u),u.removeEventListener("blur",I,!0)},!0)}},{key:"_click",value:function(u){var _=this;if(!u.classList.contains("show")){var j=u.querySelector(".hs-tooltip-toggle"),O=u.querySelector(".hs-tooltip-content"),T=this.getClassProperty(u,"--placement"),H=this.getClassProperty(u,"--strategy");(0,g.fi)(j,O,{placement:T||"top",strategy:H||"fixed",modifiers:[{name:"offset",options:{offset:[0,5]}}]}),this.show(u);var I=function F(J){setTimeout(function(){_.hide(u),u.removeEventListener("click",F,!0),u.removeEventListener("blur",F,!0)})};u.addEventListener("blur",I,!0),u.addEventListener("click",I,!0)}}},{key:"show",value:function(u){var _=this;u.querySelector(".hs-tooltip-content").classList.remove("hidden"),setTimeout(function(){u.classList.add("show"),_._fireEvent("show",u),_._dispatch("show.hs.tooltip",u,u)})}},{key:"hide",value:function(u){var _=u.querySelector(".hs-tooltip-content");u.classList.remove("show"),this._fireEvent("hide",u),this._dispatch("hide.hs.tooltip",u,u),this.afterTransition(_,function(){u.classList.contains("show")||_.classList.add("hidden")})}}])&&x(m.prototype,w),Object.defineProperty(m,"prototype",{writable:!1}),f}(a.Z);window.HSTooltip=new y,document.addEventListener("load",window.HSTooltip.init())},765:(s,l,c)=>{function a(h,x){for(var k=0;k<x.length;k++){var q=x[k];q.enumerable=q.enumerable||!1,q.configurable=!0,"value"in q&&(q.writable=!0),Object.defineProperty(h,q.key,q)}}c.d(l,{Z:()=>g});var g=function(){function h(q,M){(function(y,p){if(!(y instanceof p))throw new TypeError("Cannot call a class as a function")})(this,h),this.$collection=[],this.selector=q,this.config=M,this.events={}}var x,k;return x=h,k=[{key:"_fireEvent",value:function(q){var M=arguments.length>1&&arguments[1]!==void 0?arguments[1]:null;this.events.hasOwnProperty(q)&&this.events[q](M)}},{key:"_dispatch",value:function(q,M){var y=arguments.length>2&&arguments[2]!==void 0?arguments[2]:null,p=new CustomEvent(q,{detail:{payload:y},bubbles:!0,cancelable:!0,composed:!1});M.dispatchEvent(p)}},{key:"on",value:function(q,M){this.events[q]=M}},{key:"afterTransition",value:function(q,M){window.getComputedStyle(q,null).getPropertyValue("transition")!=="all 0s ease 0s"?q.addEventListener("transitionend",function y(){M(),q.removeEventListener("transitionend",y,!0)},!0):M()}},{key:"getClassProperty",value:function(q,M){var y=arguments.length>2&&arguments[2]!==void 0?arguments[2]:"",p=(window.getComputedStyle(q).getPropertyValue(M)||y).replace(" ","");return p}}],k&&a(x.prototype,k),Object.defineProperty(x,"prototype",{writable:!1}),h}()},714:(s,l,c)=>{function a($){if($==null)return window;if($.toString()!=="[object Window]"){var b=$.ownerDocument;return b&&b.defaultView||window}return $}function g($){return $ instanceof a($).Element||$ instanceof Element}function h($){return $ instanceof a($).HTMLElement||$ instanceof HTMLElement}function x($){return typeof ShadowRoot<"u"&&($ instanceof a($).ShadowRoot||$ instanceof ShadowRoot)}c.d(l,{fi:()=>Fr});var k=Math.max,q=Math.min,M=Math.round;function y($,b){b===void 0&&(b=!1);var S=$.getBoundingClientRect(),R=1,W=1;if(h($)&&b){var z=$.offsetHeight,V=$.offsetWidth;V>0&&(R=M(S.width)/V||1),z>0&&(W=M(S.height)/z||1)}return{width:S.width/R,height:S.height/W,top:S.top/W,right:S.right/R,bottom:S.bottom/W,left:S.left/R,x:S.left/R,y:S.top/W}}function p($){var b=a($);return{scrollLeft:b.pageXOffset,scrollTop:b.pageYOffset}}function m($){return $?($.nodeName||"").toLowerCase():null}function w($){return((g($)?$.ownerDocument:$.document)||window.document).documentElement}function D($){return y(w($)).left+p($).scrollLeft}function P($){return a($).getComputedStyle($)}function C($){var b=P($),S=b.overflow,R=b.overflowX,W=b.overflowY;return/auto|scroll|overlay|hidden/.test(S+W+R)}function f($,b,S){S===void 0&&(S=!1);var R,W,z=h(b),V=h(b)&&function(te){var Ae=te.getBoundingClientRect(),se=M(Ae.width)/te.offsetWidth||1,ye=M(Ae.height)/te.offsetHeight||1;return se!==1||ye!==1}(b),K=w(b),X=y($,V),ne={scrollLeft:0,scrollTop:0},re={x:0,y:0};return(z||!z&&!S)&&((m(b)!=="body"||C(K))&&(ne=(R=b)!==a(R)&&h(R)?{scrollLeft:(W=R).scrollLeft,scrollTop:W.scrollTop}:p(R)),h(b)?((re=y(b,!0)).x+=b.clientLeft,re.y+=b.clientTop):K&&(re.x=D(K))),{x:X.left+ne.scrollLeft-re.x,y:X.top+ne.scrollTop-re.y,width:X.width,height:X.height}}function u($){var b=y($),S=$.offsetWidth,R=$.offsetHeight;return Math.abs(b.width-S)<=1&&(S=b.width),Math.abs(b.height-R)<=1&&(R=b.height),{x:$.offsetLeft,y:$.offsetTop,width:S,height:R}}function _($){return m($)==="html"?$:$.assignedSlot||$.parentNode||(x($)?$.host:null)||w($)}function j($){return["html","body","#document"].indexOf(m($))>=0?$.ownerDocument.body:h($)&&C($)?$:j(_($))}function O($,b){var S;b===void 0&&(b=[]);var R=j($),W=R===((S=$.ownerDocument)==null?void 0:S.body),z=a(R),V=W?[z].concat(z.visualViewport||[],C(R)?R:[]):R,K=b.concat(V);return W?K:K.concat(O(_(V)))}function T($){return["table","td","th"].indexOf(m($))>=0}function H($){return h($)&&P($).position!=="fixed"?$.offsetParent:null}function I($){for(var b=a($),S=H($);S&&T(S)&&P(S).position==="static";)S=H(S);return S&&(m(S)==="html"||m(S)==="body"&&P(S).position==="static")?b:S||function(R){var W=navigator.userAgent.toLowerCase().indexOf("firefox")!==-1;if(navigator.userAgent.indexOf("Trident")!==-1&&h(R)&&P(R).position==="fixed")return null;for(var z=_(R);h(z)&&["html","body"].indexOf(m(z))<0;){var V=P(z);if(V.transform!=="none"||V.perspective!=="none"||V.contain==="paint"||["transform","perspective"].indexOf(V.willChange)!==-1||W&&V.willChange==="filter"||W&&V.filter&&V.filter!=="none")return z;z=z.parentNode}return null}($)||b}var F="top",J="bottom",Ce="right",ae="left",ot="auto",tt=[F,J,Ce,ae],Ge="start",Ue="end",ht="viewport",_e="popper",ft=tt.reduce(function($,b){return $.concat([b+"-"+Ge,b+"-"+Ue])},[]),We=[].concat(tt,[ot]).reduce(function($,b){return $.concat([b,b+"-"+Ge,b+"-"+Ue])},[]),yt=["beforeRead","read","afterRead","beforeMain","main","afterMain","beforeWrite","write","afterWrite"];function Nt($){var b=new Map,S=new Set,R=[];function W(z){S.add(z.name),[].concat(z.requires||[],z.requiresIfExists||[]).forEach(function(V){if(!S.has(V)){var K=b.get(V);K&&W(K)}}),R.push(z)}return $.forEach(function(z){b.set(z.name,z)}),$.forEach(function(z){S.has(z.name)||W(z)}),R}var It={placement:"bottom",modifiers:[],strategy:"absolute"};function qe(){for(var $=arguments.length,b=new Array($),S=0;S<$;S++)b[S]=arguments[S];return!b.some(function(R){return!(R&&typeof R.getBoundingClientRect=="function")})}function bt($){$===void 0&&($={});var b=$,S=b.defaultModifiers,R=S===void 0?[]:S,W=b.defaultOptions,z=W===void 0?It:W;return function(V,K,X){X===void 0&&(X=z);var ne,re,te={placement:"bottom",orderedModifiers:[],options:Object.assign({},It,z),modifiersData:{},elements:{reference:V,popper:K},attributes:{},styles:{}},Ae=[],se=!1,ye={state:te,setOptions:function(ie){var Me=typeof ie=="function"?ie(te.options):ie;ge(),te.options=Object.assign({},z,te.options,Me),te.scrollParents={reference:g(V)?O(V):V.contextElement?O(V.contextElement):[],popper:O(K)};var ke,fe,we=function(le){var ce=Nt(le);return yt.reduce(function(de,me){return de.concat(ce.filter(function($e){return $e.phase===me}))},[])}((ke=[].concat(R,te.options.modifiers),fe=ke.reduce(function(le,ce){var de=le[ce.name];return le[ce.name]=de?Object.assign({},de,ce,{options:Object.assign({},de.options,ce.options),data:Object.assign({},de.data,ce.data)}):ce,le},{}),Object.keys(fe).map(function(le){return fe[le]})));return te.orderedModifiers=we.filter(function(le){return le.enabled}),te.orderedModifiers.forEach(function(le){var ce=le.name,de=le.options,me=de===void 0?{}:de,$e=le.effect;if(typeof $e=="function"){var Ne=$e({state:te,name:ce,instance:ye,options:me});Ae.push(Ne||function(){})}}),ye.update()},forceUpdate:function(){if(!se){var ie=te.elements,Me=ie.reference,ke=ie.popper;if(qe(Me,ke)){te.rects={reference:f(Me,I(ke),te.options.strategy==="fixed"),popper:u(ke)},te.reset=!1,te.placement=te.options.placement,te.orderedModifiers.forEach(function($e){return te.modifiersData[$e.name]=Object.assign({},$e.data)});for(var fe=0;fe<te.orderedModifiers.length;fe++)if(te.reset!==!0){var we=te.orderedModifiers[fe],le=we.fn,ce=we.options,de=ce===void 0?{}:ce,me=we.name;typeof le=="function"&&(te=le({state:te,options:de,name:me,instance:ye})||te)}else te.reset=!1,fe=-1}}},update:(ne=function(){return new Promise(function(ie){ye.forceUpdate(),ie(te)})},function(){return re||(re=new Promise(function(ie){Promise.resolve().then(function(){re=void 0,ie(ne())})})),re}),destroy:function(){ge(),se=!0}};if(!qe(V,K))return ye;function ge(){Ae.forEach(function(ie){return ie()}),Ae=[]}return ye.setOptions(X).then(function(ie){!se&&X.onFirstUpdate&&X.onFirstUpdate(ie)}),ye}}var Re={passive:!0};function ze($){return $.split("-")[0]}function je($){return $.split("-")[1]}function Pe($){return["top","bottom"].indexOf($)>=0?"x":"y"}function ee($){var b,S=$.reference,R=$.element,W=$.placement,z=W?ze(W):null,V=W?je(W):null,K=S.x+S.width/2-R.width/2,X=S.y+S.height/2-R.height/2;switch(z){case F:b={x:K,y:S.y-R.height};break;case J:b={x:K,y:S.y+S.height};break;case Ce:b={x:S.x+S.width,y:X};break;case ae:b={x:S.x-R.width,y:X};break;default:b={x:S.x,y:S.y}}var ne=z?Pe(z):null;if(ne!=null){var re=ne==="y"?"height":"width";switch(V){case Ge:b[ne]=b[ne]-(S[re]/2-R[re]/2);break;case Ue:b[ne]=b[ne]+(S[re]/2-R[re]/2)}}return b}var Be={top:"auto",right:"auto",bottom:"auto",left:"auto"};function oe($){var b,S=$.popper,R=$.popperRect,W=$.placement,z=$.variation,V=$.offsets,K=$.position,X=$.gpuAcceleration,ne=$.adaptive,re=$.roundOffsets,te=$.isFixed,Ae=V.x,se=Ae===void 0?0:Ae,ye=V.y,ge=ye===void 0?0:ye,ie=typeof re=="function"?re({x:se,y:ge}):{x:se,y:ge};se=ie.x,ge=ie.y;var Me=V.hasOwnProperty("x"),ke=V.hasOwnProperty("y"),fe=ae,we=F,le=window;if(ne){var ce=I(S),de="clientHeight",me="clientWidth";ce===a(S)&&P(ce=w(S)).position!=="static"&&K==="absolute"&&(de="scrollHeight",me="scrollWidth"),ce=ce,(W===F||(W===ae||W===Ce)&&z===Ue)&&(we=J,ge-=(te&&le.visualViewport?le.visualViewport.height:ce[de])-R.height,ge*=X?1:-1),W!==ae&&(W!==F&&W!==J||z!==Ue)||(fe=Ce,se-=(te&&le.visualViewport?le.visualViewport.width:ce[me])-R.width,se*=X?1:-1)}var $e,Ne=Object.assign({position:K},ne&&Be),Ie=re===!0?function(Je){var it=Je.x,dt=Je.y,Ye=window.devicePixelRatio||1;return{x:M(it*Ye)/Ye||0,y:M(dt*Ye)/Ye||0}}({x:se,y:ge}):{x:se,y:ge};return se=Ie.x,ge=Ie.y,X?Object.assign({},Ne,(($e={})[we]=ke?"0":"",$e[fe]=Me?"0":"",$e.transform=(le.devicePixelRatio||1)<=1?"translate("+se+"px, "+ge+"px)":"translate3d("+se+"px, "+ge+"px, 0)",$e)):Object.assign({},Ne,((b={})[we]=ke?ge+"px":"",b[fe]=Me?se+"px":"",b.transform="",b))}var $t={left:"right",right:"left",bottom:"top",top:"bottom"};function Ft($){return $.replace(/left|right|bottom|top/g,function(b){return $t[b]})}var Qr={start:"end",end:"start"};function Tn($){return $.replace(/start|end/g,function(b){return Qr[b]})}function jn($,b){var S=b.getRootNode&&b.getRootNode();if($.contains(b))return!0;if(S&&x(S)){var R=b;do{if(R&&$.isSameNode(R))return!0;R=R.parentNode||R.host}while(R)}return!1}function gn($){return Object.assign({},$,{left:$.x,top:$.y,right:$.x+$.width,bottom:$.y+$.height})}function Pn($,b){return b===ht?gn(function(S){var R=a(S),W=w(S),z=R.visualViewport,V=W.clientWidth,K=W.clientHeight,X=0,ne=0;return z&&(V=z.width,K=z.height,/^((?!chrome|android).)*safari/i.test(navigator.userAgent)||(X=z.offsetLeft,ne=z.offsetTop)),{width:V,height:K,x:X+D(S),y:ne}}($)):g(b)?function(S){var R=y(S);return R.top=R.top+S.clientTop,R.left=R.left+S.clientLeft,R.bottom=R.top+S.clientHeight,R.right=R.left+S.clientWidth,R.width=S.clientWidth,R.height=S.clientHeight,R.x=R.left,R.y=R.top,R}(b):gn(function(S){var R,W=w(S),z=p(S),V=(R=S.ownerDocument)==null?void 0:R.body,K=k(W.scrollWidth,W.clientWidth,V?V.scrollWidth:0,V?V.clientWidth:0),X=k(W.scrollHeight,W.clientHeight,V?V.scrollHeight:0,V?V.clientHeight:0),ne=-z.scrollLeft+D(S),re=-z.scrollTop;return P(V||W).direction==="rtl"&&(ne+=k(W.clientWidth,V?V.clientWidth:0)-K),{width:K,height:X,x:ne,y:re}}(w($)))}function qn($){return Object.assign({},{top:0,right:0,bottom:0,left:0},$)}function An($,b){return b.reduce(function(S,R){return S[R]=$,S},{})}function zt($,b){b===void 0&&(b={});var S=b,R=S.placement,W=R===void 0?$.placement:R,z=S.boundary,V=z===void 0?"clippingParents":z,K=S.rootBoundary,X=K===void 0?ht:K,ne=S.elementContext,re=ne===void 0?_e:ne,te=S.altBoundary,Ae=te!==void 0&&te,se=S.padding,ye=se===void 0?0:se,ge=qn(typeof ye!="number"?ye:An(ye,tt)),ie=re===_e?"reference":_e,Me=$.rects.popper,ke=$.elements[Ae?ie:re],fe=function(Ie,Je,it){var dt=Je==="clippingParents"?function(Ee){var vt=O(_(Ee)),Ke=["absolute","fixed"].indexOf(P(Ee).position)>=0&&h(Ee)?I(Ee):Ee;return g(Ke)?vt.filter(function(Qe){return g(Qe)&&jn(Qe,Ke)&&m(Qe)!=="body"}):[]}(Ie):[].concat(Je),Ye=[].concat(dt,[it]),Ze=Ye[0],He=Ye.reduce(function(Ee,vt){var Ke=Pn(Ie,vt);return Ee.top=k(Ke.top,Ee.top),Ee.right=q(Ke.right,Ee.right),Ee.bottom=q(Ke.bottom,Ee.bottom),Ee.left=k(Ke.left,Ee.left),Ee},Pn(Ie,Ze));return He.width=He.right-He.left,He.height=He.bottom-He.top,He.x=He.left,He.y=He.top,He}(g(ke)?ke:ke.contextElement||w($.elements.popper),V,X),we=y($.elements.reference),le=ee({reference:we,element:Me,strategy:"absolute",placement:W}),ce=gn(Object.assign({},Me,le)),de=re===_e?ce:we,me={top:fe.top-de.top+ge.top,bottom:de.bottom-fe.bottom+ge.bottom,left:fe.left-de.left+ge.left,right:de.right-fe.right+ge.right},$e=$.modifiersData.offset;if(re===_e&&$e){var Ne=$e[W];Object.keys(me).forEach(function(Ie){var Je=[Ce,J].indexOf(Ie)>=0?1:-1,it=[F,J].indexOf(Ie)>=0?"y":"x";me[Ie]+=Ne[it]*Je})}return me}function Vt($,b,S){return k($,q(b,S))}function Mn($,b,S){return S===void 0&&(S={x:0,y:0}),{top:$.top-b.height-S.y,right:$.right-b.width+S.x,bottom:$.bottom-b.height+S.y,left:$.left-b.width-S.x}}function Dn($){return[F,Ce,J,ae].some(function(b){return $[b]>=0})}var Fr=bt({defaultModifiers:[{name:"eventListeners",enabled:!0,phase:"write",fn:function(){},effect:function($){var b=$.state,S=$.instance,R=$.options,W=R.scroll,z=W===void 0||W,V=R.resize,K=V===void 0||V,X=a(b.elements.popper),ne=[].concat(b.scrollParents.reference,b.scrollParents.popper);return z&&ne.forEach(function(re){re.addEventListener("scroll",S.update,Re)}),K&&X.addEventListener("resize",S.update,Re),function(){z&&ne.forEach(function(re){re.removeEventListener("scroll",S.update,Re)}),K&&X.removeEventListener("resize",S.update,Re)}},data:{}},{name:"popperOffsets",enabled:!0,phase:"read",fn:function($){var b=$.state,S=$.name;b.modifiersData[S]=ee({reference:b.rects.reference,element:b.rects.popper,strategy:"absolute",placement:b.placement})},data:{}},{name:"computeStyles",enabled:!0,phase:"beforeWrite",fn:function($){var b=$.state,S=$.options,R=S.gpuAcceleration,W=R===void 0||R,z=S.adaptive,V=z===void 0||z,K=S.roundOffsets,X=K===void 0||K,ne={placement:ze(b.placement),variation:je(b.placement),popper:b.elements.popper,popperRect:b.rects.popper,gpuAcceleration:W,isFixed:b.options.strategy==="fixed"};b.modifiersData.popperOffsets!=null&&(b.styles.popper=Object.assign({},b.styles.popper,oe(Object.assign({},ne,{offsets:b.modifiersData.popperOffsets,position:b.options.strategy,adaptive:V,roundOffsets:X})))),b.modifiersData.arrow!=null&&(b.styles.arrow=Object.assign({},b.styles.arrow,oe(Object.assign({},ne,{offsets:b.modifiersData.arrow,position:"absolute",adaptive:!1,roundOffsets:X})))),b.attributes.popper=Object.assign({},b.attributes.popper,{"data-popper-placement":b.placement})},data:{}},{name:"applyStyles",enabled:!0,phase:"write",fn:function($){var b=$.state;Object.keys(b.elements).forEach(function(S){var R=b.styles[S]||{},W=b.attributes[S]||{},z=b.elements[S];h(z)&&m(z)&&(Object.assign(z.style,R),Object.keys(W).forEach(function(V){var K=W[V];K===!1?z.removeAttribute(V):z.setAttribute(V,K===!0?"":K)}))})},effect:function($){var b=$.state,S={popper:{position:b.options.strategy,left:"0",top:"0",margin:"0"},arrow:{position:"absolute"},reference:{}};return Object.assign(b.elements.popper.style,S.popper),b.styles=S,b.elements.arrow&&Object.assign(b.elements.arrow.style,S.arrow),function(){Object.keys(b.elements).forEach(function(R){var W=b.elements[R],z=b.attributes[R]||{},V=Object.keys(b.styles.hasOwnProperty(R)?b.styles[R]:S[R]).reduce(function(K,X){return K[X]="",K},{});h(W)&&m(W)&&(Object.assign(W.style,V),Object.keys(z).forEach(function(K){W.removeAttribute(K)}))})}},requires:["computeStyles"]},{name:"offset",enabled:!0,phase:"main",requires:["popperOffsets"],fn:function($){var b=$.state,S=$.options,R=$.name,W=S.offset,z=W===void 0?[0,0]:W,V=We.reduce(function(re,te){return re[te]=function(Ae,se,ye){var ge=ze(Ae),ie=[ae,F].indexOf(ge)>=0?-1:1,Me=typeof ye=="function"?ye(Object.assign({},se,{placement:Ae})):ye,ke=Me[0],fe=Me[1];return ke=ke||0,fe=(fe||0)*ie,[ae,Ce].indexOf(ge)>=0?{x:fe,y:ke}:{x:ke,y:fe}}(te,b.rects,z),re},{}),K=V[b.placement],X=K.x,ne=K.y;b.modifiersData.popperOffsets!=null&&(b.modifiersData.popperOffsets.x+=X,b.modifiersData.popperOffsets.y+=ne),b.modifiersData[R]=V}},{name:"flip",enabled:!0,phase:"main",fn:function($){var b=$.state,S=$.options,R=$.name;if(!b.modifiersData[R]._skip){for(var W=S.mainAxis,z=W===void 0||W,V=S.altAxis,K=V===void 0||V,X=S.fallbackPlacements,ne=S.padding,re=S.boundary,te=S.rootBoundary,Ae=S.altBoundary,se=S.flipVariations,ye=se===void 0||se,ge=S.allowedAutoPlacements,ie=b.options.placement,Me=ze(ie),ke=X||(Me!==ie&&ye?function(Qe){if(ze(Qe)===ot)return[];var st=Ft(Qe);return[Tn(Qe),st,Tn(st)]}(ie):[Ft(ie)]),fe=[ie].concat(ke).reduce(function(Qe,st){return Qe.concat(ze(st)===ot?function(Lt,_t){_t===void 0&&(_t={});var lt=_t,Jt=lt.placement,Yt=lt.boundary,Et=lt.rootBoundary,mn=lt.padding,hn=lt.flipVariations,Tt=lt.allowedAutoPlacements,yn=Tt===void 0?We:Tt,Gt=je(Jt),Kt=Gt?hn?ft:ft.filter(function(ct){return je(ct)===Gt}):tt,jt=Kt.filter(function(ct){return yn.indexOf(ct)>=0});jt.length===0&&(jt=Kt);var Pt=jt.reduce(function(ct,kt){return ct[kt]=zt(Lt,{placement:kt,boundary:Yt,rootBoundary:Et,padding:mn})[ze(kt)],ct},{});return Object.keys(Pt).sort(function(ct,kt){return Pt[ct]-Pt[kt]})}(b,{placement:st,boundary:re,rootBoundary:te,padding:ne,flipVariations:ye,allowedAutoPlacements:ge}):st)},[]),we=b.rects.reference,le=b.rects.popper,ce=new Map,de=!0,me=fe[0],$e=0;$e<fe.length;$e++){var Ne=fe[$e],Ie=ze(Ne),Je=je(Ne)===Ge,it=[F,J].indexOf(Ie)>=0,dt=it?"width":"height",Ye=zt(b,{placement:Ne,boundary:re,rootBoundary:te,altBoundary:Ae,padding:ne}),Ze=it?Je?Ce:ae:Je?J:F;we[dt]>le[dt]&&(Ze=Ft(Ze));var He=Ft(Ze),Ee=[];if(z&&Ee.push(Ye[Ie]<=0),K&&Ee.push(Ye[Ze]<=0,Ye[He]<=0),Ee.every(function(Qe){return Qe})){me=Ne,de=!1;break}ce.set(Ne,Ee)}if(de)for(var vt=function(Qe){var st=fe.find(function(Lt){var _t=ce.get(Lt);if(_t)return _t.slice(0,Qe).every(function(lt){return lt})});if(st)return me=st,"break"},Ke=ye?3:1;Ke>0&&vt(Ke)!=="break";Ke--);b.placement!==me&&(b.modifiersData[R]._skip=!0,b.placement=me,b.reset=!0)}},requiresIfExists:["offset"],data:{_skip:!1}},{name:"preventOverflow",enabled:!0,phase:"main",fn:function($){var b=$.state,S=$.options,R=$.name,W=S.mainAxis,z=W===void 0||W,V=S.altAxis,K=V!==void 0&&V,X=S.boundary,ne=S.rootBoundary,re=S.altBoundary,te=S.padding,Ae=S.tether,se=Ae===void 0||Ae,ye=S.tetherOffset,ge=ye===void 0?0:ye,ie=zt(b,{boundary:X,rootBoundary:ne,padding:te,altBoundary:re}),Me=ze(b.placement),ke=je(b.placement),fe=!ke,we=Pe(Me),le=we==="x"?"y":"x",ce=b.modifiersData.popperOffsets,de=b.rects.reference,me=b.rects.popper,$e=typeof ge=="function"?ge(Object.assign({},b.rects,{placement:b.placement})):ge,Ne=typeof $e=="number"?{mainAxis:$e,altAxis:$e}:Object.assign({mainAxis:0,altAxis:0},$e),Ie=b.modifiersData.offset?b.modifiersData.offset[b.placement]:null,Je={x:0,y:0};if(ce){if(z){var it,dt=we==="y"?F:ae,Ye=we==="y"?J:Ce,Ze=we==="y"?"height":"width",He=ce[we],Ee=He+ie[dt],vt=He-ie[Ye],Ke=se?-me[Ze]/2:0,Qe=ke===Ge?de[Ze]:me[Ze],st=ke===Ge?-me[Ze]:-de[Ze],Lt=b.elements.arrow,_t=se&&Lt?u(Lt):{width:0,height:0},lt=b.modifiersData["arrow#persistent"]?b.modifiersData["arrow#persistent"].padding:{top:0,right:0,bottom:0,left:0},Jt=lt[dt],Yt=lt[Ye],Et=Vt(0,de[Ze],_t[Ze]),mn=fe?de[Ze]/2-Ke-Et-Jt-Ne.mainAxis:Qe-Et-Jt-Ne.mainAxis,hn=fe?-de[Ze]/2+Ke+Et+Yt+Ne.mainAxis:st+Et+Yt+Ne.mainAxis,Tt=b.elements.arrow&&I(b.elements.arrow),yn=Tt?we==="y"?Tt.clientTop||0:Tt.clientLeft||0:0,Gt=(it=Ie==null?void 0:Ie[we])!=null?it:0,Kt=He+hn-Gt,jt=Vt(se?q(Ee,He+mn-Gt-yn):Ee,He,se?k(vt,Kt):vt);ce[we]=jt,Je[we]=jt-He}if(K){var Pt,ct=we==="x"?F:ae,kt=we==="x"?J:Ce,xt=ce[le],Xt=le==="y"?"height":"width",Rn=xt+ie[ct],Hn=xt-ie[kt],bn=[F,ae].indexOf(Me)!==-1,Bn=(Pt=Ie==null?void 0:Ie[le])!=null?Pt:0,Nn=bn?Rn:xt-de[Xt]-me[Xt]-Bn+Ne.altAxis,In=bn?xt+de[Xt]+me[Xt]-Bn-Ne.altAxis:Hn,zn=se&&bn?function(Jr,Yr,vn){var Vn=Vt(Jr,Yr,vn);return Vn>vn?vn:Vn}(Nn,xt,In):Vt(se?Nn:Rn,xt,se?In:Hn);ce[le]=zn,Je[le]=zn-xt}b.modifiersData[R]=Je}},requiresIfExists:["offset"]},{name:"arrow",enabled:!0,phase:"main",fn:function($){var b,S=$.state,R=$.name,W=$.options,z=S.elements.arrow,V=S.modifiersData.popperOffsets,K=ze(S.placement),X=Pe(K),ne=[ae,Ce].indexOf(K)>=0?"height":"width";if(z&&V){var re=function(me,$e){return qn(typeof(me=typeof me=="function"?me(Object.assign({},$e.rects,{placement:$e.placement})):me)!="number"?me:An(me,tt))}(W.padding,S),te=u(z),Ae=X==="y"?F:ae,se=X==="y"?J:Ce,ye=S.rects.reference[ne]+S.rects.reference[X]-V[X]-S.rects.popper[ne],ge=V[X]-S.rects.reference[X],ie=I(z),Me=ie?X==="y"?ie.clientHeight||0:ie.clientWidth||0:0,ke=ye/2-ge/2,fe=re[Ae],we=Me-te[ne]-re[se],le=Me/2-te[ne]/2+ke,ce=Vt(fe,le,we),de=X;S.modifiersData[R]=((b={})[de]=ce,b.centerOffset=ce-le,b)}},effect:function($){var b=$.state,S=$.options.element,R=S===void 0?"[data-popper-arrow]":S;R!=null&&(typeof R!="string"||(R=b.elements.popper.querySelector(R)))&&jn(b.elements.popper,R)&&(b.elements.arrow=R)},requires:["popperOffsets"],requiresIfExists:["preventOverflow"]},{name:"hide",enabled:!0,phase:"main",requiresIfExists:["preventOverflow"],fn:function($){var b=$.state,S=$.name,R=b.rects.reference,W=b.rects.popper,z=b.modifiersData.preventOverflow,V=zt(b,{elementContext:"reference"}),K=zt(b,{altBoundary:!0}),X=Mn(V,R),ne=Mn(K,W,z),re=Dn(X),te=Dn(ne);b.modifiersData[S]={referenceClippingOffsets:X,popperEscapeOffsets:ne,isReferenceHidden:re,hasPopperEscaped:te},b.attributes.popper=Object.assign({},b.attributes.popper,{"data-popper-reference-hidden":re,"data-popper-escaped":te})}}]})}},t={};function r(s){var l=t[s];if(l!==void 0)return l.exports;var c=t[s]={exports:{}};return n[s](c,c.exports,r),c.exports}r.d=(s,l)=>{for(var c in l)r.o(l,c)&&!r.o(s,c)&&Object.defineProperty(s,c,{enumerable:!0,get:l[c]})},r.o=(s,l)=>Object.prototype.hasOwnProperty.call(s,l),r.r=s=>{typeof Symbol<"u"&&Symbol.toStringTag&&Object.defineProperty(s,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(s,"__esModule",{value:!0})};var i={};return r.r(i),r(661),r(795),r(682),r(284),r(181),r(778),r(51),r(185),i})()})})(Mo);function Do(o){let e=o[0].title+"",n;return{c(){n=pe(e)},m(t,r){N(t,n,r)},p(t,r){r&1&&e!==(e=t[0].title+"")&&De(n,e)},d(t){t&&B(n)}}}function Ro(o){let e,n;return{c(){e=pe("Welcome to "),n=E("span"),n.textContent="Vanna.AI",d(n,"class","nav-title")},m(t,r){N(t,e,r),N(t,n,r)},p:Y,d(t){t&&(B(e),B(n))}}}function Ho(o){let e,n,t,r,i=o[0].subtitle+"",s;function l(g,h){return g[0].title=="Welcome to Vanna.AI"?Ro:Do}let c=l(o),a=c(o);return{c(){e=E("div"),n=E("h1"),a.c(),t=Q(),r=E("p"),s=pe(i),d(n,"class","text-3xl font-bold text-gray-800 sm:text-4xl dark:text-white"),d(r,"class","mt-3 text-gray-600 dark:text-gray-400"),d(e,"class","max-w-4xl px-4 sm:px-6 lg:px-8 mx-auto text-center")},m(g,h){N(g,e,h),v(e,n),a.m(n,null),v(e,t),v(e,r),v(r,s)},p(g,[h]){c===(c=l(g))&&a?a.p(g,h):(a.d(1),a=c(g),a&&(a.c(),a.m(n,null))),h&1&&i!==(i=g[0].subtitle+"")&&De(s,i)},i:Y,o:Y,d(g){g&&B(e),a.d()}}}function Bo(o,e,n){let t;return et(o,Ot,r=>n(0,t=r)),[t]}class No extends ve{constructor(e){super(),be(this,e,Bo,Ho,he,{})}}function Io(o){let e,n;const t=o[1].default,r=on(t,o,o[0],null);return{c(){e=E("p"),r&&r.c(),d(e,"class","text-gray-800 dark:text-gray-200")},m(i,s){N(i,e,s),r&&r.m(e,null),n=!0},p(i,[s]){r&&r.p&&(!n||s&1)&&ln(r,t,i,i[0],n?sn(t,i[0],s,null):an(i[0]),null)},i(i){n||(L(r,i),n=!0)},o(i){A(r,i),n=!1},d(i){i&&B(e),r&&r.d(i)}}}function zo(o,e,n){let{$$slots:t={},$$scope:r}=e;return o.$$set=i=>{"$$scope"in i&&n(0,r=i.$$scope)},[r,t]}class at extends ve{constructor(e){super(),be(this,e,zo,Io,he,{})}}function Vo(o){let e;return{c(){e=pe(o[0])},m(n,t){N(n,e,t)},p(n,t){t&1&&De(e,n[0])},d(n){n&&B(e)}}}function Go(o){let e,n,t,r,i,s,l,c,a;l=new at({props:{$$slots:{default:[Vo]},$$scope:{ctx:o}}});const g=o[1].default,h=on(g,o,o[2],null);return{c(){e=E("li"),n=E("div"),t=E("div"),r=E("span"),r.innerHTML='<span class="text-sm font-medium text-white leading-none">You</span>',i=Q(),s=E("div"),U(l.$$.fragment),c=Q(),h&&h.c(),d(r,"class","flex-shrink-0 inline-flex items-center justify-center h-[2.375rem] w-[2.375rem] rounded-full bg-gray-600"),d(s,"class","grow mt-2 space-y-3"),d(t,"class","max-w-2xl flex gap-x-2 sm:gap-x-4"),d(n,"class","max-w-4xl px-4 sm:px-6 lg:px-8 mx-auto"),d(e,"class","py-2 sm:py-4")},m(x,k){N(x,e,k),v(e,n),v(n,t),v(t,r),v(t,i),v(t,s),G(l,s,null),v(s,c),h&&h.m(s,null),a=!0},p(x,[k]){const q={};k&5&&(q.$$scope={dirty:k,ctx:x}),l.$set(q),h&&h.p&&(!a||k&4)&&ln(h,g,x,x[2],a?sn(g,x[2],k,null):an(x[2]),null)},i(x){a||(L(l.$$.fragment,x),L(h,x),a=!0)},o(x){A(l.$$.fragment,x),A(h,x),a=!1},d(x){x&&B(e),Z(l),h&&h.d(x)}}}function Zo(o,e,n){let{$$slots:t={},$$scope:r}=e,{message:i}=e;return o.$$set=s=>{"message"in s&&n(0,i=s.message),"$$scope"in s&&n(2,r=s.$$scope)},[i,t,r]}class Ct extends ve{constructor(e){super(),be(this,e,Zo,Go,he,{message:0})}}function Uo(o){let e,n,t;return{c(){e=E("button"),e.innerHTML='<svg class="flex-shrink-0 size-4" xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path d="M12 2a3 3 0 0 0-3 3v7a3 3 0 0 0 6 0V5a3 3 0 0 0-3-3Z"></path><path d="M19 10v2a7 7 0 0 1-14 0v-2"></path><line x1="12" x2="12" y1="19" y2="22"></line></svg>',d(e,"type","button"),d(e,"class","inline-flex flex-shrink-0 justify-center items-center size-8 rounded-lg text-gray-500 hover:text-blue-600 focus:z-10 focus:outline-none focus:ring-2 focus:ring-blue-500 dark:hover:text-blue-500 dark:focus:outline-none dark:focus:ring-1 dark:focus:ring-gray-600")},m(r,i){N(r,e,i),n||(t=Te(e,"click",o[1]),n=!0)},p:Y,d(r){r&&B(e),n=!1,t()}}}function Wo(o){let e;return{c(){e=E("button"),e.innerHTML='<svg class="flex-shrink-0 size-4" xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path d="M12 2a3 3 0 0 0-3 3v7a3 3 0 0 0 6 0V5a3 3 0 0 0-3-3Z"></path><path d="M19 10v2a7 7 0 0 1-14 0v-2"></path><line x1="12" x2="12" y1="19" y2="22"></line></svg>',d(e,"type","button"),d(e,"class","animate-ping animate-pulse inline-flex flex-shrink-0 justify-center items-center size-8 rounded-lg text-red-500 hover:text-red-600 focus:z-10 focus:outline-none focus:ring-2 focus:ring-red-500 dark:hover:text-red-500 dark:focus:outline-none dark:focus:ring-1 dark:focus:ring-red-600")},m(n,t){N(n,e,t)},p:Y,d(n){n&&B(e)}}}function Qo(o){let e;function n(i,s){return i[0]?Wo:Uo}let t=n(o),r=t(o);return{c(){r.c(),e=Ve()},m(i,s){r.m(i,s),N(i,e,s)},p(i,[s]){t===(t=n(i))&&r?r.p(i,s):(r.d(1),r=t(i),r&&(r.c(),r.m(e.parentNode,e)))},i:Y,o:Y,d(i){i&&B(e),r.d(i)}}}function Fo(o,e,n){let{newMessage:t}=e,r=!1;function i(){if(n(0,r=!0),Nr.set(!0),"webkitSpeechRecognition"in window)var s=new window.webkitSpeechRecognition;else var s=new window.SpeechRecognition;s.lang="en-US",s.start(),s.onresult=l=>{const c=l.results[0][0].transcript;console.log(c),n(2,t=c),n(0,r=!1)},s.onend=()=>{n(0,r=!1)},s.onerror=()=>{n(0,r=!1)}}return o.$$set=s=>{"newMessage"in s&&n(2,t=s.newMessage)},[r,i,t]}class Jo extends ve{constructor(e){super(),be(this,e,Fo,Qo,he,{newMessage:2})}}function Yo(o){let e,n,t,r,i,s,l,c,a,g,h,x,k,q,M;function y(m){o[5](m)}let p={};return o[0]!==void 0&&(p.newMessage=o[0]),a=new Jo({props:p}),$n.push(()=>uo(a,"newMessage",y)),{c(){e=E("div"),n=E("input"),t=Q(),r=E("div"),i=E("div"),s=E("div"),s.innerHTML="",l=Q(),c=E("div"),U(a.$$.fragment),h=Q(),x=E("button"),x.innerHTML='<svg class="h-3.5 w-3.5" xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" viewBox="0 0 16 16"><path d="M15.964.686a.5.5 0 0 0-.65-.65L.767 5.855H.766l-.452.18a.5.5 0 0 0-.082.887l.41.26.001.002 4.995 3.178 3.178 4.995.002.002.26.41a.5.5 0 0 0 .886-.083l6-15Zm-1.833 1.89L6.637 10.07l-.215-.338a.5.5 0 0 0-.154-.154l-.338-.215 7.494-7.494 1.178-.471-.47 1.178Z"></path></svg>',d(n,"type","text"),d(n,"class","p-4 pb-12 block w-full bg-gray-100 border-gray-200 rounded-md text-sm focus:border-blue-500 focus:ring-blue-500 dark:bg-slate-800 dark:border-gray-700 dark:text-gray-400"),d(n,"placeholder","Ask me a question about your data that I can turn into SQL."),d(s,"class","flex items-center"),d(x,"type","button"),d(x,"class","inline-flex flex-shrink-0 justify-center items-center h-8 w-8 rounded-md text-white bg-blue-600 hover:bg-blue-500 focus:z-10 focus:outline-none focus:ring-2 focus:ring-blue-500 transition-all"),d(c,"class","flex items-center gap-x-1"),d(i,"class","flex justify-between items-center"),d(r,"class","absolute bottom-px inset-x-px p-2 rounded-b-md bg-gray-100 dark:bg-slate-800"),d(e,"class","relative")},m(m,w){N(m,e,w),v(e,n),gt(n,o[0]),v(e,t),v(e,r),v(r,i),v(i,s),v(i,l),v(i,c),G(a,c,null),v(c,h),v(c,x),k=!0,q||(M=[Te(n,"input",o[4]),Te(n,"keydown",o[1]),Te(x,"click",o[2])],q=!0)},p(m,[w]){w&1&&n.value!==m[0]&&gt(n,m[0]);const D={};!g&&w&1&&(g=!0,D.newMessage=m[0],lo(()=>g=!1)),a.$set(D)},i(m){k||(L(a.$$.fragment,m),k=!0)},o(m){A(a.$$.fragment,m),k=!1},d(m){m&&B(e),Z(a),q=!1,mt(M)}}}function Ko(o,e,n){let{onSubmit:t}=e,r="";function i(a){a.key==="Enter"&&(t(r),a.preventDefault())}function s(){t(r)}function l(){r=this.value,n(0,r)}function c(a){r=a,n(0,r)}return o.$$set=a=>{"onSubmit"in a&&n(3,t=a.onSubmit)},[r,i,s,t,l,c]}class Xo extends ve{constructor(e){super(),be(this,e,Ko,Yo,he,{onSubmit:3})}}function ei(o){let e;return{c(){e=E("div"),e.innerHTML='<button type="button" class="p-2 inline-flex justify-center items-center gap-1.5 rounded-md border font-medium bg-white text-gray-700 shadow-sm align-middle hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-offset-white focus:ring-blue-600 transition-all text-xs dark:bg-slate-900 dark:hover:bg-slate-800 dark:border-gray-700 dark:text-gray-400 dark:hover:text-white dark:focus:ring-offset-gray-800" data-hs-overlay="#application-sidebar" aria-controls="application-sidebar" aria-label="Toggle navigation"><svg class="w-3.5 h-3.5" width="16" height="16" fill="currentColor" viewBox="0 0 16 16"><path fill-rule="evenodd" d="M2.5 12a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5z"></path></svg> <span>Sidebar</span></button>',d(e,"class","lg:hidden flex justify-end mb-2 sm:mb-3")},m(n,t){N(n,e,t)},p:Y,i:Y,o:Y,d(n){n&&B(e)}}}class ti extends ve{constructor(e){super(),be(this,e,null,ei,he,{})}}function ni(o){let e,n,t,r;return{c(){e=E("button"),n=pe(o[0]),d(e,"type","button"),d(e,"class","mb-2.5 mr-1.5 py-2 px-3 inline-flex justify-center items-center gap-x-2 rounded-md border border-blue-600 bg-white text-blue-600 align-middle hover:bg-blue-50 text-sm dark:bg-slate-900 dark:text-blue-500 dark:border-blue-500 dark:hover:text-blue-400 dark:hover:border-blue-400")},m(i,s){N(i,e,s),v(e,n),t||(r=Te(e,"click",o[1]),t=!0)},p(i,[s]){s&1&&De(n,i[0])},i:Y,o:Y,d(i){i&&B(e),t=!1,r()}}}function ri(o,e,n){let{message:t}=e,{onSubmit:r}=e;function i(){r(t)}return o.$$set=s=>{"message"in s&&n(0,t=s.message),"onSubmit"in s&&n(2,r=s.onSubmit)},[t,i,r]}class ut extends ve{constructor(e){super(),be(this,e,ri,ni,he,{message:0,onSubmit:2})}}function oi(o){let e,n,t,r,i,s,l,c,a,g,h;return{c(){e=E("span"),n=Xe("svg"),t=Xe("defs"),r=Xe("linearGradient"),i=Xe("stop"),s=Xe("stop"),l=Xe("g"),c=Xe("g"),a=Xe("path"),g=Xe("path"),d(i,"offset","0"),d(i,"stop-color","#009efd"),d(s,"offset","1"),d(s,"stop-color","#2af598"),d(r,"gradientTransform","matrix(1.09331 0 0 1.09331 -47.1838 -88.8946)"),d(r,"gradientUnits","userSpaceOnUse"),d(r,"id","LinearGradient"),d(r,"x1","237.82"),d(r,"x2","785.097"),d(r,"y1","549.609"),d(r,"y2","549.609"),d(a,"d","M117.718 228.798C117.718 119.455 206.358 30.8151 315.701 30.8151L708.299 30.8151C817.642 30.8151 906.282 119.455 906.282 228.798L906.282 795.202C906.282 904.545 817.642 993.185 708.299 993.185L315.701 993.185C206.358 993.185 117.718 904.545 117.718 795.202L117.718 228.798Z"),d(a,"fill","#0f172a"),d(a,"fill-rule","nonzero"),d(a,"opacity","1"),d(a,"stroke","#374151"),d(a,"stroke-linecap","butt"),d(a,"stroke-linejoin","round"),d(a,"stroke-width","20"),d(g,"d","M212.828 215.239C213.095 281.169 213.629 413.028 213.629 413.028C213.629 413.028 511.51 808.257 513.993 809.681C612.915 677.809 810.759 414.065 810.759 414.065C810.759 414.065 811.034 280.901 811.172 214.319C662.105 362.973 662.105 362.973 513.038 511.627C362.933 363.433 362.933 363.433 212.828 215.239Z"),d(g,"fill","url(#LinearGradient)"),d(g,"fill-rule","nonzero"),d(g,"opacity","1"),d(g,"stroke","none"),d(c,"opacity","1"),d(l,"id","Layer-1"),d(n,"height","100%"),d(n,"stroke-miterlimit","10"),tn(n,"fill-rule","nonzero"),tn(n,"clip-rule","evenodd"),tn(n,"stroke-linecap","round"),tn(n,"stroke-linejoin","round"),d(n,"version","1.1"),d(n,"viewBox","0 0 1024 1024"),d(n,"width","100%"),d(n,"xml:space","preserve"),d(n,"xmlns","http://www.w3.org/2000/svg"),d(e,"class",h="flex-shrink-0 w-[2.375rem] h-[2.375rem] "+o[0])},m(x,k){N(x,e,k),v(e,n),v(n,t),v(t,r),v(r,i),v(r,s),v(n,l),v(l,c),v(c,a),v(c,g)},p(x,[k]){k&1&&h!==(h="flex-shrink-0 w-[2.375rem] h-[2.375rem] "+x[0])&&d(e,"class",h)},i:Y,o:Y,d(x){x&&B(e)}}}function ii(o,e,n){let t,{animate:r=!1}=e;return o.$$set=i=>{"animate"in i&&n(1,r=i.animate)},o.$$.update=()=>{o.$$.dirty&2&&n(0,t=r?"animate-bounce":"")},[t,r]}class Vr extends ve{constructor(e){super(),be(this,e,ii,oi,he,{animate:1})}}function si(o){let e,n,t,r,i;n=new Vr({});const s=o[1].default,l=on(s,o,o[0],null);return{c(){e=E("li"),U(n.$$.fragment),t=Q(),r=E("div"),l&&l.c(),d(r,"class","space-y-3 overflow-x-auto overflow-y-hidden whitespace-break-spaces"),d(e,"class","max-w-4xl py-2 px-4 sm:px-6 lg:px-8 mx-auto flex gap-x-2 sm:gap-x-4")},m(c,a){N(c,e,a),G(n,e,null),v(e,t),v(e,r),l&&l.m(r,null),i=!0},p(c,[a]){l&&l.p&&(!i||a&1)&&ln(l,s,c,c[0],i?sn(s,c[0],a,null):an(c[0]),null)},i(c){i||(L(n.$$.fragment,c),L(l,c),i=!0)},o(c){A(n.$$.fragment,c),A(l,c),i=!1},d(c){c&&B(e),Z(n),l&&l.d(c)}}}function li(o,e,n){let{$$slots:t={},$$scope:r}=e;return o.$$set=i=>{"$$scope"in i&&n(0,r=i.$$scope)},[r,t]}class Fe extends ve{constructor(e){super(),be(this,e,li,si,he,{})}}function ai(o){let e;return{c(){e=pe("Thinking...")},m(n,t){N(n,e,t)},d(n){n&&B(e)}}}function ci(o){let e,n,t,r,i,s;return n=new Vr({props:{animate:!0}}),i=new at({props:{$$slots:{default:[ai]},$$scope:{ctx:o}}}),{c(){e=E("li"),U(n.$$.fragment),t=Q(),r=E("div"),U(i.$$.fragment),d(r,"class","space-y-3"),d(e,"class","max-w-4xl py-2 px-4 sm:px-6 lg:px-8 mx-auto flex gap-x-2 sm:gap-x-4")},m(l,c){N(l,e,c),G(n,e,null),v(e,t),v(e,r),G(i,r,null),s=!0},p(l,[c]){const a={};c&1&&(a.$$scope={dirty:c,ctx:l}),i.$set(a)},i(l){s||(L(n.$$.fragment,l),L(i.$$.fragment,l),s=!0)},o(l){A(n.$$.fragment,l),A(i.$$.fragment,l),s=!1},d(l){l&&B(e),Z(n),Z(i)}}}class ui extends ve{constructor(e){super(),be(this,e,null,ci,he,{})}}function fi(o){let e,n,t,r,i,s,l,c,a,g,h;return{c(){e=E("ul"),n=E("li"),t=E("div"),r=E("span"),r.textContent="CSV",i=Q(),s=E("a"),l=Xe("svg"),c=Xe("path"),a=Xe("path"),g=pe(`
          Download`),d(r,"class","mr-3 flex-1 w-0 truncate"),d(c,"d","M.5 9.9a.5.5 0 0 1 .5.5v2.5a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2.5a.5.5 0 0 1 1 0v2.5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2v-2.5a.5.5 0 0 1 .5-.5z"),d(a,"d","M7.646 11.854a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0-.708-.708L8.5 10.293V1.5a.5.5 0 0 0-1 0v8.793L5.354 8.146a.5.5 0 1 0-.708.708l3 3z"),d(l,"class","flex-shrink-0 w-3 h-3"),d(l,"width","16"),d(l,"height","16"),d(l,"viewBox","0 0 16 16"),d(l,"fill","currentColor"),d(s,"class","flex items-center gap-x-2 text-gray-500 hover:text-blue-500 whitespace-nowrap"),d(s,"href",h="/api/v0/download_csv?id="+o[0]),d(t,"class","w-full flex justify-between truncate"),d(n,"class","flex items-center gap-x-2 p-3 text-sm bg-white border text-gray-800 first:rounded-t-lg first:mt-0 last:rounded-b-lg dark:bg-slate-900 dark:border-gray-700 dark:text-gray-200"),d(e,"class","flex flex-col justify-end text-start -space-y-px")},m(x,k){N(x,e,k),v(e,n),v(n,t),v(t,r),v(t,i),v(t,s),v(s,l),v(l,c),v(l,a),v(s,g)},p(x,[k]){k&1&&h!==(h="/api/v0/download_csv?id="+x[0])&&d(s,"href",h)},i:Y,o:Y,d(x){x&&B(e)}}}function di(o,e,n){let{id:t}=e;return o.$$set=r=>{"id"in r&&n(0,t=r.id)},[t]}class pi extends ve{constructor(e){super(),be(this,e,di,fi,he,{id:0})}}function Jn(o,e,n){const t=o.slice();return t[5]=e[n],t}function Yn(o,e,n){const t=o.slice();return t[8]=e[n],t}function Kn(o,e,n){const t=o.slice();return t[8]=e[n],t}function Xn(o){let e,n,t,r;return{c(){e=E("th"),n=E("div"),t=E("span"),t.textContent=`${o[8]}`,r=Q(),d(t,"class","text-xs font-semibold uppercase tracking-wide text-gray-800 dark:text-gray-200"),d(n,"class","flex items-center gap-x-2"),d(e,"scope","col"),d(e,"class","px-6 py-3 text-left")},m(i,s){N(i,e,s),v(e,n),v(n,t),v(e,r)},p:Y,d(i){i&&B(e)}}}function er(o){let e,n,t;return{c(){e=E("td"),n=E("div"),t=E("span"),t.textContent=`${o[5][o[8]]}`,d(t,"class","text-gray-800 dark:text-gray-200"),d(n,"class","px-6 py-3"),d(e,"class","h-px w-px whitespace-nowrap")},m(r,i){N(r,e,i),v(e,n),v(n,t)},p:Y,d(r){r&&B(e)}}}function tr(o){let e,n,t=Le(o[3]),r=[];for(let i=0;i<t.length;i+=1)r[i]=er(Yn(o,t,i));return{c(){e=E("tr");for(let i=0;i<r.length;i+=1)r[i].c();n=Q()},m(i,s){N(i,e,s);for(let l=0;l<r.length;l+=1)r[l]&&r[l].m(e,null);v(e,n)},p(i,s){if(s&12){t=Le(i[3]);let l;for(l=0;l<t.length;l+=1){const c=Yn(i,t,l);r[l]?r[l].p(c,s):(r[l]=er(c),r[l].c(),r[l].m(e,n))}for(;l<r.length;l+=1)r[l].d(1);r.length=t.length}},d(i){i&&B(e),nt(r,i)}}}function nr(o){let e,n;return e=new pi({props:{id:o[0]}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&1&&(i.id=t[0]),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function gi(o){let e,n,t,r,i,s,l,c,a,g,h,x=Le(o[3]),k=[];for(let p=0;p<x.length;p+=1)k[p]=Xn(Kn(o,x,p));let q=Le(o[2]),M=[];for(let p=0;p<q.length;p+=1)M[p]=tr(Jn(o,q,p));let y=o[1].csv_download&&nr(o);return{c(){e=E("div"),n=E("div"),t=E("div"),r=E("table"),i=E("thead"),s=E("tr");for(let p=0;p<k.length;p+=1)k[p].c();l=Q(),c=E("tbody");for(let p=0;p<M.length;p+=1)M[p].c();a=Q(),y&&y.c(),g=Ve(),d(i,"class","bg-gray-50 dark:bg-slate-800"),d(c,"class","divide-y divide-gray-200 dark:divide-gray-700"),d(r,"class","min-w-full divide-y divide-gray-200 dark:divide-gray-700"),d(t,"class","p-1.5 min-w-full inline-block align-middle"),d(n,"class","-m-1.5 overflow-x-auto"),d(e,"class","bg-white border border-gray-200 rounded-xl shadow-sm overflow-hidden dark:bg-slate-900 dark:border-gray-700")},m(p,m){N(p,e,m),v(e,n),v(n,t),v(t,r),v(r,i),v(i,s);for(let w=0;w<k.length;w+=1)k[w]&&k[w].m(s,null);v(r,l),v(r,c);for(let w=0;w<M.length;w+=1)M[w]&&M[w].m(c,null);N(p,a,m),y&&y.m(p,m),N(p,g,m),h=!0},p(p,[m]){if(m&8){x=Le(p[3]);let w;for(w=0;w<x.length;w+=1){const D=Kn(p,x,w);k[w]?k[w].p(D,m):(k[w]=Xn(D),k[w].c(),k[w].m(s,null))}for(;w<k.length;w+=1)k[w].d(1);k.length=x.length}if(m&12){q=Le(p[2]);let w;for(w=0;w<q.length;w+=1){const D=Jn(p,q,w);M[w]?M[w].p(D,m):(M[w]=tr(D),M[w].c(),M[w].m(c,null))}for(;w<M.length;w+=1)M[w].d(1);M.length=q.length}p[1].csv_download?y?(y.p(p,m),m&2&&L(y,1)):(y=nr(p),y.c(),L(y,1),y.m(g.parentNode,g)):y&&(Se(),A(y,1,1,()=>{y=null}),Oe())},i(p){h||(L(y),h=!0)},o(p){A(y),h=!1},d(p){p&&(B(e),B(a),B(g)),nt(k,p),nt(M,p),y&&y.d(p)}}}function mi(o,e,n){let t;et(o,Ot,c=>n(1,t=c));let{id:r}=e,{df:i}=e,s=JSON.parse(i),l=s.length>0?Object.keys(s[0]):[];return o.$$set=c=>{"id"in c&&n(0,r=c.id),"df"in c&&n(4,i=c.df)},[r,t,s,l,i]}class Gr extends ve{constructor(e){super(),be(this,e,mi,gi,he,{id:0,df:4})}}function hi(o){let e;return{c(){e=E("div"),d(e,"id",o[0])},m(n,t){N(n,e,t)},p:Y,i:Y,o:Y,d(n){n&&B(e)}}}function yi(o,e,n){let{fig:t}=e,r=JSON.parse(t),i=Math.random().toString(36).substring(2,15)+Math.random().toString(36).substring(2,15);return Hr(()=>{Plotly.newPlot(document.getElementById(i),r,{responsive:!0})}),o.$$set=s=>{"fig"in s&&n(1,t=s.fig)},[i,t]}class Zr extends ve{constructor(e){super(),be(this,e,yi,hi,he,{fig:1})}}function bi(o){let e,n,t,r;return{c(){e=E("button"),n=pe(o[0]),d(e,"type","button"),d(e,"class","mb-2.5 mr-1.5 py-3 px-4 inline-flex justify-center items-center gap-2 rounded-md border-2 border-green-200 font-semibold text-green-500 hover:text-white hover:bg-green-500 hover:border-green-500 focus:outline-none focus:ring-2 focus:ring-green-200 focus:ring-offset-2 transition-all text-sm dark:focus:ring-offset-gray-800")},m(i,s){N(i,e,s),v(e,n),t||(r=Te(e,"click",o[1]),t=!0)},p(i,[s]){s&1&&De(n,i[0])},i:Y,o:Y,d(i){i&&B(e),t=!1,r()}}}function vi(o,e,n){let{message:t}=e,{onSubmit:r}=e;function i(){r(t)}return o.$$set=s=>{"message"in s&&n(0,t=s.message),"onSubmit"in s&&n(2,r=s.onSubmit)},[t,i,r]}class Ur extends ve{constructor(e){super(),be(this,e,vi,bi,he,{message:0,onSubmit:2})}}function _i(o){let e,n,t,r,i,s,l,c,a;return{c(){e=E("div"),n=E("div"),t=E("div"),t.innerHTML='<svg class="h-4 w-4 text-yellow-400 mt-0.5" xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" viewBox="0 0 16 16"><path d="M8.982 1.566a1.13 1.13 0 0 0-1.96 0L.165 13.233c-.457.778.091 1.767.98 1.767h13.713c.889 0 1.438-.99.98-1.767L8.982 1.566zM8 5c.535 0 .954.462.9.995l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 5.995A.905.905 0 0 1 8 5zm.002 6a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"></path></svg>',r=Q(),i=E("div"),s=E("h3"),s.textContent="Error",l=Q(),c=E("div"),a=pe(o[0]),d(t,"class","flex-shrink-0"),d(s,"class","text-sm text-yellow-800 font-semibold"),d(c,"class","mt-1 text-sm text-yellow-700"),d(i,"class","ml-4"),d(n,"class","flex"),d(e,"class","bg-yellow-50 border border-yellow-200 rounded-md p-4"),d(e,"role","alert")},m(g,h){N(g,e,h),v(e,n),v(n,t),v(n,r),v(n,i),v(i,s),v(i,l),v(i,c),v(c,a)},p(g,[h]){h&1&&De(a,g[0])},i:Y,o:Y,d(g){g&&B(e)}}}function wi(o,e,n){let{message:t}=e;return o.$$set=r=>{"message"in r&&n(0,t=r.message)},[t]}let En=class extends ve{constructor(e){super(),be(this,e,wi,_i,he,{message:0})}};function $i(o){let e,n;const t=o[1].default,r=on(t,o,o[0],null);return{c(){e=E("div"),r&&r.c(),d(e,"class","font-mono whitespace-pre-wrap")},m(i,s){N(i,e,s),r&&r.m(e,null),n=!0},p(i,[s]){r&&r.p&&(!n||s&1)&&ln(r,t,i,i[0],n?sn(t,i[0],s,null):an(i[0]),null)},i(i){n||(L(r,i),n=!0)},o(i){A(r,i),n=!1},d(i){i&&B(e),r&&r.d(i)}}}function ki(o,e,n){let{$$slots:t={},$$scope:r}=e;return o.$$set=i=>{"$$scope"in i&&n(0,r=i.$$scope)},[r,t]}class Wr extends ve{constructor(e){super(),be(this,e,ki,$i,he,{})}}function xi(o){let e;return{c(){e=pe(o[1])},m(n,t){N(n,e,t)},p(n,t){t&2&&De(e,n[1])},d(n){n&&B(e)}}}function Si(o){let e,n,t,r,i,s,l,c;return t=new ut({props:{message:"Run SQL",onSubmit:o[3]}}),i=new at({props:{$$slots:{default:[xi]},$$scope:{ctx:o}}}),{c(){e=E("textarea"),n=Q(),U(t.$$.fragment),r=Q(),U(i.$$.fragment),d(e,"rows","6"),d(e,"class","block p-2.5 w-full text-blue-600 hover:text-blue-500 dark:text-blue-500 dark:hover:text-blue-400 bg-gray-50 rounded-lg border border-gray-300 focus:ring-blue-500 focus:border-blue-500 dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:focus:ring-blue-500 dark:focus:border-blue-500 font-mono"),d(e,"placeholder","SELECT col1, col2, col3 FROM ...")},m(a,g){N(a,e,g),gt(e,o[1]),N(a,n,g),G(t,a,g),N(a,r,g),G(i,a,g),s=!0,l||(c=Te(e,"input",o[2]),l=!0)},p(a,[g]){g&2&&gt(e,a[1]);const h={};g&3&&(h.onSubmit=a[3]),t.$set(h);const x={};g&18&&(x.$$scope={dirty:g,ctx:a}),i.$set(x)},i(a){s||(L(t.$$.fragment,a),L(i.$$.fragment,a),s=!0)},o(a){A(t.$$.fragment,a),A(i.$$.fragment,a),s=!1},d(a){a&&(B(e),B(n),B(r)),Z(t,a),Z(i,a),l=!1,c()}}}function Oi(o,e,n){let t;et(o,Qt,l=>n(1,t=l));let{onSubmit:r}=e;function i(){t=this.value,Qt.set(t)}const s=()=>r(t);return o.$$set=l=>{"onSubmit"in l&&n(0,r=l.onSubmit)},[r,t,i,s]}class Ci extends ve{constructor(e){super(),be(this,e,Oi,Si,he,{onSubmit:0})}}function Li(o){let e,n,t,r,i,s;return t=new ut({props:{message:o[3],onSubmit:o[5]}}),{c(){e=E("textarea"),n=Q(),U(t.$$.fragment),d(e,"rows","6"),d(e,"class","block p-2.5 w-full text-blue-600 hover:text-blue-500 dark:text-blue-500 dark:hover:text-blue-400 bg-gray-50 rounded-lg border border-gray-300 focus:ring-blue-500 focus:border-blue-500 dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:focus:ring-blue-500 dark:focus:border-blue-500 font-mono"),d(e,"placeholder",o[2])},m(l,c){N(l,e,c),gt(e,o[0]),N(l,n,c),G(t,l,c),r=!0,i||(s=Te(e,"input",o[4]),i=!0)},p(l,[c]){(!r||c&4)&&d(e,"placeholder",l[2]),c&1&&gt(e,l[0]);const a={};c&8&&(a.message=l[3]),c&3&&(a.onSubmit=l[5]),t.$set(a)},i(l){r||(L(t.$$.fragment,l),r=!0)},o(l){A(t.$$.fragment,l),r=!1},d(l){l&&(B(e),B(n)),Z(t,l),i=!1,s()}}}function Ei(o,e,n){let{onSubmit:t}=e,{currentValue:r}=e,{placeholder:i}=e,{buttonText:s}=e;function l(){r=this.value,n(0,r)}const c=()=>t(r);return o.$$set=a=>{"onSubmit"in a&&n(1,t=a.onSubmit),"currentValue"in a&&n(0,r=a.currentValue),"placeholder"in a&&n(2,i=a.placeholder),"buttonText"in a&&n(3,s=a.buttonText)},[r,t,i,s,l,c]}class Ti extends ve{constructor(e){super(),be(this,e,Ei,Li,he,{onSubmit:1,currentValue:0,placeholder:2,buttonText:3})}}function ji(o){let e,n;return e=new ut({props:{message:"Play",onSubmit:o[2]}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,[r]){const i={};r&1&&(i.onSubmit=t[2]),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function rr(o){if("speechSynthesis"in window){const e=new SpeechSynthesisUtterance(o);e.lang="en-US",e.volume=1,e.rate=1,e.pitch=1,window.speechSynthesis.speak(e)}else console.error("SpeechSynthesis API is not supported in this browser.")}function Pi(o,e,n){let t;et(o,Nr,s=>n(1,t=s));let{message:r}=e;const i=()=>rr(r);return o.$$set=s=>{"message"in s&&n(0,r=s.message)},o.$$.update=()=>{o.$$.dirty&3&&t&&rr(r)},[r,t,i]}class qi extends ve{constructor(e){super(),be(this,e,Pi,ji,he,{message:0})}}function Ai(o){let e,n,t;return{c(){e=E("button"),e.textContent="Open Debugger",n=Q(),t=E("div"),t.innerHTML='<div class="flex justify-between items-center py-3 px-4 border-b dark:border-neutral-700"><h3 class="font-bold text-gray-800 dark:text-white">Server Logs</h3> <button type="button" class="flex justify-center items-center size-7 text-sm font-semibold rounded-full border border-transparent text-gray-800 hover:bg-gray-100 disabled:opacity-50 disabled:pointer-events-none dark:text-white dark:hover:bg-neutral-700" data-hs-overlay="#hs-overlay-right"><span class="sr-only">Close modal</span> <svg class="flex-shrink-0 size-4" xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path d="M18 6 6 18"></path><path d="m6 6 12 12"></path></svg></button></div> <div class="p-4"><p id="log-contents" class="text-gray-800 dark:text-neutral-400"></p></div>',d(e,"type","button"),d(e,"class","absolute top-0 right-0 m-1 ms-0 py-3 px-4 inline-flex items-center gap-x-2 text-sm font-semibold rounded-lg border border-transparent bg-blue-600 text-white hover:bg-blue-700 disabled:opacity-50 disabled:pointer-events-none"),d(e,"data-hs-overlay","#hs-overlay-right"),d(t,"id","hs-overlay-right"),d(t,"class","hs-overlay hs-overlay-open:translate-x-0 hidden translate-x-full fixed top-0 end-0 transition-all duration-300 transform h-full max-w-xs w-full z-[80] bg-white border-s dark:bg-neutral-800 dark:border-neutral-700 [--body-scroll:true] overflow-y-auto"),d(t,"tabindex","-1")},m(r,i){N(r,e,i),N(r,n,i),N(r,t,i)},p:Y,i:Y,o:Y,d(r){r&&(B(e),B(n),B(t))}}}class Mi extends ve{constructor(e){super(),be(this,e,null,Ai,he,{})}}function or(o,e,n){const t=o.slice();return t[11]=e[n],t}function ir(o,e,n){const t=o.slice();return t[14]=e[n],t}function sr(o,e,n){const t=o.slice();return t[17]=e[n],t}function lr(o,e,n){const t=o.slice();return t[17]=e[n],t}function ar(o){let e,n;return e=new Mi({}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function cr(o){let e,n;return e=new Fe({props:{$$slots:{default:[Ri]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&4194306&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function ur(o){let e,n;return e=new ut({props:{message:o[17],onSubmit:Ln}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&2&&(i.message=t[17]),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function Di(o){let e=o[1].header+"",n,t,r,i,s=Le(o[1].questions),l=[];for(let a=0;a<s.length;a+=1)l[a]=ur(lr(o,s,a));const c=a=>A(l[a],1,1,()=>{l[a]=null});return{c(){n=pe(e),t=Q();for(let a=0;a<l.length;a+=1)l[a].c();r=Ve()},m(a,g){N(a,n,g),N(a,t,g);for(let h=0;h<l.length;h+=1)l[h]&&l[h].m(a,g);N(a,r,g),i=!0},p(a,g){if((!i||g&2)&&e!==(e=a[1].header+"")&&De(n,e),g&2){s=Le(a[1].questions);let h;for(h=0;h<s.length;h+=1){const x=lr(a,s,h);l[h]?(l[h].p(x,g),L(l[h],1)):(l[h]=ur(x),l[h].c(),L(l[h],1),l[h].m(r.parentNode,r))}for(Se(),h=s.length;h<l.length;h+=1)c(h);Oe()}},i(a){if(!i){for(let g=0;g<s.length;g+=1)L(l[g]);i=!0}},o(a){l=l.filter(Boolean);for(let g=0;g<l.length;g+=1)A(l[g]);i=!1},d(a){a&&(B(n),B(t),B(r)),nt(l,a)}}}function Ri(o){let e,n;return e=new at({props:{$$slots:{default:[Di]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&4194306&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function Hi(o){let e,n;return e=new Fe({props:{$$slots:{default:[ts]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&4194312&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function Bi(o){let e,n;return e=new Fe({props:{$$slots:{default:[rs]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&4194312&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function Ni(o){let e,n;return e=new Ct({props:{message:"Put your SQL here",$$slots:{default:[os]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&4194304&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function Ii(o){let e,n,t,r,i,s,l,c,a,g;e=new Ct({props:{message:o[14].question}}),t=new Fe({props:{$$slots:{default:[ls]},$$scope:{ctx:o}}}),i=new Fe({props:{$$slots:{default:[as]},$$scope:{ctx:o}}}),l=new Fe({props:{$$slots:{default:[cs]},$$scope:{ctx:o}}});let h=o[14].summary&&fr(o);return{c(){U(e.$$.fragment),n=Q(),U(t.$$.fragment),r=Q(),U(i.$$.fragment),s=Q(),U(l.$$.fragment),c=Q(),h&&h.c(),a=Ve()},m(x,k){G(e,x,k),N(x,n,k),G(t,x,k),N(x,r,k),G(i,x,k),N(x,s,k),G(l,x,k),N(x,c,k),h&&h.m(x,k),N(x,a,k),g=!0},p(x,k){const q={};k&8&&(q.message=x[14].question),e.$set(q);const M={};k&4194312&&(M.$$scope={dirty:k,ctx:x}),t.$set(M);const y={};k&4194312&&(y.$$scope={dirty:k,ctx:x}),i.$set(y);const p={};k&4194312&&(p.$$scope={dirty:k,ctx:x}),l.$set(p),x[14].summary?h?(h.p(x,k),k&8&&L(h,1)):(h=fr(x),h.c(),L(h,1),h.m(a.parentNode,a)):h&&(Se(),A(h,1,1,()=>{h=null}),Oe())},i(x){g||(L(e.$$.fragment,x),L(t.$$.fragment,x),L(i.$$.fragment,x),L(l.$$.fragment,x),L(h),g=!0)},o(x){A(e.$$.fragment,x),A(t.$$.fragment,x),A(i.$$.fragment,x),A(l.$$.fragment,x),A(h),g=!1},d(x){x&&(B(n),B(r),B(s),B(c),B(a)),Z(e,x),Z(t,x),Z(i,x),Z(l,x),h&&h.d(x)}}}function zi(o){let e,n;return e=new Fe({props:{$$slots:{default:[ds]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&4194313&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function Vi(o){let e,n;return e=new Fe({props:{$$slots:{default:[ps]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&4194312&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function Gi(o){let e,n;return e=new Ct({props:{message:"No, the results were not correct."}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p:Y,i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function Zi(o){let e,n;return e=new Ct({props:{message:"Yes, the results were correct."}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p:Y,i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function Ui(o){let e,n,t=o[0].ask_results_correct&&pr(o);return{c(){t&&t.c(),e=Ve()},m(r,i){t&&t.m(r,i),N(r,e,i),n=!0},p(r,i){r[0].ask_results_correct?t?i&1&&L(t,1):(t=pr(r),t.c(),L(t,1),t.m(e.parentNode,e)):t&&(Se(),A(t,1,1,()=>{t=null}),Oe())},i(r){n||(L(t),n=!0)},o(r){A(t),n=!1},d(r){r&&B(e),t&&t.d(r)}}}function Wi(o){let e,n,t=o[0].ask_results_correct&&gr(o);return{c(){t&&t.c(),e=Ve()},m(r,i){t&&t.m(r,i),N(r,e,i),n=!0},p(r,i){r[0].ask_results_correct?t?i&1&&L(t,1):(t=gr(r),t.c(),L(t,1),t.m(e.parentNode,e)):t&&(Se(),A(t,1,1,()=>{t=null}),Oe())},i(r){n||(L(t),n=!0)},o(r){A(t),n=!1},d(r){r&&B(e),t&&t.d(r)}}}function Qi(o){let e,n;return e=new Ct({props:{message:"Change the chart based on these instructions",$$slots:{default:[ys]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&4194304&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function Fi(o){let e,n,t=o[0].chart&&mr(o);return{c(){t&&t.c(),e=Ve()},m(r,i){t&&t.m(r,i),N(r,e,i),n=!0},p(r,i){r[0].chart?t?(t.p(r,i),i&1&&L(t,1)):(t=mr(r),t.c(),L(t,1),t.m(e.parentNode,e)):t&&(Se(),A(t,1,1,()=>{t=null}),Oe())},i(r){n||(L(t),n=!0)},o(r){A(t),n=!1},d(r){r&&B(e),t&&t.d(r)}}}function Ji(o){let e,n,t=o[0].table&&yr(o);return{c(){t&&t.c(),e=Ve()},m(r,i){t&&t.m(r,i),N(r,e,i),n=!0},p(r,i){r[0].table?t?(t.p(r,i),i&1&&L(t,1)):(t=yr(r),t.c(),L(t,1),t.m(e.parentNode,e)):t&&(Se(),A(t,1,1,()=>{t=null}),Oe())},i(r){n||(L(t),n=!0)},o(r){A(t),n=!1},d(r){r&&B(e),t&&t.d(r)}}}function Yi(o){let e,n;return e=new Fe({props:{$$slots:{default:[$s]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&4194312&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function Ki(o){let e,n,t=o[0].sql==!0&&vr(o);return{c(){t&&t.c(),e=Ve()},m(r,i){t&&t.m(r,i),N(r,e,i),n=!0},p(r,i){r[0].sql==!0?t?(t.p(r,i),i&1&&L(t,1)):(t=vr(r),t.c(),L(t,1),t.m(e.parentNode,e)):t&&(Se(),A(t,1,1,()=>{t=null}),Oe())},i(r){n||(L(t),n=!0)},o(r){A(t),n=!1},d(r){r&&B(e),t&&t.d(r)}}}function Xi(o){let e,n;return e=new Ct({props:{message:o[14].question}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&8&&(i.message=t[14].question),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function es(o){let e=JSON.stringify(o[14])+"",n;return{c(){n=pe(e)},m(t,r){N(t,n,r)},p(t,r){r&8&&e!==(e=JSON.stringify(t[14])+"")&&De(n,e)},d(t){t&&B(n)}}}function ts(o){let e,n;return e=new at({props:{$$slots:{default:[es]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&4194312&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function ns(o){let e=o[14].text+"",n;return{c(){n=pe(e)},m(t,r){N(t,n,r)},p(t,r){r&8&&e!==(e=t[14].text+"")&&De(n,e)},d(t){t&&B(n)}}}function rs(o){let e,n,t,r;return e=new at({props:{$$slots:{default:[ns]},$$scope:{ctx:o}}}),t=new qi({props:{message:o[14].text}}),{c(){U(e.$$.fragment),n=Q(),U(t.$$.fragment)},m(i,s){G(e,i,s),N(i,n,s),G(t,i,s),r=!0},p(i,s){const l={};s&4194312&&(l.$$scope={dirty:s,ctx:i}),e.$set(l);const c={};s&8&&(c.message=i[14].text),t.$set(c)},i(i){r||(L(e.$$.fragment,i),L(t.$$.fragment,i),r=!0)},o(i){A(e.$$.fragment,i),A(t.$$.fragment,i),r=!1},d(i){i&&B(n),Z(e,i),Z(t,i)}}}function os(o){let e,n;return e=new Ci({props:{onSubmit:Co}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p:Y,i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function is(o){let e=o[14].sql+"",n;return{c(){n=pe(e)},m(t,r){N(t,n,r)},p(t,r){r&8&&e!==(e=t[14].sql+"")&&De(n,e)},d(t){t&&B(n)}}}function ss(o){let e,n;return e=new Wr({props:{$$slots:{default:[is]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&4194312&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function ls(o){let e,n;return e=new at({props:{$$slots:{default:[ss]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&4194312&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function as(o){let e,n;return e=new Gr({props:{id:o[14].id,df:o[14].df}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&8&&(i.id=t[14].id),r&8&&(i.df=t[14].df),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function cs(o){let e,n;return e=new Zr({props:{fig:o[14].fig}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&8&&(i.fig=t[14].fig),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function fr(o){let e,n;return e=new Fe({props:{$$slots:{default:[fs]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&4194312&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function us(o){let e=o[14].summary+"",n;return{c(){n=pe(e)},m(t,r){N(t,n,r)},p(t,r){r&8&&e!==(e=t[14].summary+"")&&De(n,e)},d(t){t&&B(n)}}}function fs(o){let e,n;return e=new at({props:{$$slots:{default:[us]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&4194312&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function dr(o){let e,n;function t(){return o[9](o[14])}return e=new ut({props:{message:"Auto Fix",onSubmit:t}}),{c(){U(e.$$.fragment)},m(r,i){G(e,r,i),n=!0},p(r,i){o=r;const s={};i&8&&(s.onSubmit=t),e.$set(s)},i(r){n||(L(e.$$.fragment,r),n=!0)},o(r){A(e.$$.fragment,r),n=!1},d(r){Z(e,r)}}}function ds(o){let e,n,t,r,i,s;e=new En({props:{message:o[14].error}}),t=new ut({props:{message:"Manually Fix",onSubmit:o[8]}});let l=o[0].auto_fix_sql&&dr(o);return{c(){U(e.$$.fragment),n=Q(),U(t.$$.fragment),r=Q(),l&&l.c(),i=Ve()},m(c,a){G(e,c,a),N(c,n,a),G(t,c,a),N(c,r,a),l&&l.m(c,a),N(c,i,a),s=!0},p(c,a){const g={};a&8&&(g.message=c[14].error),e.$set(g),c[0].auto_fix_sql?l?(l.p(c,a),a&1&&L(l,1)):(l=dr(c),l.c(),L(l,1),l.m(i.parentNode,i)):l&&(Se(),A(l,1,1,()=>{l=null}),Oe())},i(c){s||(L(e.$$.fragment,c),L(t.$$.fragment,c),L(l),s=!0)},o(c){A(e.$$.fragment,c),A(t.$$.fragment,c),A(l),s=!1},d(c){c&&(B(n),B(r),B(i)),Z(e,c),Z(t,c),l&&l.d(c)}}}function ps(o){let e,n;return e=new En({props:{message:o[14].error}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&8&&(i.message=t[14].error),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function pr(o){let e,n;return e=new Ct({props:{message:"",$$slots:{default:[gs]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function gs(o){let e,n,t,r;return e=new ut({props:{message:"Yes",onSubmit:o[6]}}),t=new ut({props:{message:"No",onSubmit:o[7]}}),{c(){U(e.$$.fragment),n=Q(),U(t.$$.fragment)},m(i,s){G(e,i,s),N(i,n,s),G(t,i,s),r=!0},p:Y,i(i){r||(L(e.$$.fragment,i),L(t.$$.fragment,i),r=!0)},o(i){A(e.$$.fragment,i),A(t.$$.fragment,i),r=!1},d(i){i&&B(n),Z(e,i),Z(t,i)}}}function gr(o){let e,n;return e=new Fe({props:{$$slots:{default:[hs]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function ms(o){let e;return{c(){e=pe("Were the results correct?")},m(n,t){N(n,e,t)},d(n){n&&B(e)}}}function hs(o){let e,n;return e=new at({props:{$$slots:{default:[ms]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&4194304&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function ys(o){let e,n;return e=new Ti({props:{onSubmit:o[5],placeholder:"Make the line red",buttonText:"Update Chart",currentValue:""}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p:Y,i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function mr(o){let e,n,t,r;e=new Fe({props:{$$slots:{default:[bs]},$$scope:{ctx:o}}});let i=o[0].redraw_chart&&hr(o);return{c(){U(e.$$.fragment),n=Q(),i&&i.c(),t=Ve()},m(s,l){G(e,s,l),N(s,n,l),i&&i.m(s,l),N(s,t,l),r=!0},p(s,l){const c={};l&4194312&&(c.$$scope={dirty:l,ctx:s}),e.$set(c),s[0].redraw_chart?i?l&1&&L(i,1):(i=hr(s),i.c(),L(i,1),i.m(t.parentNode,t)):i&&(Se(),A(i,1,1,()=>{i=null}),Oe())},i(s){r||(L(e.$$.fragment,s),L(i),r=!0)},o(s){A(e.$$.fragment,s),A(i),r=!1},d(s){s&&(B(n),B(t)),Z(e,s),i&&i.d(s)}}}function bs(o){let e,n;return e=new Zr({props:{fig:o[14].fig}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&8&&(i.fig=t[14].fig),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function hr(o){let e,n;return e=new Fe({props:{$$slots:{default:[vs]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function vs(o){let e,n;return e=new ut({props:{message:"Redraw Chart",onSubmit:Lo}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p:Y,i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function yr(o){let e,n;return e=new Fe({props:{$$slots:{default:[_s]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&4194312&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function _s(o){let e,n;return e=new Gr({props:{id:o[14].id,df:o[14].df}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&8&&(i.id=t[14].id),r&8&&(i.df=t[14].df),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function br(o){let e,n;return e=new ut({props:{message:o[17],onSubmit:Ln}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&8&&(i.message=t[17]),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function ws(o){let e=o[14].header+"",n,t,r,i,s=Le(o[14].questions),l=[];for(let a=0;a<s.length;a+=1)l[a]=br(sr(o,s,a));const c=a=>A(l[a],1,1,()=>{l[a]=null});return{c(){n=pe(e),t=Q();for(let a=0;a<l.length;a+=1)l[a].c();r=Ve()},m(a,g){N(a,n,g),N(a,t,g);for(let h=0;h<l.length;h+=1)l[h]&&l[h].m(a,g);N(a,r,g),i=!0},p(a,g){if((!i||g&8)&&e!==(e=a[14].header+"")&&De(n,e),g&8){s=Le(a[14].questions);let h;for(h=0;h<s.length;h+=1){const x=sr(a,s,h);l[h]?(l[h].p(x,g),L(l[h],1)):(l[h]=br(x),l[h].c(),L(l[h],1),l[h].m(r.parentNode,r))}for(Se(),h=s.length;h<l.length;h+=1)c(h);Oe()}},i(a){if(!i){for(let g=0;g<s.length;g+=1)L(l[g]);i=!0}},o(a){l=l.filter(Boolean);for(let g=0;g<l.length;g+=1)A(l[g]);i=!1},d(a){a&&(B(n),B(t),B(r)),nt(l,a)}}}function $s(o){let e,n;return e=new at({props:{$$slots:{default:[ws]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&4194312&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function vr(o){let e,n;return e=new Fe({props:{$$slots:{default:[Ss]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&4194312&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function ks(o){let e=o[14].text+"",n;return{c(){n=pe(e)},m(t,r){N(t,n,r)},p(t,r){r&8&&e!==(e=t[14].text+"")&&De(n,e)},d(t){t&&B(n)}}}function xs(o){let e,n;return e=new Wr({props:{$$slots:{default:[ks]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&4194312&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function Ss(o){let e,n;return e=new at({props:{$$slots:{default:[xs]},$$scope:{ctx:o}}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&4194312&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function _r(o){let e,n,t,r;const i=[Xi,Ki,Yi,Ji,Fi,Qi,Wi,Ui,Zi,Gi,Vi,zi,Ii,Ni,Bi,Hi],s=[];function l(c,a){return c[14].type==="user_question"?0:c[14].type==="sql"?1:c[14].type==="question_list"?2:c[14].type==="df"?3:c[14].type==="plotly_figure"?4:c[14].type==="chart_modification"?5:c[14].type==="feedback_question"?6:c[14].type==="feedback_buttons"?7:c[14].type==="feedback_correct"?8:c[14].type==="feedback_incorrect"?9:c[14].type==="error"?10:c[14].type==="sql_error"?11:c[14].type==="question_cache"?12:c[14].type==="user_sql"?13:c[14].type==="text"?14:15}return e=l(o),n=s[e]=i[e](o),{c(){n.c(),t=Ve()},m(c,a){s[e].m(c,a),N(c,t,a),r=!0},p(c,a){let g=e;e=l(c),e===g?s[e].p(c,a):(Se(),A(s[g],1,1,()=>{s[g]=null}),Oe(),n=s[e],n?n.p(c,a):(n=s[e]=i[e](c),n.c()),L(n,1),n.m(t.parentNode,t))},i(c){r||(L(n),r=!0)},o(c){A(n),r=!1},d(c){c&&B(t),s[e].d(c)}}}function wr(o){let e,n;return e=new ui({}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function Os(o){let e,n;return e=new Xo({props:{onSubmit:Ln}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p:Y,i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function Cs(o){let e,n,t,r;e=new Ur({props:{message:"New Question",onSubmit:dn}});let i=Le(o[3]),s=[];for(let c=0;c<i.length;c+=1)s[c]=kr(or(o,i,c));const l=c=>A(s[c],1,1,()=>{s[c]=null});return{c(){U(e.$$.fragment),n=Q();for(let c=0;c<s.length;c+=1)s[c].c();t=Ve()},m(c,a){G(e,c,a),N(c,n,a);for(let g=0;g<s.length;g+=1)s[g]&&s[g].m(c,a);N(c,t,a),r=!0},p(c,a){if(a&8){i=Le(c[3]);let g;for(g=0;g<i.length;g+=1){const h=or(c,i,g);s[g]?(s[g].p(h,a),L(s[g],1)):(s[g]=kr(h),s[g].c(),L(s[g],1),s[g].m(t.parentNode,t))}for(Se(),g=i.length;g<s.length;g+=1)l(g);Oe()}},i(c){if(!r){L(e.$$.fragment,c);for(let a=0;a<i.length;a+=1)L(s[a]);r=!0}},o(c){A(e.$$.fragment,c),s=s.filter(Boolean);for(let a=0;a<s.length;a+=1)A(s[a]);r=!1},d(c){c&&(B(n),B(t)),Z(e,c),nt(s,c)}}}function $r(o){let e,n;function t(){return o[10](o[11])}return e=new Ur({props:{message:"Re-Run SQL",onSubmit:t}}),{c(){U(e.$$.fragment)},m(r,i){G(e,r,i),n=!0},p(r,i){o=r;const s={};i&8&&(s.onSubmit=t),e.$set(s)},i(r){n||(L(e.$$.fragment,r),n=!0)},o(r){A(e.$$.fragment,r),n=!1},d(r){Z(e,r)}}}function kr(o){let e,n,t=o[11].type==="question_cache"&&$r(o);return{c(){t&&t.c(),e=Ve()},m(r,i){t&&t.m(r,i),N(r,e,i),n=!0},p(r,i){r[11].type==="question_cache"?t?(t.p(r,i),i&8&&L(t,1)):(t=$r(r),t.c(),L(t,1),t.m(e.parentNode,e)):t&&(Se(),A(t,1,1,()=>{t=null}),Oe())},i(r){n||(L(t),n=!0)},o(r){A(t),n=!1},d(r){r&&B(e),t&&t.d(r)}}}function Ls(o){let e,n,t,r,i,s,l,c,a,g,h,x,k,q,M;t=new No({});let y=o[0].debug&&ar(),p=o[1]&&o[1].type=="question_list"&&!o[2]&&cr(o),m=Le(o[3]),w=[];for(let _=0;_<m.length;_+=1)w[_]=_r(ir(o,m,_));const D=_=>A(w[_],1,1,()=>{w[_]=null});let P=o[4]&&wr();h=new ti({});const C=[Cs,Os],f=[];function u(_,j){return _[2]?0:1}return k=u(o),q=f[k]=C[k](o),{c(){e=E("div"),n=E("div"),U(t.$$.fragment),r=Q(),y&&y.c(),i=Q(),p&&p.c(),s=Q(),l=E("ul");for(let _=0;_<w.length;_+=1)w[_].c();c=Q(),P&&P.c(),a=Q(),g=E("footer"),U(h.$$.fragment),x=Q(),q.c(),d(l,"class","mt-16 space-y-5"),d(n,"class","py-10 lg:py-14"),d(g,"class","max-w-4xl mx-auto sticky bottom-0 z-10 p-3 sm:py-6"),d(e,"class","relative h-screen w-full lg:pl-64")},m(_,j){N(_,e,j),v(e,n),G(t,n,null),v(n,r),y&&y.m(n,null),v(n,i),p&&p.m(n,null),v(n,s),v(n,l);for(let O=0;O<w.length;O+=1)w[O]&&w[O].m(l,null);v(l,c),P&&P.m(l,null),v(e,a),v(e,g),G(h,g,null),v(g,x),f[k].m(g,null),M=!0},p(_,[j]){if(_[0].debug?y?j&1&&L(y,1):(y=ar(),y.c(),L(y,1),y.m(n,i)):y&&(Se(),A(y,1,1,()=>{y=null}),Oe()),_[1]&&_[1].type=="question_list"&&!_[2]?p?(p.p(_,j),j&6&&L(p,1)):(p=cr(_),p.c(),L(p,1),p.m(n,s)):p&&(Se(),A(p,1,1,()=>{p=null}),Oe()),j&9){m=Le(_[3]);let T;for(T=0;T<m.length;T+=1){const H=ir(_,m,T);w[T]?(w[T].p(H,j),L(w[T],1)):(w[T]=_r(H),w[T].c(),L(w[T],1),w[T].m(l,c))}for(Se(),T=m.length;T<w.length;T+=1)D(T);Oe()}_[4]?P?j&16&&L(P,1):(P=wr(),P.c(),L(P,1),P.m(l,null)):P&&(Se(),A(P,1,1,()=>{P=null}),Oe());let O=k;k=u(_),k===O?f[k].p(_,j):(Se(),A(f[O],1,1,()=>{f[O]=null}),Oe(),q=f[k],q?q.p(_,j):(q=f[k]=C[k](_),q.c()),L(q,1),q.m(g,null))},i(_){if(!M){L(t.$$.fragment,_),L(y),L(p);for(let j=0;j<m.length;j+=1)L(w[j]);L(P),L(h.$$.fragment,_),L(q),M=!0}},o(_){A(t.$$.fragment,_),A(y),A(p),w=w.filter(Boolean);for(let j=0;j<w.length;j+=1)A(w[j]);A(P),A(h.$$.fragment,_),A(q),M=!1},d(_){_&&B(e),Z(t),y&&y.d(),p&&p.d(),nt(w,_),P&&P.d(),Z(h),f[k].d()}}}function Es(o,e,n){let t,r,i,s,l;return et(o,Ot,q=>n(0,t=q)),et(o,On,q=>n(1,r=q)),et(o,un,q=>n(2,i=q)),et(o,Bt,q=>n(3,s=q)),et(o,Ut,q=>n(4,l=q)),[t,r,i,s,l,q=>{To(q)},()=>{Eo()},()=>{Un()},()=>{Un()},q=>{Oo(q.error)},q=>q.type==="question_cache"?mo(q.id):void 0]}class Ts extends ve{constructor(e){super(),be(this,e,Es,Ls,he,{})}}function js(o){let e,n,t,r,i,s,l,c,a,g,h,x,k,q,M,y,p,m,w;return{c(){e=E("div"),n=E("div"),t=E("div"),r=E("div"),i=E("h3"),i.textContent="Are you sure?",s=Q(),l=E("button"),l.innerHTML='<span class="sr-only">Close</span> <svg class="w-3.5 h-3.5" width="8" height="8" viewBox="0 0 8 8" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M0.258206 1.00652C0.351976 0.912791 0.479126 0.860131 0.611706 0.860131C0.744296 0.860131 0.871447 0.912791 0.965207 1.00652L3.61171 3.65302L6.25822 1.00652C6.30432 0.958771 6.35952 0.920671 6.42052 0.894471C6.48152 0.868271 6.54712 0.854471 6.61352 0.853901C6.67992 0.853321 6.74572 0.865971 6.80722 0.891111C6.86862 0.916251 6.92442 0.953381 6.97142 1.00032C7.01832 1.04727 7.05552 1.1031 7.08062 1.16454C7.10572 1.22599 7.11842 1.29183 7.11782 1.35822C7.11722 1.42461 7.10342 1.49022 7.07722 1.55122C7.05102 1.61222 7.01292 1.6674 6.96522 1.71352L4.31871 4.36002L6.96522 7.00648C7.05632 7.10078 7.10672 7.22708 7.10552 7.35818C7.10442 7.48928 7.05182 7.61468 6.95912 7.70738C6.86642 7.80018 6.74102 7.85268 6.60992 7.85388C6.47882 7.85498 6.35252 7.80458 6.25822 7.71348L3.61171 5.06702L0.965207 7.71348C0.870907 7.80458 0.744606 7.85498 0.613506 7.85388C0.482406 7.85268 0.357007 7.80018 0.264297 7.70738C0.171597 7.61468 0.119017 7.48928 0.117877 7.35818C0.116737 7.22708 0.167126 7.10078 0.258206 7.00648L2.90471 4.36002L0.258206 1.71352C0.164476 1.61976 0.111816 1.4926 0.111816 1.36002C0.111816 1.22744 0.164476 1.10028 0.258206 1.00652Z" fill="currentColor"></path></svg>',c=Q(),a=E("div"),g=E("p"),h=pe(o[0]),x=Q(),k=E("div"),q=E("button"),q.textContent="Close",M=Q(),y=E("button"),p=pe(o[1]),d(i,"class","font-bold text-gray-800 dark:text-white"),d(l,"type","button"),d(l,"class","hs-dropdown-toggle inline-flex flex-shrink-0 justify-center items-center h-8 w-8 rounded-md text-gray-500 hover:text-gray-400 focus:outline-none focus:ring-2 focus:ring-gray-400 focus:ring-offset-2 focus:ring-offset-white transition-all text-sm dark:focus:ring-gray-700 dark:focus:ring-offset-gray-800"),d(l,"data-hs-overlay","#hs-vertically-centered-modal"),d(r,"class","flex justify-between items-center py-3 px-4 border-b dark:border-gray-700"),d(g,"class","text-gray-800 dark:text-gray-400"),d(a,"class","p-4 overflow-y-auto"),d(q,"type","button"),d(q,"class","hs-dropdown-toggle py-3 px-4 inline-flex justify-center items-center gap-2 rounded-md border font-medium bg-white text-gray-700 shadow-sm align-middle hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-offset-white focus:ring-blue-600 transition-all text-sm dark:bg-slate-900 dark:hover:bg-slate-800 dark:border-gray-700 dark:text-gray-400 dark:hover:text-white dark:focus:ring-offset-gray-800"),d(q,"data-hs-overlay","#hs-vertically-centered-modal"),d(y,"class","py-3 px-4 inline-flex justify-center items-center gap-2 rounded-md border border-transparent font-semibold bg-blue-500 text-white hover:bg-blue-600 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 transition-all text-sm dark:focus:ring-offset-gray-800"),d(k,"class","flex justify-end items-center gap-x-2 py-3 px-4 border-t dark:border-gray-700"),d(t,"class","flex flex-col bg-white border shadow-sm rounded-xl dark:bg-gray-800 dark:border-gray-700 dark:shadow-slate-700/[.7]"),d(n,"class","hs-overlay-open:mt-7 hs-overlay-open:opacity-100 hs-overlay-open:duration-500 mt-0 opacity-0 ease-out transition-all sm:max-w-lg sm:w-full m-3 sm:mx-auto min-h-[calc(100%-3.5rem)] flex items-center"),d(e,"class","hs-overlay open w-full h-full fixed top-0 left-0 z-[60] overflow-x-hidden overflow-y-auto")},m(D,P){N(D,e,P),v(e,n),v(n,t),v(t,r),v(r,i),v(r,s),v(r,l),v(t,c),v(t,a),v(a,g),v(g,h),v(t,x),v(t,k),v(k,q),v(k,M),v(k,y),v(y,p),m||(w=[Te(l,"click",function(){Dt(o[2])&&o[2].apply(this,arguments)}),Te(q,"click",function(){Dt(o[2])&&o[2].apply(this,arguments)}),Te(y,"click",function(){Dt(o[3])&&o[3].apply(this,arguments)})],m=!0)},p(D,[P]){o=D,P&1&&De(h,o[0]),P&2&&De(p,o[1])},i:Y,o:Y,d(D){D&&B(e),m=!1,mt(w)}}}function Ps(o,e,n){let{message:t}=e,{buttonLabel:r}=e,{onClose:i}=e,{onConfirm:s}=e;return o.$$set=l=>{"message"in l&&n(0,t=l.message),"buttonLabel"in l&&n(1,r=l.buttonLabel),"onClose"in l&&n(2,i=l.onClose),"onConfirm"in l&&n(3,s=l.onConfirm)},[t,r,i,s]}class qs extends ve{constructor(e){super(),be(this,e,Ps,js,he,{message:0,buttonLabel:1,onClose:2,onConfirm:3})}}function xr(o,e,n){const t=o.slice();return t[10]=e[n].name,t[11]=e[n].description,t[12]=e[n].example,t}function Sr(o){let e,n,t,r,i,s,l,c,a,g,h,x;return g=no(o[7][0]),{c(){e=E("div"),n=E("div"),t=E("input"),r=Q(),i=E("label"),s=E("span"),s.textContent=`${o[10]}`,l=Q(),c=E("span"),c.textContent=`${o[11]}`,a=Q(),d(t,"id","hs-radio-"+o[10]),t.__value=o[10],gt(t,t.__value),d(t,"name","hs-radio-with-description"),d(t,"type","radio"),d(t,"class","border-gray-200 rounded-full text-blue-600 focus:ring-blue-500 dark:bg-gray-800 dark:border-gray-700 dark:checked:bg-blue-500 dark:checked:border-blue-500 dark:focus:ring-offset-gray-800"),d(t,"aria-describedby","hs-radio-delete-description"),d(n,"class","flex items-center h-5 mt-1"),d(s,"class","block text-sm font-semibold text-gray-800 dark:text-gray-300"),d(c,"id","hs-radio-ddl-description"),d(c,"class","block text-sm text-gray-600 dark:text-gray-500"),d(i,"for","hs-radio-"+o[10]),d(i,"class","ml-3"),d(e,"class","relative flex items-start"),g.p(t)},m(k,q){N(k,e,q),v(e,n),v(n,t),t.checked=t.__value===o[0],v(e,r),v(e,i),v(i,s),v(i,l),v(i,c),v(e,a),h||(x=Te(t,"change",o[6]),h=!0)},p(k,q){q&1&&(t.checked=t.__value===k[0])},d(k){k&&B(e),g.r(),h=!1,x()}}}function As(o){let e,n,t,r,i,s,l,c,a,g,h,x,k,q,M,y,p,m,w,D,P,C,f,u,_,j=Le(o[3]),O=[];for(let T=0;T<j.length;T+=1)O[T]=Sr(xr(o,j,T));return{c(){var T;e=E("div"),n=E("div"),t=E("div"),r=E("div"),i=E("h2"),i.textContent="Add Training Data",s=Q(),l=E("button"),l.innerHTML='<span class="sr-only">Close</span> <svg class="w-3.5 h-3.5" width="8" height="8" viewBox="0 0 8 8" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M0.258206 1.00652C0.351976 0.912791 0.479126 0.860131 0.611706 0.860131C0.744296 0.860131 0.871447 0.912791 0.965207 1.00652L3.61171 3.65302L6.25822 1.00652C6.30432 0.958771 6.35952 0.920671 6.42052 0.894471C6.48152 0.868271 6.54712 0.854471 6.61352 0.853901C6.67992 0.853321 6.74572 0.865971 6.80722 0.891111C6.86862 0.916251 6.92442 0.953381 6.97142 1.00032C7.01832 1.04727 7.05552 1.1031 7.08062 1.16454C7.10572 1.22599 7.11842 1.29183 7.11782 1.35822C7.11722 1.42461 7.10342 1.49022 7.07722 1.55122C7.05102 1.61222 7.01292 1.6674 6.96522 1.71352L4.31871 4.36002L6.96522 7.00648C7.05632 7.10078 7.10672 7.22708 7.10552 7.35818C7.10442 7.48928 7.05182 7.61468 6.95912 7.70738C6.86642 7.80018 6.74102 7.85268 6.60992 7.85388C6.47882 7.85498 6.35252 7.80458 6.25822 7.71348L3.61171 5.06702L0.965207 7.71348C0.870907 7.80458 0.744606 7.85498 0.613506 7.85388C0.482406 7.85268 0.357007 7.80018 0.264297 7.70738C0.171597 7.61468 0.119017 7.48928 0.117877 7.35818C0.116737 7.22708 0.167126 7.10078 0.258206 7.00648L2.90471 4.36002L0.258206 1.71352C0.164476 1.61976 0.111816 1.4926 0.111816 1.36002C0.111816 1.22744 0.164476 1.10028 0.258206 1.00652Z" fill="currentColor"></path></svg>',c=Q(),a=E("span"),a.textContent="Training Data Type",g=Q(),h=E("div");for(let H=0;H<O.length;H+=1)O[H].c();x=Q(),k=E("div"),q=E("label"),M=pe("Your "),y=pe(o[0]),p=Q(),m=E("div"),w=E("textarea"),P=Q(),C=E("div"),f=E("button"),f.textContent="Save",d(i,"class","text-xl text-gray-800 font-bold sm:text-3xl dark:text-white"),d(l,"type","button"),d(l,"class","hs-dropdown-toggle inline-flex flex-shrink-0 justify-center items-center h-8 w-8 rounded-md text-gray-500 hover:text-gray-400 focus:outline-none focus:ring-2 focus:ring-gray-400 focus:ring-offset-2 focus:ring-offset-white transition-all text-sm dark:focus:ring-gray-700 dark:focus:ring-offset-gray-800"),d(l,"data-hs-overlay","#hs-vertically-centered-modal"),d(r,"class","flex justify-between items-center py-3 px-4 border-b dark:border-gray-700 mb-2"),d(a,"class","block mb-2 text-sm font-medium dark:text-white"),d(h,"class","grid space-y-3 mb-1"),d(q,"for","hs-feedback-post-comment-textarea-1"),d(q,"class","block mt-2 mb-2 text-sm font-medium dark:text-white"),d(w,"id","hs-feedback-post-comment-textarea-1"),d(w,"name","hs-feedback-post-comment-textarea-1"),d(w,"rows","3"),d(w,"class","py-3 px-4 block w-full border border-gray-200 rounded-md text-sm focus:border-blue-500 focus:ring-blue-500 sm:p-4 dark:bg-gray-800 dark:border-gray-700 dark:text-gray-400"),d(w,"placeholder",D=((T=o[3].find(o[8]))==null?void 0:T.example)??"No example available"),d(m,"class","mt-1"),d(k,"class","mt-2 border-t dark:border-gray-700"),d(f,"class","py-3 px-4 inline-flex justify-center items-center gap-2 rounded-md border border-transparent font-semibold bg-blue-500 text-white hover:bg-blue-600 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 transition-all dark:focus:ring-offset-gray-800"),d(C,"class","mt-6 grid"),d(t,"class","mt-5 p-4 relative z-10 bg-white border rounded-xl sm:mt-10 md:p-10 dark:bg-gray-800 dark:border-gray-700"),d(n,"class","mx-auto max-w-2xl"),d(e,"class","max-w-[85rem] px-4 py-10 sm:px-6 lg:px-8 lg:py-14 mx-auto")},m(T,H){N(T,e,H),v(e,n),v(n,t),v(t,r),v(r,i),v(r,s),v(r,l),v(t,c),v(t,a),v(t,g),v(t,h);for(let I=0;I<O.length;I+=1)O[I]&&O[I].m(h,null);v(t,x),v(t,k),v(k,q),v(q,M),v(q,y),v(k,p),v(k,m),v(m,w),gt(w,o[2]),v(t,P),v(t,C),v(C,f),u||(_=[Te(l,"click",function(){Dt(o[1])&&o[1].apply(this,arguments)}),Te(w,"input",o[9]),Te(f,"click",o[4])],u=!0)},p(T,[H]){var I;if(o=T,H&9){j=Le(o[3]);let F;for(F=0;F<j.length;F+=1){const J=xr(o,j,F);O[F]?O[F].p(J,H):(O[F]=Sr(J),O[F].c(),O[F].m(h,null))}for(;F<O.length;F+=1)O[F].d(1);O.length=j.length}H&1&&De(y,o[0]),H&1&&D!==(D=((I=o[3].find(o[8]))==null?void 0:I.example)??"No example available")&&d(w,"placeholder",D),H&4&&gt(w,o[2])},i:Y,o:Y,d(T){T&&B(e),nt(O,T),u=!1,mt(_)}}}function Ms(o,e,n){let{onDismiss:t}=e,{onTrain:r}=e,{selectedTrainingDataType:i="SQL"}=e,s=[{name:"DDL",description:"These are the CREATE TABLE statements that define your database structure.",example:"CREATE TABLE table_name (column_1 datatype, column_2 datatype, column_3 datatype);"},{name:"Documentation",description:"This can be any text-based documentation. Keep the chunks small and focused on a single topic.",example:"Our definition of ABC is XYZ."},{name:"SQL",description:"This can be any SQL statement that works. The more the merrier.",example:"SELECT column_1, column_2 FROM table_name;"}],l="";const c=()=>{r(l,i.toLowerCase())},a=[[]];function g(){i=this.__value,n(0,i)}const h=k=>k.name===i;function x(){l=this.value,n(2,l)}return o.$$set=k=>{"onDismiss"in k&&n(1,t=k.onDismiss),"onTrain"in k&&n(5,r=k.onTrain),"selectedTrainingDataType"in k&&n(0,i=k.selectedTrainingDataType)},[i,t,l,s,c,r,g,a,h,x]}class Ds extends ve{constructor(e){super(),be(this,e,Ms,As,he,{onDismiss:1,onTrain:5,selectedTrainingDataType:0})}}function Or(o,e,n){const t=o.slice();return t[21]=e[n],t}function Cr(o,e,n){const t=o.slice();return t[24]=e[n],t}function Lr(o,e,n){const t=o.slice();return t[24]=e[n],t}function Er(o){let e,n;return e=new Ds({props:{onDismiss:o[13],onTrain:o[0]}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&1&&(i.onTrain=t[0]),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function Rs(o){let e;return{c(){e=pe("Action")},m(n,t){N(n,e,t)},p:Y,d(n){n&&B(e)}}}function Hs(o){let e=o[24]+"",n;return{c(){n=pe(e)},m(t,r){N(t,n,r)},p:Y,d(t){t&&B(n)}}}function Tr(o){let e,n,t,r;function i(c,a){return c[24]!="id"?Hs:Rs}let l=i(o)(o);return{c(){e=E("th"),n=E("div"),t=E("span"),l.c(),r=Q(),d(t,"class","text-xs font-semibold uppercase tracking-wide text-gray-800 dark:text-gray-200"),d(n,"class","flex items-center gap-x-2"),d(e,"scope","col"),d(e,"class","px-6 py-3 text-left")},m(c,a){N(c,e,a),v(e,n),v(n,t),l.m(t,null),v(e,r)},p(c,a){l.p(c,a)},d(c){c&&B(e),l.d()}}}function Bs(o){let e,n,t;function r(){return o[18](o[21],o[24])}return{c(){e=E("button"),e.textContent="Delete",d(e,"type","button"),d(e,"class","py-2 px-3 inline-flex justify-center items-center gap-2 rounded-md border-2 border-red-200 font-semibold text-red-500 hover:text-white hover:bg-red-500 hover:border-red-500 focus:outline-none focus:ring-2 focus:ring-red-200 focus:ring-offset-2 transition-all text-sm dark:focus:ring-offset-gray-800")},m(i,s){N(i,e,s),n||(t=Te(e,"click",r),n=!0)},p(i,s){o=i},d(i){i&&B(e),n=!1,t()}}}function Ns(o){let e,n=o[21][o[24]]+"",t;return{c(){e=E("span"),t=pe(n),d(e,"class","text-gray-800 dark:text-gray-200")},m(r,i){N(r,e,i),v(e,t)},p(r,i){i&16&&n!==(n=r[21][r[24]]+"")&&De(t,n)},d(r){r&&B(e)}}}function jr(o){let e,n;function t(s,l){return s[24]!="id"?Ns:Bs}let i=t(o)(o);return{c(){e=E("td"),n=E("div"),i.c(),d(n,"class","px-6 py-3"),d(e,"class","h-px w-px ")},m(s,l){N(s,e,l),v(e,n),i.m(n,null)},p(s,l){i.p(s,l)},d(s){s&&B(e),i.d()}}}function Pr(o){let e,n,t=Le(o[8]),r=[];for(let i=0;i<t.length;i+=1)r[i]=jr(Cr(o,t,i));return{c(){e=E("tr");for(let i=0;i<r.length;i+=1)r[i].c();n=Q()},m(i,s){N(i,e,s);for(let l=0;l<r.length;l+=1)r[l]&&r[l].m(e,null);v(e,n)},p(i,s){if(s&304){t=Le(i[8]);let l;for(l=0;l<t.length;l+=1){const c=Cr(i,t,l);r[l]?r[l].p(c,s):(r[l]=jr(c),r[l].c(),r[l].m(e,n))}for(;l<r.length;l+=1)r[l].d(1);r.length=t.length}},d(i){i&&B(e),nt(r,i)}}}function qr(o){let e,n;return e=new qs({props:{message:"Are you sure you want to delete this?",buttonLabel:"Delete",onClose:o[19],onConfirm:o[20]}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&32&&(i.onClose=t[19]),r&34&&(i.onConfirm=t[20]),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function Is(o){let e,n,t,r,i,s,l,c,a,g,h,x,k,q,M,y,p,m,w,D,P,C,f,u,_,j,O,T=o[2]+1+"",H,I,F=Math.min(o[3],o[7].length)+"",J,Ce,ae,ot,tt,Ge,Ue,ht,_e,ft,We,yt,Nt,It,qe=o[6]&&Er(o),bt=Le(o[8]),Re=[];for(let ee=0;ee<bt.length;ee+=1)Re[ee]=Tr(Lr(o,bt,ee));let ze=Le(o[4]),je=[];for(let ee=0;ee<ze.length;ee+=1)je[ee]=Pr(Or(o,ze,ee));let Pe=o[5]!=null&&qr(o);return{c(){qe&&qe.c(),e=Q(),n=E("div"),t=E("div"),r=E("div"),i=E("div"),s=E("div"),l=E("div"),c=E("div"),c.innerHTML='<h2 class="text-xl font-semibold text-gray-800 dark:text-gray-200">Training Data</h2> <p class="text-sm text-gray-600 dark:text-gray-400">Add or remove training data. Good training data is the key to accuracy.</p>',a=Q(),g=E("div"),h=E("div"),x=E("button"),x.textContent="View all",k=Q(),q=E("button"),q.innerHTML=`<svg class="w-3 h-3" xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 16 16" fill="none"><path d="M2.63452 7.50001L13.6345 7.5M8.13452 13V2" stroke="currentColor" stroke-width="2" stroke-linecap="round"></path></svg>
                    Add training data`,M=Q(),y=E("table"),p=E("thead"),m=E("tr");for(let ee=0;ee<Re.length;ee+=1)Re[ee].c();w=Q(),D=E("tbody");for(let ee=0;ee<je.length;ee+=1)je[ee].c();P=Q(),C=E("div"),f=E("div"),u=E("p"),u.textContent="Showing:",_=Q(),j=E("div"),O=E("span"),H=pe(T),I=pe(" - "),J=pe(F),Ce=Q(),ae=E("p"),ae.textContent=`of ${o[7].length}`,ot=Q(),tt=E("div"),Ge=E("div"),Ue=E("button"),Ue.innerHTML=`<svg class="w-3 h-3" xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" viewBox="0 0 16 16"><path fill-rule="evenodd" d="M11.354 1.646a.5.5 0 0 1 0 .708L5.707 8l5.647 5.646a.5.5 0 0 1-.708.708l-6-6a.5.5 0 0 1 0-.708l6-6a.5.5 0 0 1 .708 0z"></path></svg>
                    Prev`,ht=Q(),_e=E("button"),_e.innerHTML=`Next
                    <svg class="w-3 h-3" xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" viewBox="0 0 16 16"><path fill-rule="evenodd" d="M4.646 1.646a.5.5 0 0 1 .708 0l6 6a.5.5 0 0 1 0 .708l-6 6a.5.5 0 0 1-.708-.708L10.293 8 4.646 2.354a.5.5 0 0 1 0-.708z"></path></svg>`,ft=Q(),Pe&&Pe.c(),We=Ve(),d(x,"class","py-2 px-3 inline-flex justify-center items-center gap-2 rounded-md border font-medium bg-white text-gray-700 shadow-sm align-middle hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-offset-white focus:ring-blue-600 transition-all text-sm dark:bg-slate-900 dark:hover:bg-slate-800 dark:border-gray-700 dark:text-gray-400 dark:hover:text-white dark:focus:ring-offset-gray-800"),d(q,"class","py-2 px-3 inline-flex justify-center items-center gap-2 rounded-md border border-transparent font-semibold bg-blue-500 text-white hover:bg-blue-600 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 transition-all text-sm dark:focus:ring-offset-gray-800"),d(h,"class","inline-flex gap-x-2"),d(l,"class","px-6 py-4 grid gap-3 md:flex md:justify-between md:items-center border-b border-gray-200 dark:border-gray-700"),d(p,"class","bg-gray-50 dark:bg-slate-800"),d(D,"class","divide-y divide-gray-200 dark:divide-gray-700"),d(y,"class","min-w-full divide-y divide-gray-200 dark:divide-gray-700"),d(u,"class","text-sm text-gray-600 dark:text-gray-400"),d(O,"class","py-2 px-3 pr-9 block w-full border-gray-200 rounded-md text-sm focus:border-blue-500 focus:ring-blue-500 dark:bg-slate-900 dark:border-gray-700 dark:text-gray-400"),d(j,"class","max-w-sm space-y-3"),d(ae,"class","text-sm text-gray-600 dark:text-gray-400"),d(f,"class","inline-flex items-center gap-x-2"),d(Ue,"type","button"),d(Ue,"class","py-2 px-3 inline-flex justify-center items-center gap-2 rounded-md border font-medium bg-white text-gray-700 shadow-sm align-middle hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-offset-white focus:ring-blue-600 transition-all text-sm dark:bg-slate-900 dark:hover:bg-slate-800 dark:border-gray-700 dark:text-gray-400 dark:hover:text-white dark:focus:ring-offset-gray-800"),d(_e,"type","button"),d(_e,"class","py-2 px-3 inline-flex justify-center items-center gap-2 rounded-md border font-medium bg-white text-gray-700 shadow-sm align-middle hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-offset-white focus:ring-blue-600 transition-all text-sm dark:bg-slate-900 dark:hover:bg-slate-800 dark:border-gray-700 dark:text-gray-400 dark:hover:text-white dark:focus:ring-offset-gray-800"),d(Ge,"class","inline-flex gap-x-2"),d(C,"class","px-6 py-4 grid gap-3 md:flex md:justify-between md:items-center border-t border-gray-200 dark:border-gray-700"),d(s,"class","bg-white border border-gray-200 rounded-xl shadow-sm overflow-hidden dark:bg-slate-900 dark:border-gray-700"),d(i,"class","p-1.5 min-w-full inline-block align-middle"),d(r,"class","-m-1.5 overflow-x-auto"),d(t,"class","flex flex-col"),d(n,"class","max-w-[85rem] px-4 py-10 sm:px-6 lg:px-8 lg:py-14 mx-auto")},m(ee,Be){qe&&qe.m(ee,Be),N(ee,e,Be),N(ee,n,Be),v(n,t),v(t,r),v(r,i),v(i,s),v(s,l),v(l,c),v(l,a),v(l,g),v(g,h),v(h,x),v(h,k),v(h,q),v(s,M),v(s,y),v(y,p),v(p,m);for(let oe=0;oe<Re.length;oe+=1)Re[oe]&&Re[oe].m(m,null);v(y,w),v(y,D);for(let oe=0;oe<je.length;oe+=1)je[oe]&&je[oe].m(D,null);v(s,P),v(s,C),v(C,f),v(f,u),v(f,_),v(f,j),v(j,O),v(O,H),v(O,I),v(O,J),v(f,Ce),v(f,ae),v(C,ot),v(C,tt),v(tt,Ge),v(Ge,Ue),v(Ge,ht),v(Ge,_e),N(ee,ft,Be),Pe&&Pe.m(ee,Be),N(ee,We,Be),yt=!0,Nt||(It=[Te(x,"click",o[11]),Te(q,"click",o[12]),Te(Ue,"click",o[9]),Te(_e,"click",o[10])],Nt=!0)},p(ee,[Be]){if(ee[6]?qe?(qe.p(ee,Be),Be&64&&L(qe,1)):(qe=Er(ee),qe.c(),L(qe,1),qe.m(e.parentNode,e)):qe&&(Se(),A(qe,1,1,()=>{qe=null}),Oe()),Be&256){bt=Le(ee[8]);let oe;for(oe=0;oe<bt.length;oe+=1){const $t=Lr(ee,bt,oe);Re[oe]?Re[oe].p($t,Be):(Re[oe]=Tr($t),Re[oe].c(),Re[oe].m(m,null))}for(;oe<Re.length;oe+=1)Re[oe].d(1);Re.length=bt.length}if(Be&304){ze=Le(ee[4]);let oe;for(oe=0;oe<ze.length;oe+=1){const $t=Or(ee,ze,oe);je[oe]?je[oe].p($t,Be):(je[oe]=Pr($t),je[oe].c(),je[oe].m(D,null))}for(;oe<je.length;oe+=1)je[oe].d(1);je.length=ze.length}(!yt||Be&4)&&T!==(T=ee[2]+1+"")&&De(H,T),(!yt||Be&8)&&F!==(F=Math.min(ee[3],ee[7].length)+"")&&De(J,F),ee[5]!=null?Pe?(Pe.p(ee,Be),Be&32&&L(Pe,1)):(Pe=qr(ee),Pe.c(),L(Pe,1),Pe.m(We.parentNode,We)):Pe&&(Se(),A(Pe,1,1,()=>{Pe=null}),Oe())},i(ee){yt||(L(qe),L(Pe),yt=!0)},o(ee){A(qe),A(Pe),yt=!1},d(ee){ee&&(B(e),B(n),B(ft),B(We)),qe&&qe.d(ee),nt(Re,ee),nt(je,ee),Pe&&Pe.d(ee),Nt=!1,mt(It)}}}function zs(o,e,n){let{df:t}=e,{onTrain:r}=e,{removeTrainingData:i}=e,s=JSON.parse(t),l=s.length>0?Object.keys(s[0]):[],c=10,a=1,g=Math.ceil(s.length/c),h=(a-1)*c,x=a*c,k=s.slice(h,x);const q=()=>{a>1&&n(16,a--,a)},M=()=>{a<g&&n(16,a++,a)},y=()=>{n(16,a=1),n(15,c=s.length)};let p=null,m=!1;const w=()=>{n(6,m=!0)},D=()=>{n(6,m=!1)},P=(u,_)=>{n(5,p=u[_])},C=()=>{n(5,p=null)},f=()=>{p&&i(p)};return o.$$set=u=>{"df"in u&&n(14,t=u.df),"onTrain"in u&&n(0,r=u.onTrain),"removeTrainingData"in u&&n(1,i=u.removeTrainingData)},o.$$.update=()=>{o.$$.dirty&98304&&n(2,h=(a-1)*c),o.$$.dirty&98304&&n(3,x=a*c),o.$$.dirty&12&&n(4,k=s.slice(h,x)),o.$$.dirty&32768&&n(17,g=Math.ceil(s.length/c)),o.$$.dirty&196608&&console.log(a,g)},[r,i,h,x,k,p,m,s,l,q,M,y,w,D,t,c,a,g,P,C,f]}class Vs extends ve{constructor(e){super(),be(this,e,zs,Is,he,{df:14,onTrain:0,removeTrainingData:1})}}function Gs(o){let e;return{c(){e=E("div"),e.innerHTML='<div class="flex flex-auto flex-col justify-center items-center p-4 md:p-5"><div class="flex justify-center"><div class="animate-spin inline-block w-6 h-6 border-[3px] border-current border-t-transparent text-blue-600 rounded-full" role="status" aria-label="loading"><span class="sr-only">Loading...</span></div></div></div>',d(e,"class","min-h-[15rem] flex flex-col bg-white border shadow-sm rounded-xl dark:bg-gray-800 dark:border-gray-700 dark:shadow-slate-700/[.7]")},m(n,t){N(n,e,t)},p:Y,i:Y,o:Y,d(n){n&&B(e)}}}function Zs(o){let e,n,t,r;const i=[Ws,Us],s=[];function l(c,a){return c[0].type==="df"?0:c[0].type==="error"?1:-1}return~(e=l(o))&&(n=s[e]=i[e](o)),{c(){n&&n.c(),t=Ve()},m(c,a){~e&&s[e].m(c,a),N(c,t,a),r=!0},p(c,a){let g=e;e=l(c),e===g?~e&&s[e].p(c,a):(n&&(Se(),A(s[g],1,1,()=>{s[g]=null}),Oe()),~e?(n=s[e],n?n.p(c,a):(n=s[e]=i[e](c),n.c()),L(n,1),n.m(t.parentNode,t)):n=null)},i(c){r||(L(n),r=!0)},o(c){A(n),r=!1},d(c){c&&B(t),~e&&s[e].d(c)}}}function Us(o){let e,n;return e=new En({props:{message:o[0].error}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&1&&(i.message=t[0].error),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function Ws(o){let e,n;return e=new Vs({props:{df:o[0].df,removeTrainingData:vo,onTrain:ko}}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},p(t,r){const i={};r&1&&(i.df=t[0].df),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function Qs(o){let e,n,t,r,i;const s=[Zs,Gs],l=[];function c(a,g){return a[0]!==null?0:1}return t=c(o),r=l[t]=s[t](o),{c(){e=E("div"),n=E("div"),r.c(),d(n,"class","py-10 lg:py-14"),d(e,"class","relative h-screen w-full lg:pl-64")},m(a,g){N(a,e,g),v(e,n),l[t].m(n,null),i=!0},p(a,[g]){let h=t;t=c(a),t===h?l[t].p(a,g):(Se(),A(l[h],1,1,()=>{l[h]=null}),Oe(),r=l[t],r?r.p(a,g):(r=l[t]=s[t](a),r.c()),L(r,1),r.m(n,null))},i(a){i||(L(r),i=!0)},o(a){A(r),i=!1},d(a){a&&B(e),l[t].d()}}}function Fs(o,e,n){let t;return et(o,cn,r=>n(0,t=r)),[t]}class Js extends ve{constructor(e){super(),be(this,e,Fs,Qs,he,{})}}function Ys(o){let e;return{c(){e=E("body"),e.innerHTML=`<div class="max-w-[50rem] flex flex-col mx-auto size-full"><header class="mb-auto flex justify-center z-50 w-full py-4"><nav class="px-4 sm:px-6 lg:px-8" aria-label="Global"><span class="flex-none text-xl font-semibold sm:text-3xl dark:text-white">Vanna.AI</span></nav></header> <div class="text-center py-10 px-4 sm:px-6 lg:px-8"><h1 class="block text-7xl font-bold text-gray-800 sm:text-9xl dark:text-white">No Training Data</h1> <h1 class="block text-2xl font-bold text-white">Did you read the docs?</h1> <p class="mt-3 text-gray-600 dark:text-gray-400">Oops, something went wrong.</p> <p class="text-gray-600 dark:text-gray-400">You need some training data before you can use Vanna</p> <div class="mt-5 flex flex-col justify-center items-center gap-2 sm:flex-row sm:gap-3"><a class="w-full sm:w-auto py-3 px-4 inline-flex justify-center items-center gap-x-2 text-sm font-semibold rounded-lg border border-transparent bg-blue-600 text-white hover:bg-blue-700 disabled:opacity-50 disabled:pointer-events-none dark:focus:outline-none dark:focus:ring-1 dark:focus:ring-gray-600" href="https://github.com/htmlstreamofficial/preline/tree/main/examples/html" target="_blank"><svg class="flex-shrink-0 size-4" xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" viewBox="0 0 16 16"><path d="M8 0C3.58 0 0 3.58 0 8c0 3.54 2.29 6.53 5.47 7.59.4.07.55-.17.55-.38 0-.19-.01-.82-.01-1.49-2.01.37-2.53-.49-2.69-.94-.09-.23-.48-.94-.82-1.13-.28-.15-.68-.52-.01-.53.63-.01 1.08.58 1.23.82.72 1.21 1.87.87 2.33.66.07-.52.28-.87.51-1.07-1.78-.2-3.64-.89-3.64-3.95 0-.87.31-1.59.82-2.15-.08-.2-.36-1.02.08-2.12 0 0 .67-.21 2.2.82.64-.18 1.32-.27 2-.27.68 0 1.36.09 2 .27 1.53-1.04 2.2-.82 2.2-.82.44 1.1.16 1.92.08 2.12.51.56.82 1.27.82 2.15 0 3.07-1.87 3.75-3.65 3.95.29.25.54.73.54 1.48 0 1.07-.01 1.93-.01 2.2 0 .21.15.46.55.38A8.012 8.012 0 0 0 16 8c0-4.42-3.58-8-8-8z"></path></svg>
            Get the source code</a> <a class="w-full sm:w-auto py-3 px-4 inline-flex justify-center items-center gap-x-2 text-sm font-semibold rounded-lg border border-transparent text-blue-600 hover:text-blue-800 disabled:opacity-50 disabled:pointer-events-none dark:text-blue-500 dark:hover:text-blue-400 dark:focus:outline-none dark:focus:ring-1 dark:focus:ring-gray-600" href="../examples.html"><svg class="flex-shrink-0 size-4" xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path d="m15 18-6-6 6-6"></path></svg>
            Back to examples</a></div></div> <footer class="mt-auto text-center py-5"><div class="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8"><p class="text-sm text-gray-500">© All Rights Reserved. 2022.</p></div></footer></div>`,d(e,"class","flex h-full")},m(n,t){N(n,e,t)},p:Y,i:Y,o:Y,d(n){n&&B(e)}}}class Ks extends ve{constructor(e){super(),be(this,e,null,Ys,he,{})}}function Xs(o){let e,n,t;return{c(){e=E("div"),n=E("div"),t=E("div"),d(t,"class","mt-7 bg-white border border-gray-200 rounded-xl shadow-sm dark:bg-gray-800 dark:border-gray-700"),d(n,"class","w-full max-w-md mx-auto p-6"),d(e,"class","dark:bg-slate-900 bg-gray-100 flex h-screen items-center py-16")},m(r,i){N(r,e,i),v(e,n),v(n,t),t.innerHTML=o[0]},p(r,[i]){i&1&&(t.innerHTML=r[0])},i:Y,o:Y,d(r){r&&B(e)}}}function el(o,e,n){let t;return et(o,fn,r=>n(0,t=r)),[t]}class tl extends ve{constructor(e){super(),be(this,e,el,Xs,he,{})}}function Ar(o){let e,n;return e=new Ao({}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function nl(o){let e,n;return e=new tl({}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function rl(o){let e,n;return e=new Ks({}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function ol(o){let e,n;return e=new Js({}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function il(o){let e,n;return e=new Ts({}),{c(){U(e.$$.fragment)},m(t,r){G(e,t,r),n=!0},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){A(e.$$.fragment,t),n=!1},d(t){Z(e,t)}}}function sl(o){let e,n,t,r,i,s=o[0]!=="login"&&Ar();const l=[il,ol,rl,nl],c=[];function a(g,h){return g[0]==="chat"?0:g[0]==="training-data"?1:g[0]==="no-training-data"?2:g[0]==="login"?3:-1}return~(t=a(o))&&(r=c[t]=l[t](o)),{c(){e=E("main"),s&&s.c(),n=Q(),r&&r.c()},m(g,h){N(g,e,h),s&&s.m(e,null),v(e,n),~t&&c[t].m(e,null),i=!0},p(g,[h]){g[0]!=="login"?s?h&1&&L(s,1):(s=Ar(),s.c(),L(s,1),s.m(e,n)):s&&(Se(),A(s,1,1,()=>{s=null}),Oe());let x=t;t=a(g),t!==x&&(r&&(Se(),A(c[x],1,1,()=>{c[x]=null}),Oe()),~t?(r=c[t],r||(r=c[t]=l[t](g),r.c()),L(r,1),r.m(e,null)):r=null)},i(g){i||(L(s),L(r),i=!0)},o(g){A(s),A(r),i=!1},d(g){g&&B(e),s&&s.d(),~t&&c[t].d()}}}function ll(o,e,n){let t;return et(o,wt,r=>n(0,t=r)),Hr(async()=>{yo(),ho(),new URL(window.location.href).hash.slice(1)==="training-data"?Ir():zr()}),[t]}class al extends ve{constructor(e){super(),be(this,e,ll,sl,he,{})}}new al({target:document.getElementById("app")});
'''